function sphase,mu,g,type
;+
; ROUTINE:  sphase,polar,g,type=type
;
; PURPOSE:  compute sphase greenstein phase function
;
; USEAGE:   sphase,polar,g
;
; INPUT:    
;   mu      cosine of polar angle (mu=1 in forward direction)
;   g       asymmetry factor 
; 
; keywords
;   rayleigh
;           returns rayleigh phase function and ignors value of g
;  
; EXAMPLE:  compute fraction of all single scattered radiation 
;           within a disk which subtends one degree of the of 
;           the forward direction.
;
;           shadow,.8,30,.01,type="henyey"
;
; AUTHOR:   Paul Ricchiazzi                        22 Apr 98
;           Institute for Computational Earth System Science
;           University of California, Santa Barbara
;           paul@icess.ucsb.edu
;
; REVISIONS:
;
;-
;


case 1 of 
strpos("rayleigh",type) ge 0:          return,.75*(1.+mu^2)
strpos("henyey-greenstein",type) ge 0: return,(1.-g^2)/(1.+g^2-2.*g*mu)^1.5
end 

end

