;+NAME/ONE LINE DESCRIPTIONG OF ROUTINE:
;    SCATANG returns the scattering angle in degrees.
;
; inputs:
;   sunz = solar zenith in degrees
;   senz = sensor view zenith in degrees
;   raz  = relative azimuth (suna - 180 - sena) in degrees
;          assuming both vectors are from surface to (sun or sen)
;          i.e.; raz of zero implies specular reflection 
;
; B. Franz
;
function scatang, sunz, senz, raz

;    scat = !radeg * acos( $
;     -cos(sunz/!radeg)*cos(senz/!radeg) $
;     +sin(sunz/!radeg)*sin(senz/!radeg)*cos((raz)/!radeg))

    csenz = cos(senz/!radeg)
    csolz = cos(sunz/!radeg)
    cphi  = cos((raz)/!radeg)

    temp  = sqrt((1-csenz*csenz)*(1-csolz*csolz))*cphi
    scat  = !radeg * acos(-csenz*csolz + temp)

    return, scat
end

