;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    PLPS is a postscript plot file tool.
;
;--------------------------------------------------------------------
;
; Procedure PLPS
;
; IDL procedure to simplify opening, closing, and printing of postscript 
; plot files.  
;
; Written By:   BA Franz
;
; Inputs:
;     iflag - 0=open plot file
;             1=close plot file
;
;--------------------------------------------------------------------
;
pro plps,iflag,queue,port=port,encap=encap,full=full,file=filename,ysize=ysize,color=color

common external, dev_type, file

if (n_elements(color) eq 0) then color=0

if (n_elements(queue)     eq 0) then begin
    queue=''
    hardcopy=0
endif else $
    hardcopy=1

if (n_elements(ysize) eq 0) then ysize=5

if (iflag eq 0) then $
    if (n_elements(filename)  eq 0) then begin
        spawn,'echo $$',pid
        file='/tmp/plps'+pid(0)+'.ps'
    endif else begin
        file = filename
    endelse

if (n_params(0) lt 1) then begin

    print,' '
    print,'Usage: plps,iflag,queue'
    print,' '
    print,'iflag = 0: open plot file'
    print,'        1: close plot file'
    print,' '

endif else begin

    if (iflag eq 0) then begin 

        dev_type = !d.name  ; Store current device name
        set_plot,'ps'

        device,color=color,file=file

        if (keyword_set(encap)) then begin
            device,encap=1
;            !p.charsize = 2.0*!p.charsize
;            !p.thick=2*!p.thick
;            !y.thick=2*!y.thick
;            !x.thick=2*!x.thick
            !p.font = 0
            device, /times
        endif else                         $
            device,encap=0
           
        if (keyword_set(port)) then begin
            device,/port
            if (keyword_set(full)) then           $
                device,/inches,ysize=9,yoffset=1   $
            else                                  $
                device,/inches,ysize=ysize,yoffset=5
        endif else begin
            device,/land
        endelse
           
    endif else begin

        device,/close
        set_plot,dev_type   ; Restore Previous Plot Type

        if (hardcopy) then begin
             spawn,'lpr -P'+queue+' '+file
             print,'Sending ',file,' to ',queue
        endif else $
             print,'File ',file,' has been generated'

    endelse

endelse

return
end
