;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    LMPOLYFIT is a polynomial fitting function which uses a Levenburg-Marquart
;    optimization.
;
;---------------------------------------------------------------------
; Polynomial fitting function for curvefit
;
; BA Franz
;
;----------------------------------------------------------------------
pro polyfunc,x,a,f,pder

npts   = n_elements(x)
nterms = n_elements(a)

;
; Evaluate the function
;
f = a(0) & for i=1,nterms-1 do f = f + a(i)*x^i

;
; Evaluate the partial derivatives
;
if (n_params(0) gt 3) then begin
    pder = dblarr(npts,nterms)
    for i=0,nterms-1 do pder(*,i) = x^i
endif

return
end
;
;=====================================================================
;
;---------------------------------------------------------------------
; Polynomial fitter for curvefit
;
; BA Franz
;
;----------------------------------------------------------------------
function lmpolyfit,xin,yin,order,wts=wts,yfit

npts   = n_elements(xin)
fitpar = dblarr(order+1)

;
; Shift to center of gravity to minimize precission losses
;
x = double(xin)  &  x0 = med(x)  &  x = x-x0
y = double(yin)  &  y0 = med(y)  &  y = y-y0

;
; Initial estimates of fitting parameters
;
fitpar(0) = med(y)
if (order ge 1) then $
    fitpar(1) = (y(where(x eq max(x)))-y(where(x eq min(x))))/(max(x)-min(x))

;
; Form weights
;
if (n_elements(wts) eq 0) then wts = dblarr(npts)+1.0

;
; Form fit
;
yfit = modelfit(x,y,wts,fitpar,function_name='polyfunc')

;
; Shift coeffs back to original ordinate and evaluate fit for xin
;
fitpar = polyshft(fitpar,x0,y0)
polyfunc,xin,fitpar,yfit

return,fitpar
end
