;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    LSPLINE linearly interpolates/extrapolates to perform a spline on a
;    set of points.
;
;------------------------------------------------------------------------
; Procedure LSPLINE
;
; IDL Procedure to spline-fit a set of points using linear interpolation
; and/or extrapolation.
;
; Programmer: Bryan A. Franz, ARC
; Date Written: 2/93
;
; Inputs:
;   xin   - input x-vector (sorted)
;   yin   - input y-vector
;   xout  - output x-vector (sorted)
;
; Outputs:
;   yout  - output y-array
;
;------------------------------------------------------------------------
function lspline,xxin,yyin,xout
;
nin = n_elements(xxin)
xin = 1.*xxin
yin = 1.*yyin

nout = n_elements(xout)
yout = fltarr(nout)
;
; Calculate slopes (forward difference)
;
i   = lindgen(nin-1)
ip1 = i+1
m   = 1.*(yin(ip1)-yin(i))/(xin(ip1) - xin(i))
m   = [m,m(nin-2)]
;
; Forward extrapolation
;
nforw = 0
select = where(xout ge xin(nin-1))
if (select(0) ne -1) then begin
    nforw = n_elements(select)
    yout(select) = yin(nin-1) + m(nin-1)*(xout(select)-xin(nin-1))
endif
;
; Backward extrapolation
;
nback = 0
select = where(xout le xin(0))
if (select(0) ne -1) then begin
    nback = n_elements(select)
    yout(select) = yin(0) + m(0)*(xout(select)-xin(0))
endif
;
; Interpolation
;
j = long(nback)
i = 0L
while (j lt nout-nforw) do begin
    while (xin(i) le xout(j) ) do i=i+1
    i = i-1
    yout(j) = yin(i) + m(i)*(xout(j)-xin(i))
    j = j+1
endwhile     

return,yout
end
