;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    POLYSHFT shifts a set of polynomial coefficients in x and y.
;
;-----------------------------------------------------------------
; Function to shift a set of polynomial coefficients in X and Y.
; Formulation courtesy of R. G. Arendt.
;
; Written By: BA Franz, 2/23/94
;
; Inputs:
;     B   - original coefficients, (B(0)-Yo)+B(1)*(X-Xo)+B(2)*(X-Xo)^2 + ...
;     Xo  - Amount to shift curve in X
;     Yo  - Amount to shift curve in Y
; 
; Outputs:
;     A   - new coefficients, A(0) + A(1)*X + A(2)*X^2 + ...
;-----------------------------------------------------------------
function polyshft,B,Xo,Yo

order = n_elements(B)-1

if (n_elements(Yo) eq 0) then Yo = 0.
if ((n_elements(Xo) eq 0) or (order eq 0)) then return,B

A = B*0.0  &  A(0) = Yo

for i=0,order do for j=i,order do $
    A(i) = A(i) + B(j)*(-Xo)^(j-i)*bnc(j,i)

return,A
end
