;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    TEST_MODELFIT evaluates a function and tests the modelfit routine with it.
;
pro expfunc,x,a,f,pder,indxpar=indxpar

npts = n_elements(x)

Co    = a(0)
C1    = a(1)
Tau   = a(2)

;
; Evaluate the function
;
f = Co + C1 * exp(x/Tau)

;
; Evaluate the partial derivatives
;
if (n_params(0) gt 3) then begin
    pder = dblarr(npts,3)
    pder(*,0) =  1.
    pder(*,1) =  exp(x/Tau)
    pder(*,2) =  - C1 * exp(x/Tau) * x/Tau^2
endif

return
end

;
;=====================================================================
;
tsparams = [3.948,0.6869,0.3934]
params = [5.0,1.0,0.5]
astart = params * [1.5,0.5,1.5]

npts = 2000
x = findgen(npts)*2./npts + 0.01
expfunc,x,params,y

expfunc,x,tsparams,tsfit

seed         = 9999
input_sigma  = 0.01 * max(y)
noise        = randomn(seed, npts) * input_sigma
output_sigma = stdev(noise)

y2  = y + noise
wts = fltarr(npts) + 1./output_sigma^2

;
; Form fit
;
fitpar = astart
yfit   = modelfit(x,y2,wts,fitpar,sigma=sigma_a,covar=covar,chisqr=chisqr, $
                 function_name='expfunc')

wait,1.

;plot,x,y,/xst,/yst
plot,x,y2,psym=3
oplot,x,yfit,line=1
;oplot,x,tsfit,line=1

openw,1,'test_modelfit.dat'
printf,1,''
printf,1,'Fitting Function:'
printf,1,'y = Co + C1 * exp(x/Tau)'
printf,1,''
printf,1,'True Parameters:
printf,1,'Co = ',params(0),',  C1 = ',params(1),',  Tau = ',params(2)
printf,1,''
printf,1,'My Starting Params:',astart(0),astart(1),astart(2)
printf,1,'My Final Params:   ',fitpar(0),fitpar(1),fitpar(2)
printf,1,'My Chisqr: ',chisqr
printf,1,'My Sigmas: ',sigma_a(0),sigma_a(1),sigma_a(2)
printf,1,''
printf,1,'Data (x,y,sigma):'
printf,1,''
for i=0,npts-1 do printf,1,x(i),y2(i),output_sigma
close,1

end
