;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    HDF_INFO obtains file description information from a given hdf file.
;
pro hdf_info,filename,sds=sds,rig=rig,all=all,global=global

    F1='(" ",A,I4)'
    F2='("-----",A,A,"-----")'
    F3='("-----",A,"-----")'
    FI='(A24," ",A8," ",I6," ",I)'
    FS='(A24," ",A8," ",I6," ",A)'
    FF='(A24," ",A8," ",I6," ",F)'
    FD='(A24," ",A8," ",I6," ",D)'
    F4='(A24," ",A8," ",I6)'
    F5='(A24," ",A8," ",A6)'

    ;
    ; Check that it is HDF
    ;
    if hdf_ishdf(filename) ne 1 then begin
        message,"File "+filename+" is not an HDF file."
    endif

    ;
    ; Open the HDF file readonly
    ;
    fileid=hdf_open(filename,/read)
    print
    print,"Contents of ",filename
    print

    ; Get and report the number of free palettes.
    numfpals=hdf_dfp_npals(filename)>0
    print,'====================================='
    print,"	# of free palettes = ",numfpals,FORMAT=F1

    ; Get the number of file ids and read them.
    numid=hdf_number(fileid,tag=100)>0
    print,'====================================='
    print,"	# of file file ids = ",numid,FORMAT=F1
    if numid ne 0 then begin
        if numid eq 1 then begin
            hdf_dfan_getfid,filename,fid,/first
            print,"File Id",FORMAT=F3 & print,strcompress(string(fid))
        endif else begin
            print,"File Id",string(1),FORMAT=F2
            hdf_dfan_getfid,filename,fid,/first & print,strcompress(string(fid))
            for i=2,numid do  begin
                print,"File Id",strtrim(string(i)),FORMAT=F2
                hdf_dfan_getfid,filename,fid & print,strcompress(string(fid))
            endfor
        endelse
    endif

    ; Get the number of file descriptions and read them.
    numdesc=hdf_number(fileid,tag=101)>0
    print,'====================================='
    print,"	# of file descriptions = ",numdesc,FORMAT=F1
    if numdesc ne 0 then begin
	if numdesc eq 1 then begin
	    hdf_dfan_getfds,filename,desc,/first
	    print,"File Description",FORMAT=F3 & print,string(desc)
	endif else begin
	    print,"File Description",string(1),FORMAT=F2
	    hdf_dfan_getfds,filename,desc,/first & print,string(desc)
	    for i=2,numdesc do  begin
	        print,"File Description",string(i),FORMAT=F2
	        hdf_dfan_getfds,filename,desc & print,string(desc)
	    endfor
	endelse
    endif


    if (keyword_set(rig) or keyword_set(all)) then begin

        ; Get the number of RIG groups in the file
        numrig=hdf_number(fileid,tag=306)>0
	print,'====================================='
	print,"	# of RIG groups = ",numrig,FORMAT=F1
	if numrig gt 0 then begin
	    result=hdf_dfan_lablist(filename,306,reflist,RIGLABELS)
	    print,reflist,string(RIGLABELS)
	endif

    endif 


    if (keyword_set(sds) or keyword_set(all)) then begin

        ; Get the number of SDSs in the file
        numndg=hdf_number(fileid,tag=721)>0
        numsdd=hdf_number(fileid,tag=701)>0
        numsd=hdf_number(fileid,tag=702)>0
	hdf_dfsd_getinfo,filename, NSDS=numsds
	print,'====================================='
	print,"	# of SDS = ",numsds,FORMAT=F1
	print," 

        ;Get the number of MFSDs in the file
        sd_id=HDF_SD_START(filename,/read)
        HDF_SD_FILEINFO,sd_id,nmfsds,nglobatts
	print,'====================================='
	print,"	# of MFSD = ",nmfsds,FORMAT=F1
	print," 

	if nmfsds gt 0 then begin
	    print," "
	    print,"     Name        Rank      Type     DIMS      Nattrs   Attribute Value"
	    print,"---------------------------------------------------------------"
            FSD='(A14," ",I4,"      ",A8,"     ",I4)'

	    for i=0,nmfsds-1 do begin
	        sds_id=HDF_SD_SELECT(sd_id,i)
	        HDF_SD_GETINFO,sds_id,name=n,ndims=r,type=t,natts=nats,dims=dims
	        print,n,r,t,nats,FORMAT=FSD
	        print,'                                       DIMS = ',dims

  	        for j=0,nats-1 do begin
	            d=''
	            HDF_SD_ATTRINFO,sds_id,j,name=n,type=t,count=c,data=d
	            print,'                                         ',n,'= ',d
	        endfor
	        HDF_SD_ENDACCESS,sds_id
	    endfor
	endif

        HDF_SD_END,sd_id

    endif

    if (keyword_set(all) or keyword_set(global)) then begin

        print,'====================================='
        print,"    # of Global Attributes ",nglobatts
	if nglobatts gt 0 then begin
            print
	    print,"------------------------------------------------"
	    print,'Name','Type','Number',FORMAT=F5
	    print
	    for i=0,nglobatts-1 do begin
		HDF_SD_ATTRINFO,sd_id,i,name=n,type=t,count=c,data=d
	        if (t eq 'STRING' ) then print,strtrim(n),t,c,d(0,0),FORMAT=FS else $
	        if (t eq 'FLOAT' )  then print,strtrim(n),t,c,d(0,0),FORMAT=FF else $
	        if (t eq 'DOUBLE' ) then print,strtrim(n),t,c,d(0,0),FORMAT=FD else $
		                         print,strtrim(n),t,c,d(0,0),FORMAT=FI
   	    endfor
	endif

    endif


    HDF_CLOSE,fileid

end
