;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    READL2NC reads a geophysical dataset from an l2gen netcdf4 file, applies scaling
;
;  NAME:
;    readl2nc
;
;  PURPOSE:                                   
;    Simplifies the reading of standard k2gen netcdf4 file. Auto
;    applies slope/intercept scaling. Can read multiple band-specific 
;    SDS products into a single array.
;
;  CALLING SEQUENCE:
;    data = readl2nc(filename,prodname)
;
;  INPUT:
;    filename - L2 filename string.
;    prodname - L2 product name string. If this ends in '_', all
;               products of name prodname_nnn (where nnn is wavelength)
;               will be returned.
;
;  OUTPUT:
;    data - 1, 2, or 3-dimensional array containing the requested product.
;
;  SUBROUTINES CALLED:
;
;  WRITTEN BY:
;    B. Franz, October 2014.
;
;-
function readl2nc,file,field,grp=grp,wv=wave

    if (not keyword_set(grp)) then grp='geophysical_data'

    last_char = strmid(field,strlen(field)-1,1)

    if (last_char eq '_') then begin

      wave = read_hdf5(file,'wavelength',group='sensor_band_parameters')
      wl = strtrim(string(wave),2)
      nb = n_elements(wl)

      first =  1

      for i=0,nb-1 do begin

        sdsname = field+wl(i)
        print,sdsname
        val = read_hdf5(file,sdsname,/scale,group=grp)

        if (first eq 1) then begin
            first = 0
            data  = val
        endif else begin
            data  = [[[data]],[[val]]]
        endelse

      endfor

    endif else begin

      sdsname = field
      data = read_hdf5(file,sdsname,/scale,group=grp)

    endelse

    return, data
end


