;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    READL3SMI reads the image from and SMI file
;
;  NAME:
;    readl3smi
;
;  PURPOSE:                                   
;    Simplifies the reading of SeaWiFS standard L3 mapped images. 
;
;  CALLING SEQUENCE:
;    data = readl3smi(filename)
;
;  INPUT:
;    filename - SMI filename string.
;
;  OUTPUT:
;    data - 2-dimensional array containing the converted image data.
;
;  SUBROUTINES CALLED:
;
;  WRITTEN BY:
;    B. A. Franz, SAIC 
;    February 2007.
;
; HISTORY:
;
;-
function readl3smi,file

    fid = HDF_SD_START(file, /READ)
    idata = rd_sds(fid,'l3m_data')
    iret  = HDF_Get_ATTR(fid, 'Slope',     gain)
    iret  = HDF_Get_ATTR(fid, 'Intercept', offset)
    iret  = HDF_Get_ATTR(fid, 'Scaling',   type)
    if (type eq "linear") then $
        data  = idata*gain + offset $
    else $
        data  = 10.0^(idata*gain + offset)

    HDF_SD_END, fid

    return, data
end
