PRO l3t_anal, DO_SCAT = do_scat, DO_SUMSCAT = do_sumscat, DO_HIST = do_hist
;
;  l3t_anal will do many types of analysis on the l3 timebinned files
;  ** Testing here to see if we can read same dataset from 2 directories
;
;  Keywords:
;    DO_SCAT - do the scatter plot.  It also is a skip factor for
;              plotting the scatter (to reduce file size currently, 100
;              is used)
;    DO_SUMSCAT - do the summary scatter plot
;    DO_HIST - do a pair of histograms
;
;  W. Robinson, GSC, 20 Nov 2000
;
;
;  Variable section for the files to use and the parameters to do
;
;  declare the base and test file names: Winter only
test_f_w = '/mnt/pr005/disk01/SeaWiFS/Mission_Test/l3_timebin/1998/S19981851998192.L3b_8D_SWREP4.main'
base_f_w = '/mnt/pr002/disk01/SeaWiFS/Wayne_Jul98/l3_timebin/1998/S19981851998192.L3b_8D_SWREP4.main'
;
;
;  declare the standard parameters to process
params = [ 'nLw_412', 'nLw_443', 'nLw_490', 'nLw_510', 'nLw_555',  $
   'nLw_670', 'angstrom_510', 'chlor_a', 'K_490', 'chlor_a_K_490', $
   'eps_78', 'tau_865' ]
;
;  set the parm plot range and bin size for non-chlor data
prm_pl_rng = [ [ 0., 5. ], [ 0., 5. ], [ 0., 4. ], [ 0., 3. ], $
   [ 0., 2. ], [ 0., 0.6 ], [ -.2, 1.5 ], [ 0., 64. ], [ 0., 0.5 ], $
   [ 0., 30. ], [ 0.8, 1.5 ], [ 0., 0.5 ] ]
prm_bin_sz = [ 0.01, 0.01, 0.01, 0.01, 0.005, 0.002, $
    0.01, 0.001, 0.005, 0.05, 0.005, 0.002 ]
;
;  for convenience, set the index of parameters to really do
;prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 ]
;prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 8, 9, 10, 11 ]
prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 ]
;
;  declare the scatter plot specifics
sp_base_titl = 'Repro 3 SGI'
sp_test_titl = 'Repro 3 LINUX'
sp_base_titl = 'Oper. stray light'
sp_test_titl = 'New stray light'
;
;  set up for the plotting
!X.STYLE = 1
!Y.STYLE = 1
!P.FONT = 0
SET_PLOT, 'PS'
!P.MULTI = [0, 1, 2 ]
DEVICE, YSIZE = 9, YOFFSET = 1, /INCHES, /PORTRAIT
;
;  set a lun for summary scatter output
OPENW, lun, 'l3t_anal.txt', /GET_LUN
;
nparams = n_elements( prm_ix )
nseason = 1
ncomp = 2
totbin = lonarr(nseason,ncomp)
totsamp = lonarr(nseason,ncomp)
prm_mean = fltarr(nseason,ncomp,nparams)
;  for # of bins that are matching to some degree
nin = fltarr(nseason, nparams, 10)      ; of matching bins
nin_mch = fltarr(nseason, nparams, 10)  ; of bins with same # obs
nbin_mch = lonarr(nseason,2)   ; how many bins have same # obs for same
                               ; bins and for same bins with same # obs?
;
print, 'Base Winter dataset: ', base_f_w
print, 'Test Winter dataset: ', test_f_w
printf, lun, 'Base Winter dataset: ', base_f_w
printf, lun, 'Test Winter dataset: ', test_f_w
filebreak, base_f_w, dir = base_dir, file = base_fex_w
filebreak, test_f_w, dir = test_dir, file = test_fex_w
;
;  read in the base data
spawn, 'pwd', result
start_dir = result[0]
FOR  i = 0, ( nparams - 1 ) DO $
  BEGIN
  PRINT, 'Param index: ', i, '  Param #: ', $
      prm_ix[i], '  Param Name: ', params[prm_ix[i]]
  PRINTF, lun, 'Param index: ', i, '  Param #: ', $
      prm_ix[i], '  Param Name: ', params[prm_ix[i]]
;
;  do Winter and Summer in this loop
  FOR  j = 0, (nseason - 1) DO $
    BEGIN
    PRINT, 'Season: ', j
    PRINTF, lun, 'Season: ', j
    IF  j EQ 0  THEN BEGIN
      base_f = base_fex_w  
      test_f = test_fex_w
      END ELSE BEGIN
      base_f = base_fex_s
      test_f = test_fex_s
      END
;
;    base data read
    cd, base_dir
    mean_b = readl3bin( base_f, params[prm_ix[i]], lon, lat, bins_b, nobs_b, wts_b, $
       out_b, nseg, /noll )
    cd, start_dir
;
;  get the info on that data
    ix = where( nobs_b GT 0, ct_b )
    prm_mean[j,0,i] = TOTAL( DOUBLE( out_b[0,ix] ) ) / TOTAL( DOUBLE( wts_b ) )
    totbin[j,0] = ct_b
    totsamp[j,0] = TOTAL( LONG( nobs_b ) )
;
;    Test data read
    cd, test_dir
    mean_t = readl3bin( test_f, params[prm_ix[i]], lon, lat, bins_t, nobs_t, wts_t, $
       out_t, nseg, /noll )
    cd, start_dir
; 
;  get the info on that data
    ix = where( nobs_t GT 0, ct_t )
    prm_mean[j,1,i] = TOTAL( DOUBLE( out_t[0,ix] ) ) / TOTAL( DOUBLE( wts_t ) )
    totbin[j,1] = ct_t
    totsamp[j,1] = TOTAL( LONG( nobs_t ) )
;
;    find the common points and do the scatter plot
    ct_comm = bin_mtch( bins_b, bins_t, ix_b, ix_t )
    nbin_mch[j, 0 ] = ct_comm
;
;    collect some info on bins that match exactly or within 10^x
    dif = mean_t[ix_t] - mean_b[ix_b]
    ixt = WHERE( dif EQ 0., cx )
    nin[j, i, 0] = float( cx ) / nbin_mch[j, 0 ]
;    get the rms(diff)
    nin[j, i, 1] = SQRT( TOTAL( dif * dif ) / nbin_mch[j, 0 ] )
    FOR  ipow = -6, 1  DO $
      BEGIN
      ixt = WHERE( ABS( dif ) LT 10.^ipow, cx )
      nin[j, i, 8 + ipow ] = FLOAT( cx ) / nbin_mch[j, 0 ]
      END
;
;    do again for matching bins with same # observations
    ix_m = WHERE( nobs_b[ix_b] EQ nobs_t[ix_t], cx )
    nbin_mch[j, 1 ] = cx
    dif = dif[ix_m]
    ixt = WHERE( dif EQ 0., cx )
    nin_mch[j, i, 0] = float( cx ) / nbin_mch[j, 1 ]
;    get the rms(diff)
    nin_mch[j, i, 1] = SQRT( TOTAL( dif * dif ) / nbin_mch[j, 1 ] )
    FOR  ipow = -6, 1  DO $
      BEGIN
      ixt = WHERE( ABS( dif ) LT 10.^ipow, cx )
      nin_mch[j, i, 8 + ipow ] = FLOAT( cx ) / nbin_mch[j, 1 ]
      END
;
    IF  KEYWORD_SET( do_scat )  THEN $
      BEGIN
      IF  j EQ 0  THEN  month = 'January' ELSE month = 'July'
      IF  params[prm_ix[i]] EQ 'chlor_a'  THEN $
        BEGIN
        ptitle = 'Chlorophyll scatter plot, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_scat_chl, mean_b[ix_b], mean_t[ix_t], $
          ptitle, pxtitle, pytitle, PLT_SKIP = do_scat, FR_DIFF = 0.05,  $
          TLUN = lun
        END $
      ELSE $
        BEGIN
        ptitle = params[prm_ix[i]] + ' scatter plot, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_scat_lin, mean_b[ix_b], mean_t[ix_t], ptitle, $
          pxtitle, pytitle, PLT_SKIP = do_scat, FR_DIFF = 0.01, $
          PLT_RNG = prm_pl_rng[*,prm_ix[i]], TLUN = lun
        END
      END  ; do_scat stuff
;
    IF  KEYWORD_SET( do_sumscat )  THEN $
      BEGIN
      IF  j EQ 0  THEN  month = 'January' ELSE month = 'July'
      IF  params[prm_ix[i]] EQ 'chlor_a'  THEN $
        BEGIN
        ptitle = 'Chlorophyll scatter plot, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_scat_chl_sum, mean_b[ix_b], mean_t[ix_t], $
          ptitle, pxtitle, pytitle, 1, TLUN = lun
        END $
      ELSE $
        BEGIN
        ptitle = params[prm_ix[i]] + ' summary scatter plot, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_scat_lin_sum, mean_b[ix_b], mean_t[ix_t], ptitle, $
          pxtitle, pytitle, 1, TLUN = lun, PLT_RNG = prm_pl_rng[*,prm_ix[i]]
        END
      END  ; do_sumscat stuff
;
    IF  KEYWORD_SET( do_hist )  THEN $
      BEGIN
      IF  j EQ 0  THEN  month = 'January' ELSE month = 'July'
      IF  params[prm_ix[i]] EQ 'chlor_a'  THEN $
        BEGIN
        ptitle = 'Chlorophyll histograms, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_hst_chl, mean_b, mean_t, ptitle, pxtitle, pytitle, TLUN = lun
        END  $
      ELSE $
        BEGIN
        ptitle = params[prm_ix[i]] + ' histograms, ' + month
        pxtitle = sp_base_titl
        pytitle = sp_test_titl
        plt_hst_lin, mean_b, mean_t, params[prm_ix[i]], ptitle, pxtitle, $
           pytitle, /EXCL_HIGH_BIN, PLT_RNG = prm_pl_rng[*,prm_ix[i]], $
           BIN_SZ = prm_bin_sz[prm_ix[i]], TLUN = lun
        END
      END  ; do_hist stuff
    END
;
  END
;
;  finish plots
DEVICE, /CLOSE
SET_PLOT, 'x'
;
;  print the results of the means...
FOR  j = 0, (nseason - 1 ) DO $
  BEGIN
  IF  j EQ 0  THEN  PRINT, 'Winter:' ELSE PRINT, 'Summer:'
  PRINT, 'parameter             base        test   % change'
  PRINT, '# filled bins ', totbin[j,0], totbin[j,1],  $
    100. * FLOAT( totbin[j,1] - totbin[j,0] ) / FLOAT( totbin[j,0] ), $
    FORMAT ='(a,i12,i12,f11.4)'
  PRINT, '# samples     ', totsamp[j,0], totsamp[j,1], $
    100. * FLOAT( totsamp[j,1] - totsamp[j,0] ) / FLOAT( totsamp[j,0] ), $
    FORMAT ='(a,i12,i12,f11.4)'
;
  IF  j EQ 0  THEN  PRINTF, lun,  'Winter:' ELSE PRINTF, lun,  'Summer:'
  PRINTF, lun, 'parameter             base        test   % change'
  PRINTF, lun, '# filled bins ', totbin[j,0], totbin[j,1],  $
    100. * FLOAT( totbin[j,1] - totbin[j,0] ) / FLOAT( totbin[j,0] ), $
    FORMAT ='(a,i12,i12,f11.4)'
  PRINTF, lun, '# samples     ', totsamp[j,0], totsamp[j,1], $
    100. * FLOAT( totsamp[j,1] - totsamp[j,0] ) / FLOAT( totsamp[j,0] ), $
    FORMAT ='(a,i12,i12,f11.4)'
;
  PRINT, 'Means of parameters (Note that means here use bin weights)'
  PRINTF, lun, 'Means of parameters (Note that means here use bin weights)'
  FOR  i = 0, ( nparams - 1 ) DO $
    BEGIN
    PRINT, params[prm_ix[i]], prm_mean[j,0,i], prm_mean[j,1,i], $
    100. * ( prm_mean[j,1,i] - prm_mean[j,0,i] ) / prm_mean[j,0,i], $
    FORMAT ='(a14,f12.6,f12.6,f11.4)'
;
    PRINTF, lun, params[prm_ix[i]], prm_mean[j,0,i], prm_mean[j,1,i], $
    100. * ( prm_mean[j,1,i] - prm_mean[j,0,i] ) / prm_mean[j,0,i], $
    FORMAT ='(a14,f12.6,f12.6,f11.4)'
    END
;
;  do report for matching bins 
  PRINT, ' '
  PRINT, '# of matched bins: ', nbin_mch[j, 0]
  PRINT, ' '
  PRINT, 'Next, fraction of bins matching within a tolerence'
  PRINT, 'Tolerence      0         RMS(dif)   10^-6      10^-5     10^-4     0.001      0.01       0.1      1.        10.'
  PRINTF, lun, ' '
  PRINTF, lun, '# of matched bins: ', nbin_mch[j, 0]
  PRINTF, lun, ' '
  PRINTF, lun, 'Next, fraction of bins matching within a tolerence'
  PRINTF, lun, 'Tolerence          0     RMS(dif)   10^-6      10^-5     10^-4     0.001      0.01       0.1      1.        10.'
  FOR  i = 0, ( nparams - 1 ) DO $
    BEGIN
    PRINT, params[prm_ix[i]], nin[j, i, 0], nin[j, i, 1], nin[j, i, 2], nin[j, i, 3], nin[j, i, 4], nin[j, i, 5], nin[j, i, 6], nin[j, i, 7], nin[j, i, 8],nin[j, i, 9], FORMAT = '(a14,f10.6,9f10.7)'
    PRINTF, lun, params[prm_ix[i]], nin[j, i, 0], nin[j, i, 1], nin[j, i, 2], nin[j, i, 3], nin[j, i, 4], nin[j, i, 5], nin[j, i, 6], nin[j, i, 7], nin[j, i, 8],nin[j, i, 9], FORMAT = '(a14,f10.6,9f10.7)'
    END
  PRINT, ' '
  red = nbin_mch[j, 0] - nbin_mch[j, 1]
  redp = 100. * red / nbin_mch[j, 0]
  PRINT, '# of matched bins with equal # of observations: ', nbin_mch[j, 1], ' a reduction of: ', red, redp, ' %'
  PRINT, ' '
  PRINT, 'Next, fraction of bins matching within a tolerence (= # obs)'
  PRINT, 'Tolerence          0     RMS(dif)   10^-6      10^-5     10^-4     0.001      0.01       0.1      1.        10.'
  PRINTF, lun, ' '
  PRINTF, lun, '# of matched bins with equal # of observations: ', nbin_mch[j, 1], ' a reduction of: ', red, redp, ' %'
  PRINTF, lun, ' '
  PRINTF, lun, 'Next, fraction of bins matching within a tolerence (= # obs)'
  PRINTF, lun, 'Tolerence      0         RMS(dif)   10^-6      10^-5     10^-4     0.001      0.01       0.1      1.        10.'
  FOR  i = 0, ( nparams - 1 ) DO $
    BEGIN
    PRINT, params[prm_ix[i]], nin_mch[j, i, 0], nin_mch[j, i, 1], nin_mch[j, i, 2], nin_mch[j, i, 3], nin_mch[j, i, 4], nin_mch[j, i, 5], nin_mch[j, i, 6], nin_mch[j, i, 7], nin_mch[j, i, 8], nin_mch[j, i, 9], FORMAT = '(a14,f10.6,9f10.7)'
    PRINTF, lun, params[prm_ix[i]], nin_mch[j, i, 0], nin_mch[j, i, 1], nin_mch[j, i, 2], nin_mch[j, i, 3], nin_mch[j, i, 4], nin_mch[j, i, 5], nin_mch[j, i, 6], nin_mch[j, i, 7], nin_mch[j, i, 8], nin_mch[j, i, 9], FORMAT = '(a14,f10.6,9f10.7)'
    END
  END
;
CLOSE, lun
FREE_LUN, lun
;
;
;
RETURN
END
