PRO mskchg, LATRNG = latrng, LONRNG = lonrng
;
;  mskchg will get info out about the mask changes as they affect the data
;
;  W. Robinson, GSC, 21 Jan 2002
;
;  keywords LATRNG and LONRNG select only a certain latitude and longitude range
;
;
;  Variable section for the files to use and the parameters to do
;
fil1 = '/mnt/pr002/disk01/SeaWiFS/'
fil2 = '/l3_timebin/2001/S20011532001160.L3b_8D_SWREP4.main'
;filmid = [ 'Control_Set', 'ABSAER_Set', 'ATMWARN_Set', 'COCCOLITH_Set', 'HILT_Set', 'HISATZEN_Set', 'HISOLZEN_Set', 'LOWLW_Set', 'MASAERITER_Set', 'NAVWARN_Set', 'STRAYLIGHT_Set', 'TURBIDW_Set' ]
filmid = [ 'Control_Set', 'STRAYLIGHT_Set' ]
;
base_f = fil1 + filmid[0] + fil2
;
;
;  declare the standard parameters to process
params = [ 'nLw_412', 'nLw_443', 'nLw_490', 'nLw_510', 'nLw_555',  $
   'nLw_670', 'angstrom_510', 'chlor_a', 'K_490', 'chlor_a_K_490', $
   'eps_78', 'tau_865' ]
;
;  set the parm plot range and bin size for non-chlor data
prm_pl_rng = [ [ 0., 5. ], [ 0., 5. ], [ 0., 4. ], [ 0., 3. ], $
   [ 0., 2. ], [ 0., 0.6 ], [ -.2, 1.5 ], [ 0., 64. ], [ 0., 0.5 ], $
   [ 0., 30. ], [ 0.8, 1.5 ], [ 0., 0.5 ] ]
prm_bin_sz = [ 0.01, 0.01, 0.01, 0.01, 0.005, 0.002, $
    0.01, 0.001, 0.005, 0.05, 0.005, 0.002 ]
;
;  for convenience, set the index of parameters to really do
;prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 ]
;prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 8, 9, 10, 11 ]
;prm_ix = [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 ]
prm_ix = [ 7 ]
;
latrng = [ -35., -20. ]
lonrng = [ -140., -100. ]
;
;  declare the scatter plot specifics
sp_base_titl = 'Control set'
;
;  set up for the plotting
!X.STYLE = 1
!Y.STYLE = 1
!P.FONT = 0
SET_PLOT, 'PS'
!P.MULTI = [0, 1, 2 ]
DEVICE, YSIZE = 9, YOFFSET = 1, /INCHES, /PORTRAIT
;
;  set a lun for summary scatter output
OPENW, lun, 'mskchg.txt', /GET_LUN
;
nparams = n_elements( prm_ix )
ncomp = n_elements( filmid ) - 1
totbin = lonarr(ncomp+1)
totsamp = lonarr(ncomp+1)
meanv = dblarr( ncomp+1, nparams )
sdv = dblarr( ncomp+1, nparams )
;
filebreak, base_f, dir = base_dir, file = base_fex
spawn, 'pwd', result
start_dir = result[0]
;
; loop through the parameters and do compares
for ipar = 0, ( nparams - 1 ) do $
  BEGIN
  ;  get the info from the base file
  cd, base_dir
  mean_b = readl3bin( base_f, params[prm_ix[ipar]], lon, lat, bins_b, nobs_b, wts_b, out_b, nseg )
  cd, start_dir
;
;  get the lat, long specific values
  ix = where( ( lon ge lonrng[0] ) and ( lon le lonrng[1] ) and $
         ( lat ge latrng[0] ) and ( lat le latrng[1] ), ct )
  if  ct le 0  THEN $
    begin
    print,'no points in lat, lon range'
    return
    endif
  mean_b = mean_b[ix]
  nobs_b = nobs_b[ix]
  wts_b = wts_b[ix]
  out_b = out_b[*, ix]
;
  nsamp_b = total( nobs_b )
  nbin_b = n_elements(mean_b)
  totbin[0] = nbin_b
  totsamp[0] = nsamp_b
  print, '# bins, samples = ', nbin_b, nsamp_b
;
  meanv[0,ipar] = total( double( out_b[0,*] ) ) / total( double( wts_b ) )
  sdv[0,ipar] = total( double( out_b[1,*] ) ) / total( double( wts_b ) ) - $
                    meanv[0,ipar] * meanv[0,ipar]
  if  sdv[0,ipar] gt 0  then  sdv[0,ipar] = sqrt( sdv[0,ipar] ) else $
         sdv[0,ipar] = 0
  print, 'mean, sd found are: ', meanv[0,ipar], sdv[0,ipar]
;
;  next, loop through the test files and compare the parameter
  for icomp = 0, ( ncomp - 1 ) do $
    BEGIN
    sp_base_titl = 'Control set'
    sp_test_titl = filmid[icomp+1] + ' flag on'
    test_f = fil1 + filmid[icomp+1] + fil2
    filebreak, test_f, dir = test_dir, file = test_fex
    cd, test_dir
    mean_t = readl3bin( test_f, params[prm_ix[ipar]], lon, lat, bins_t, nobs_t, wts_t, out_t, nseg )
    cd, start_dir
;
    ix = where( ( lon ge lonrng[0] ) and ( lon le lonrng[1] ) and $
         ( lat ge latrng[0] ) and ( lat le latrng[1] ), ct )
  if  ct le 0  THEN $
    begin
    print,'no points in lat, lon range'
    return
    endif
  mean_t = mean_t[ix]
  nobs_t = nobs_t[ix]
  wts_t = wts_t[ix]
  out_t = out_t[*, ix]
;
;    note the bins and the samples
    nsamp_t = total( nobs_t )
    nbin_t = n_elements(mean_t)
    totbin[icomp+1] = nbin_t
    totsamp[icomp+1] = nsamp_t
    print, filmid[icomp + 1], ', # bins, samples = ', n_elements(mean_t), total( nobs_t )
    print, '#, % decrease in bins', nbin_b - nbin_t, 100. * ( float( nbin_b ) - nbin_t ) / nbin_b
    print, '#, % decrease in samples', nsamp_b - nsamp_t, 100. * ( float( nsamp_b ) - nsamp_t ) / nsamp_b
;
;    mean, sd
    meanv[icomp+1,ipar] = $
      total( double( out_t[0,*] ) ) / total( double( wts_t ) )
    sdv[icomp+1,ipar] = total( double( out_t[0,*] ) * out_t[0,*] ) - $
                    meanv[icomp+1,ipar] * meanv[icomp+1,ipar]
    sdv[icomp+1,ipar] = $
           total( double( out_t[1,*] ) ) / total( double( wts_t ) ) - $
                    meanv[icomp+1,ipar] * meanv[icomp+1,ipar]
    if  sdv[icomp+1,ipar] gt 0  then  $
         sdv[icomp+1,ipar] = sqrt( sdv[icomp+1,ipar] ) else $
         sdv[icomp+1,ipar] = 0
    print, 'mean, sd found are: ', meanv[icomp+1,ipar], sdv[icomp+1,ipar]
    print, 'mean change of ',meanv[icomp+1,ipar] - meanv[0,ipar]
    print, 'sd change of ', sdv[icomp+1,ipar] - sdv[0,ipar]
;
;    do histogram compare
    month = filmid[icomp+1]
    IF  params[prm_ix[ipar]] EQ 'chlor_a'  THEN $
      BEGIN
      ptitle = 'Chlorophyll histograms, ' + month
      pxtitle = sp_base_titl
      pytitle = sp_test_titl
      plt_hst_chl, mean_b, mean_t, ptitle, pxtitle, pytitle, TLUN = lun
      END  $
    ELSE $
      BEGIN
      ptitle = params[prm_ix[ipar]] + ' histograms, ' + month
      pxtitle = sp_base_titl
      pytitle = sp_test_titl
      plt_hst_lin, mean_b, mean_t, params[prm_ix[ipar]], ptitle, pxtitle, $
      pytitle, /EXCL_HIGH_BIN, PLT_RNG = prm_pl_rng[*,prm_ix[ipar]], $
      BIN_SZ = prm_bin_sz[prm_ix[ipar]], TLUN = lun
      END
    ENDFOR
  ENDFOR;
;  finish plots
DEVICE, /CLOSE
SET_PLOT, 'x'
;
CLOSE, lun
FREE_LUN, lun
;
RETURN
END
