pro plt_hst_chl, base, test, ptitle, base_str, test_str, TLUN = tlun
;
;  plt_hst_chl will plot the two histograms of chlorophyll for a base (x) 
;  and a test (y)
;
;  call seq:
;    plt_hst_chl, base, test, ptitle, base_str, test_str
;
;  base - x data (y vs x)
;  test - y data (y vs x)
;  ptitle - plot title
;  base_str, test_str - strings to identify the base and test histograms
;
;  KEYWORDS:
;    TLUN - logical unit to write out to
;
;
write_file = 0
IF  KEYWORD_SET( tlun )  THEN  write_file = 1
;
PRINT, 'Histogram plots - Chlorophyll'
IF  write_file EQ 1  THEN  PRINTF, tlun, 'Histogram plots - Chlorophyll'
;
;  get the histogram arrays of the test and base, use 64000 .001 bins
hmin = 0.001
hmax = 64.
binsiz = .001
npts = (hmax - hmin ) / binsiz + 1
xax=findgen( npts ) * binsiz + hmin
yaxb = HISTOGRAM( base, binsize = binsiz, min = hmin, max = hmax )
yaxt = HISTOGRAM( test, binsize = binsiz, min = hmin, max = hmax )
ymax = MAX( [ yaxb, yaxt ] )
plot,xax,yaxb,linestyle=1, psym = 10, title=ptitle, $
xtitle = 'Chlor-a', ytitle = 'Number', /XLOG, XRANGE=[hmin,hmax], $
YRANGE = [ 0, ymax / .65 ]
oplot, xax,yaxt, psym = 10
;
;  get and add the info on each distribution
npt_b = N_ELEMENTS( base )
npt_t = N_ELEMENTS( test )
mean_b = TOTAL( DOUBLE( base ) ) / npt_b
sd_b = TOTAL( DOUBLE( base ) * DOUBLE( base ) ) / npt_b - $
       mean_b * mean_b
IF  sd_b GT 0  THEN  sd_b = SQRT( sd_b )  ELSE  sd_b = 0
;
res = CONVERT_COORD( [hmin, hmax], [0, ymax / .65], /DATA, /TO_NORMAL )
b_x1 = res[0,0]
b_x2 = res[0,1]
b_y1 = res[1,0]
b_y2 = res[1,1]
ann_x = b_x1 + ( b_x2 - b_x1 ) * .02
ann_y = b_y2 - ( b_y2 - b_y1 ) *.05
ann_dy = ( b_y2 - b_y1 ) *.05
;
str = base_str + ' (dotted line):'
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y, str, /NORMAL, CHARSIZE = .7
;
str = STRING( npt_b, FORMAT = '( "# points: ", i12 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-ann_dy, str, /NORMAL, CHARSIZE = .7
;
str = STRING( mean_b, FORMAT = '( "Mean: ", f9.4 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-2*ann_dy, str, /NORMAL, CHARSIZE = .7
;
str = STRING( sd_b, FORMAT = '( "Std dev: ", f9.4 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-3*ann_dy, str, /NORMAL, CHARSIZE = .7
;
;  try to also do a chi square, first normalize test to base
yaxt_n = float( yaxt ) * npt_b / npt_t
sumval = yaxt_n + yaxb
ixv = where( sumval ne 0, ctv )
if  ctv gt 0  THEN  $
     chi = total( ( yaxt_n[ixv] - yaxb[ixv] )^2 / sumval[ixv] ) $
     ELSE chi = 0.
; ~ idl version:chi = xsq_test( yaxt_n, yaxb )
str = STRING( chi, FORMAT = '( "Chi^2: ", e15.6 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-4*ann_dy, str, /NORMAL, CHARSIZE = .7
;
;  test...
npt = npt_t
mean = TOTAL( DOUBLE( test ) ) / npt
sd = TOTAL( DOUBLE( test ) * DOUBLE( test ) ) / npt - $
       mean * mean
IF  sd GT 0  THEN  sd = SQRT( sd )  ELSE  sd = 0
;
ann_x = b_x1 + ( b_x2 - b_x1 ) * .45
;
str = test_str + ' (solid line):'
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y, str, /NORMAL, CHARSIZE = .7
;
str = STRING( npt, FORMAT = '( "# points: ", i12 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-ann_dy, str, /NORMAL, CHARSIZE = .7
;
str = STRING( mean, FORMAT = '( "Mean: ", f9.4 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-2*ann_dy, str, /NORMAL, CHARSIZE = .7
;
str = STRING( sd, FORMAT = '( "Std dev: ", f9.4 )' )
PRINT, str
IF  write_file EQ 1  THEN  PRINTF, tlun, str
XYOUTS, ann_x, ann_y-3*ann_dy, str, /NORMAL, CHARSIZE = .7
;
; don't have a P value
;str = STRING( chi[1], FORMAT = '( "Chi^2 prob: ", f9.4 )' )
;IF  write_file EQ 1  THEN  PRINTF, tlun, str
;XYOUTS, ann_x, ann_y-4*ann_dy, str, /NORMAL, CHARSIZE = .7
;
return
end
