;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    HISTOGAUSS overlays histogram data with a Gaussian.
;
;NAME:
; HISTOGAUSS
;
;PURPOSE:
; Histograms data and overlays it with a Gaussian. Draws the mean, sigma,
; and number of points on the plot.
;
;CALLING SEQUENCE:
; HISTOGAUSS, SAMPLE, GAUSS_COEFF, XCENTERS, YCENTERS 
;
;INPUT ARGUMENT:
; SAMPLE = Vector to be histogrammed
;
;OUTPUT ARGUMENT:
; A = coefficients of the Gaussian fit: Height, mean, sigma
; XX = the x coordinates of the histogram bins
; YY = the y coordinates of the histogram bins
;
;SUBROUTINE CALLS:
; BIWEIGHT_MEAN, which determines the mean and std. dev.
; AUTOHIST, which draws the histogram
; MED, which calculates a median (called by AUTOHIST)
;
;AUTHOR: H. Freudenreich, STX, 12/89
;        Modified for IDL Version 2, 1/91, HF
;-
PRO HISTOGAUSS,SAMPLE,A,XX,YY     ;IDL Version 2

DATA=SAMPLE

A=FLTARR(3)
N=N_ELEMENTS(DATA)
A(1)=BIWEIGHT_MEAN(DATA,S)
A(2)=S*SQRT(N)
U1=A(1)-5.*A(2)
U2=A(1)+5.*A(2)
Q=WHERE(DATA LT U1)
IF Q(0) GE 0 THEN DATA(Q) = U1
Q=WHERE(DATA GT U2)
IF Q(0) GE 0 THEN DATA(Q) = U2

OLDLINETYPE=!LINETYPE  &  OLDPSYM=!PSYM  &  !PSYM=10  &  !LINETYPE=0
AUTOHIST,DATA,X,Y,XX,YY
;!C=0
;PLOT,X,Y
!PSYM=0 ; &  !LINETYPE=2

M=N_ELEMENTS(X)

W=FLTARR(M)
A(0)=MAX(SMOOTH(Y,5))

Z = EXP(-.5*(X-A(1))^2/A(2)^2 )

A1=.6*A(0)
A2=1.4*A(0)
DA=(A2-A1)/20
YFIT=A1*Z 
K = A1
A0= A1
B1=A1
B2=A2
BEST = AVG( ABS(Y-YFIT) )
FOR I=1,19 DO BEGIN
  K=K+DA
  YFIT=K*Z 
  DEV = ABS( Y-YFIT )
  MAD = AVG(DEV)
  IF( MAD LT BEST )THEN BEGIN
     B1 = K-DA
     B2 = K+DA
     A0 = K
     BEST = MAD
  ENDIF
ENDFOR
IF((B1 GT A1) AND B1 LT A2) THEN BEGIN
   DA = (B2-B1)/20.
   YFIT=B1*Z 
   K = B1
   A0= B1
   BEST = AVG( ABS(Y-YFIT) )
   FOR I=1,19 DO BEGIN
     K=K+DA
     YFIT=K*Z 
     DEV = ABS( Y-YFIT )
     MAD = AVG(DEV)
     IF( MAD LT BEST )THEN BEGIN
        B1 = K-DA
        B2 = K+DA
        A0 = K
        BEST = MAD
     ENDIF
   ENDFOR
ENDIF
A(0) = A0

U=FLTARR(200)
DU=(U2-U1)/199.
U(0)=U1
FOR I=1,199 DO U(I)=U(I-1)+DU
Z=(U-A(1))/A(2)
YFIT=A(0)*EXP(-Z^2/2. )
OPLOT,U,YFIT

!LINETYPE=OLDLINETYPE  &  !PSYM=OLDPSYM

DX=(!cxmax-!cxmin)
DY=(!cymax-!cymin)
Y1=!cymin + 0.90*dy
Y2=!cymin + 0.85*dy
Y3=!cymin + 0.80*dy
X1=!cxmin + 0.70*dx

MEANST=STRING(A(1),'(F9.4)')
SIGST =STRING(A(2),'(F9.4)')
NUM=N_ELEMENTS(DATA)
NUMST = strtrim(string(N),2)

LABEL1='Mean='+meanst
LABEL2='Sigm='+sigst
LABEL3='Npts='+numst 
XYOUTS,x1,y1,LABEL1,size=0.6
XYOUTS,x1,y2,LABEL2,size=0.6
XYOUTS,x1,y3,LABEL3,size=0.6

RETURN
END
