;+
; Project     : SOHO-CDS
;
; Name        : FIX_DATE
;
; Purpose     : Fix date that uses digit month into one with a string month
;
; Category    : utility
;
; Explanation : 
;
; Syntax      : fdate=fix_date(date)
;
; Examples    :
;
; Inputs      : DATE = string date to fix (e.g. '10/02/98')
;
; Opt. Inputs : None
;
; Outputs     : FDATE = fixed date (e.g. '10-feb-98')
;
; Opt. Outputs: None
;
; Keywords    : None
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 26 August 1998, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function fix_date,date

if datatype(date) ne 'STR' then return,''

months=['January','February','March','April','May','June','July','August',$
         'September','October','November','December'] 

ndate=n_elements(date)
new_date=date
for i=0,ndate-1 do begin
 new=str_replace(new_date(i),'/','-')
 temp=str2arr(trim(new),delim='-')
 if n_elements(temp) eq 3 then begin
  mn=trim(temp(1))
  if is_number(mn) and is_number(temp(0)) and is_number(temp(2)) then begin
   val=fix(mn)
   if (val ge 1) and (val le 12) then begin
    mon=months(val-1)
    new_temp=temp & new_temp(1)=mon
    new_date(i)=arr2str(new_temp,delim='-')
   endif
  endif  
 endif
endfor

if n_elements(date) eq 1 then new_date=new_date(0)
return,new_date & end

