;+
; Project     : HESSI
;
; Name        : get_def_times
;
; Purpose     : return default times
;
; Category    : HESSI, GBO, utility
;
; Explanation : If TSTART/TEND are not specified correctly, then
;               return current time and end of current day
;               as useful defaults
;
; Syntax      : IDL> dstart=get_def_times(tstart,tend,dend=dend)
;
; Opt. Inputs : TSTART = start time
;               TEND   = end time: 
;
; Outputs     : DSTART = TSTART or current time if invalid TSTART
;
; Opt. Outputs: None
;
; Keywords    : DEND = TEND or end of current day if invalid TEND
;               Inherits ANYTIM keywords
;               ROUND_TIMES = round start/end to start/end of day
;
; History     : 14-Nov-1999,  D.M. Zarro (SM&A/GSFC),  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function get_def_times,tstart,tend,dend=dend,_extra=extra,$
                       round_times=round_times

; TSTART = start time [def= start of current day]
; TEND   = end time [def = end of current day]
 
err=''
dstart=anytim2utc(tstart,err=err)
secs_day= 86400.d

if err ne '' then begin
 get_utc,dstart 
 dstart.time=0
endif

round_t=keyword_set(round_times)
if round_t then dstart.time=0
dstart=anytim2tai(dstart)    

err=''
dend=anytim2utc(tend,err=err)
if err ne '' then begin
 dend=anytim2utc(dstart)
 dend.time=0
endif

if round_t then begin
 dend.time=0
 dend.mjd=dend.mjd+1
endif

dend=anytim2tai(dend)
if str_format(dend) eq str_format(dstart) then dend=dstart+secs_day

;-- ensure start < end

if (dend lt dstart) then begin
 temp=dend
 dend=dstart & dstart=temp
endif

;-- convert to other requested formats

if datatype(extra) eq 'STC' then dstart=anytim2utc(dstart,_extra=extra)
if datatype(extra) eq 'STC' then dend=anytim2utc(dend,_extra=extra) 

return,dstart & end


