PRO MODIS_LOCATE, SLAT, SLON, LAT, LON, X, Y, MINRANGE=MINRANGE

;+
; PURPOSE:
;    Locate a given lat/lon in a MODIS image.
;
; INPUT:
;    SLAT    Latitude to locate (deg)
;    SLON    Longitude to locate (deg)
;    LAT     Array of MODIS latitude values (deg)
;    LON     Array of MODIS longitude values (deg)
;
; OUTPUT:
;    X       Pixel number closest to the given lat/lon (-1 if not found)
;    Y       Line number closest to the given lat/lon (-1 if not found)
;
; REVISED:
; Liam.Gumley@ssec.wisc.edu
; $Id: modis_locate.pro,v 1.3 2001/02/16 22:03:21 gumley Exp $
;-

;- Check arguments

if n_params() ne 6 then message, 'Usage: MODIS_LOCATE, SLAT, SLON, LAT, LON, X, Y'
if n_elements(slat) eq 0 then message, 'SLAT is undefined'
if n_elements(slon) eq 0 then message, 'SLON is undefined'
if n_elements(lat) eq 0 then message, 'LAT is undefined'
if n_elements(lat) eq 0 then message, 'LON is undefined'
if size(lat, /n_dim) ne 2 then message, 'LAT is not a 2D array'
if size(lon, /n_dim) ne 2 then message, 'LON is not a 2D array'

;- Set default return values
x = -1L
y = -1L
minrange = 1.0e6

;- Screen lat/lon values outside this granule
latmin = min(lat, max=latmax)
lonmin = min(lon, max=lonmax)
if ((slat lt (latmin - 0.1)) or (slat gt (latmax + 0.1)) or $
    (slon lt (lonmin - 0.1)) or (slon gt (lonmax + 0.1))) then return

;- Find array elements close to the requested latitude
result = where(abs(lat - slat) lt 0.1, latcount)
if (latcount lt 1) then return

;- Compute the distance from requested lat/lon to the array elements
compass, slat, slon, lat[result], lon[result], range, azimuth

;- Find the array element closest to the requested lat/lon
minrange = min(range, minindex)

;- Convert the 1D array element index to x/y
dims = size(lat, /dim)
x = result[minindex] mod dims[0]
y = result[minindex] / dims[0]

END
