;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    L1MOSDESTRIPE removes striping effect from mos image files.
;
pro l1mosdestripe,ifile,ofile,m,rgn,getrgn=getrgn

    if (n_elements(getrgn) eq 0) then getrgn = 0

    m    = readl1(ifile,hdr)
    npix = n_elements(m(0).lon)
    
    if (npix ne 384) then begin
        print,'Only full MOS scans can be destriped'
        return
    endif

    cloudmask = reform(m.data(0,*)) * 0.0 + 1.0
    s = where(m.data(7,*) gt 2)
    if (s(0) ne -1) then cloudmask(s) = 0.0

    if (n_elements(rgn) eq 0 or getrgn ne 0) then begin
         rgn    = fltarr(384,8)
         getrgn = 1
    endif

    for i=0,7 do begin
        data        = reform(m.data(i,*))
        if (getrgn ne 0) then begin
            rgn(*,i)    = mos_destripe(data*cloudmask)
        endif
        new_data    = apply_mos_destripe(data,rgn(*,i))
        m.data(i,*) = reform(new_data,1,384,384)
    endfor


    new_hdr = bytarr(hdr.reclen)
    new_hdr(0:3)  = byte(long(hdr.sensorID),0,4)
    new_hdr(4:7)  = byte(long(hdr.reclen  ),0,4)
    new_hdr(8:11) = byte(long(hdr.npix    ),0,4)
    new_hdr(500:500+384*8*4-1) = byte(rgn,0,384*8*4)

    openw,/get_lun,olun,ofile
    writeu,olun,new_hdr
    writeu,olun,m
    free_lun,olun

    return
end
