;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MORDL1HDF reads a mos level1b file.
;
function mordl1hdf, file, time, lon, lat, solz, sola, senz, sena

    nx = 384
    ny = 384
    nb = 13

    acal = fltarr(nb)

    ;
    ; Break-up header info into ID and DESC fields
    ;
    hdf_dfan_getfds,file,hdr,/first
    s = where(hdr eq 10,ns)
    id   = strarr(ns)
    desc = strarr(ns)
    p1 = 0
    for i=0,ns-1 do begin
        p2 = s(i)-1
        desc(i) = strtrim(string(hdr(p1:p2)),2)
        n = strpos(desc(i),';',0)
        desc(i) = strmid(desc(i),0,n)
        p = strpos(desc(i),'=',0)
        id(i)   = strtrim(strmid(desc(i),0,p),2)
        desc(i) = strtrim(strmid(desc(i),p+1,n),2)
        p1 = p2+2
    endfor

    ul = fltarr(4)
    ur = fltarr(4)
    ll = fltarr(4)
    lr = fltarr(4)

    ;
    ; Convert header information to usable format
    ;
    for i=0,ns-1 do begin
        case id(i) of
            'LONG_UL': ul(0) = float(desc(i))
            'LATI_UL': ul(1) = float(desc(i))
            'SUNZ_UL': ul(2) = float(desc(i))
            'SUNA_UL': ul(3) = float(desc(i))
            'LONG_UR': ur(0) = float(desc(i))
            'LATI_UR': ur(1) = float(desc(i))
            'SUNZ_UR': ur(2) = float(desc(i))
            'SUNA_UR': ur(3) = float(desc(i))
            'LONG_LL': ll(0) = float(desc(i))
            'LATI_LL': ll(1) = float(desc(i))
            'SUNZ_LL': ll(2) = float(desc(i))
            'SUNA_LL': ll(3) = float(desc(i))
            'LONG_LR': lr(0) = float(desc(i))
            'LATI_LR': lr(1) = float(desc(i))
            'SUNZ_LR': lr(2) = float(desc(i))
            'SUNA_LR': lr(3) = float(desc(i))
            'BCAL_VAL': begin
                 calstr = desc(i)
                 for ib=0,nb-1 do begin
                     acal(ib) = float(calstr)
                     p = strpos(calstr,' ',0)
                     if (p gt 0) then begin
                         n = strlen(calstr)
                         calstr = strmid(calstr,p+1,n-1)
                     endif
                 endfor
                 end
            'OP_BEG_DATE': begin
                 yr = fix(strmid(desc(i),6,2))
                 mo = fix(strmid(desc(i),3,2))
                 dm = fix(strmid(desc(i),0,2))
                 hr = fix(strmid(desc(i),9,2))
                 mn = fix(strmid(desc(i),12,2))
                 sc = fix(strmid(desc(i),15,2))
                 if (yr lt 50) then $
                     yr = yr + 2000 $
                 else               $
                     yr = yr + 1900
                 begTime = ymdhms2sec(yr,mo,dm,hr,mn,sc)
                 end
            'OP_END_DATE': begin
                 yr = fix(strmid(desc(i),6,2))
                 mo = fix(strmid(desc(i),3,2))
                 dm = fix(strmid(desc(i),0,2))
                 hr = fix(strmid(desc(i),9,2))
                 mn = fix(strmid(desc(i),12,2))
                 sc = fix(strmid(desc(i),15,2))
                 if (yr lt 50) then $
                     yr = yr + 2000 $
                 else               $
                     yr = yr + 1900
                 endTime = ymdhms2sec(yr,mo,dm,hr,mn,sc)
                 end
            'OP_BEG_MS': begMsec = float(desc(i))
            'OP_END_MS': endMsec = float(desc(i))
            else:
        endcase
    endfor

    begTime = begTime + begMsec/1000.D0
    endTime = endTime + endMsec/1000.D0
    time    = begTime + (endTime-begTime)/(ny-1) * findgen(ny)

    print,ul
    print,ur
    print,ll
    print,lr

    x    = (findgen(nx)/(nx-1)) # (fltarr(ny) +1)
    y    = (fltarr(nx) +1)      # (findgen(ny)/(ny-1))
    lon  = bilinear([[ul(0),ur(0)],[ll(0),lr(0)]],x,y)
    lat  = bilinear([[ul(1),ur(1)],[ll(1),lr(1)]],x,y)
    solz = bilinear([[ul(2),ur(2)],[ll(2),lr(2)]],x,y)
    sola = bilinear([[ul(3),ur(3)],[ll(3),lr(3)]],x,y)

    s = where(lon gt  180)
    if (s(0) ne -1) then lon(s) = lon(s)-360.
    s = where(lon lt -180)
    if (s(0) ne -1) then lon(s) = lon(s)+360.

    ;
    ; According to T. Walzel of MOS/DLR, the solar azimuth stored in the
    ; L1B file is actually solar hour angle, so we adjust it here.
    ;
;    r     = !pi/180
;    omega = sola
;    delta = acos((cos(solz*r)-sin(lat*r))/(cos(lat*r)*cos(omega*r)-sin(lat*r)))
;    sola  = acos((sin(delta)-sin(lat*r)*cos(solz*r))/(cos(lat*r)*sin(solz*r)))

    ;
    ; No sensor geometry is available.  Assume zenith is zero at center, 7-deg at
    ; edge.  Azimuth is 90-deg relative to solar azimuth.
    ;
    senz = abs( -7.0 +  x * 14.0 )
    sena = (sola + 270.0) mod 360.0

    data  = rd_sds(file,'Data-Set-4')
    if (data(0) eq -1) then begin
        data  = rd_sds(file,'Data-Set-6'); need this for day 267 file
    endif

    image = fltarr(nx,ny,8)
    bands = [0,1,2,3,4,7,8,10]
    for i=0,7 do begin
       band = bands(i)
       ibnd = indgen(384)*14 + band
       image(*,*,i) = data(*,ibnd) * acal(band)
    endfor

    return, image
end

