;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    EPHPARMS calculates ephemeris parameters.
;
;  This subroutine computes ephemeris parameters used by other Mission
;  Operations routines:  the solar mean longitude and mean anomaly, and
;  the lunar mean longitude and mean ascending node.  It uses the model
;  referenced in The Astronomical Almanac for 1984, Section S 
;  (Supplement) and documented for the SeaWiFS Project in "Constants
;  and Parameters for SeaWiFS Mission Operations", in TBD.  These
;  parameters are used to compute the solar longitude and the nutation
;  in longitude and obliquity.
;
;	implicit real*8 (a-h,o-z)
;	radeg = 180.d0/3.14159265359d0
pro ephparms,t,xls,gs,xlm,omega

;  Sun Mean Longitude 		
	xls = 280.46592d0 + 0.9856473516d0*t
	xls = xls mod 360.d0
 
;  Sun Mean Anomaly		
	gs = 357.52772d0 + 0.9856002831d0*t 
	gs = gs mod 360.d0

;  Moon Mean Longitude		
	xlm = 218.31643d0 + 13.17639648d0*t 
	xlm = xlm mod 360.d0

;  Ascending Node of Moon's Mean Orbit 	
	omega = 125.04452d0 - 0.0529537648d0*t 
	omega = omega mod 360.d0
	
	return
	end
