;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    NUTATE computes the nutation in longitude and the obliquity of the
;    ecliptic corrected for nutation.
;
;  This subroutine computes the nutation in longitude and the obliquity
;  of the ecliptic corrected for nutation.  It uses the model referenced
;  in The Astronomical Almanac for 1984, Section S (Supplement) and 
;  documented for the SeaWiFS Project in "Constants and Parameters for 
;  SeaWiFS Mission Operations", in TBD.  These parameters are used to 
;  compute the apparent time correction to the Greenwich Hour Angle and 
;  for the calculation of the geocentric Sun vector.  The input 
;  ephemeris parameters are computed using subroutine ephparms.  Terms 
;  are included to 0.1 arcsecond.
;
;	implicit real*8 (a-h,o-z)
;	radeg = 180.d0/3.14159265359d0
pro nutate,t,xls,gs,xlm,omega,dpsi,eps

	
;  Nutation in Longitude
	dpsi = - 17.1996*sin(omega/!radeg) 	$
     	 	+ 0.2062*sin(2.*omega/!radeg)	$
     	     	- 1.3187*sin(2.*xls/!radeg) 	$
     		+ 0.1426*sin(gs/!radeg) 	$
     		- 0.2274*sin(2.*xlm/!radeg)
	
;  Mean Obliquity of the Ecliptic	
	epsm = 23.439291d0 - 3.560d-7*t 

;  Nutation in Obliquity 
	deps = 9.2025*cos(omega/!radeg) + 0.5736*cos(2.*xls/!radeg)

;  True Obliquity of the Ecliptic 
	eps = epsm + deps/3600.d0

	dpsi = dpsi/3600.d0
        return
	end

