;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SUN2000 computes the sun vector in geocentric inertial (equatorial)
;    coordinates.
;
;  This subroutine computes the Sun vector in geocentric inertial 
;  (equatorial) coodinates.  It uses the model referenced in The 
;  Astronomical Almanac for 1984, Section S (Supplement) and documented
;  for the SeaWiFS Project in "Constants and Parameters for SeaWiFS
;  Mission Operations", in TBD.  The accuracy of the Sun vector is
;  approximately 0.1 arcminute.
;
pro sun2000,iyr,iday,sec,sun,rs
;	implicit real*8 (a-h,o-z)
;	real*4 sun(3),rs
	xk=0.0056932		;Constant of aberration 
	imon=1
;	common nutcm,dpsi,eps,nutime
;	radeg = 180.d0/3.14159265359d0

;   Compute floating point days since Jan 1.5, 2000 
;    Note that the Julian day starts at noon on the specified date
	jd,iyr,imon,iday,jday
	t = jday - 2451545.0d0 + (sec-43200.d0)/86400.d0
	n = n_elements(t)
	sun=fltarr(3,n)

;  Compute solar ephemeris parameters
	ephparms,t,xls,gs,xlm,omega

;  Check if need to compute nutation corrections for this day
;	nt = t
;	if (nt ne nutime) then begin
;	  nutime = nt
	  nutate,t,xls,gs,xlm,omega,dpsi,eps
;	endif

;  Compute planet mean anomalies
;   Venus Mean Anomaly 	
	g2 = 50.40828 + 1.60213022*t 	
	g2 = g2 mod 360.d0

;   Mars Mean Anomaly 		
	g4 = 19.38816 + 0.52402078*t 	
	g4 = g4 mod 360.d0

;  Jupiter Mean Anomaly 
	g5 = 20.35116 + 0.08309121*t 	
	g5 = g5 mod 360.d0

;  Compute solar distance (AU)
	rs = 1.00014-0.01671*cos(gs/!radeg)-0.00014*cos(2.*gs/!radeg)

;  Compute Geometric Solar Longitude 
	dls = 	(6893. - 4.6543463D-4*t)*sin(gs/!radeg) $
     		+ 72.*sin(2.*gs/!radeg) 		$
     		- 7.*cos((gs - g5)/!radeg) 		$
     		+ 6.*sin((xlm - xls)/!radeg) 		$ 
     		+ 5.*sin((4.*gs - 8.*g4 + 3.*g5)/!radeg) $
     		- 5.*cos((2.*gs - 2.*g2)/!radeg) 	$
     		- 4.*sin((gs - g2)/!radeg) 		$
     		+ 4.*cos((4.*gs - 8.*g4 + 3.*g5)/!radeg) $
     		+ 3.*sin((2.*gs - 2.*g2)/!radeg) 	$
     		- 3.*sin(g5/!radeg) 			$
     		- 3.*sin((2.*gs - 2.*g5)/!radeg)

	xlsg = xls + dls/3600.d0

;  Compute Apparent Solar Longitude; includes corrections for nutation 
;   in longitude and velocity aberration
	xlsa = xlsg + dpsi - xk/rs

;   Compute unit Sun vector 
	sun(0,*) = cos(xlsa/!radeg)
	sun(1,*) = sin(xlsa/!radeg)*cos(eps/!radeg)
	sun(2,*) = sin(xlsa/!radeg)*sin(eps/!radeg)

	return
	end

