;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    OCTLM2NAV returns the navigation information from a telemetry stream.
;
function octlm2nav,tlm

n    = n_elements(tlm)/120

nav  = replicate({ epoch : 0.D0, $
                   pos   : fltarr(3), $
                   vel   : fltarr(3), $
                   att   : fltarr(3) }, n )

epoch = lonarr(n)
orbit = intarr(n)
pos   = lonarr(3,n)
vel   = lonarr(3,n)
att   = lonarr(3,n)
rec   = tlm(74:111,*)

for i=0,n-1 do begin
    att(0,i) = (rec( 0,i) and 'FF'X)*2L^8   + $
               (rec( 1,i) and 'FF'X)     
    att(1,i) = (rec( 2,i) and 'FF'X)*2L^8   + $
               (rec( 3,i) and 'FF'X)     
    att(2,i) = (rec( 4,i) and 'FF'X)*2L^8   + $
               (rec( 5,i) and 'FF'X)     
    epoch(i) = (rec(12,i) and 'FF'X)*2L^24  + $
               (rec(13,i) and 'FF'X)*2L^16  + $
               (rec(14,i) and 'FF'X)*2L^8   + $
               (rec(15,i) and 'FF'X)
    pos(0,i) = (rec(16,i) and 'FF'X)*2L^16  + $
               (rec(17,i) and 'FF'X)*2L^8   + $
               (rec(18,i) and 'FF'X)     
    pos(1,i) = (rec(19,i) and 'FF'X)*2L^16  + $
               (rec(20,i) and 'FF'X)*2L^8   + $
               (rec(21,i) and 'FF'X)     
    pos(2,i) = (rec(22,i) and 'FF'X)*2L^16  + $
               (rec(23,i) and 'FF'X)*2L^8   + $
               (rec(24,i) and 'FF'X)     
    vel(0,i) = (rec(25,i) and 'FF'X)*2L^16  + $
               (rec(26,i) and 'FF'X)*2L^8   + $
               (rec(27,i) and 'FF'X)     
    vel(1,i) = (rec(28,i) and 'FF'X)*2L^16  + $
               (rec(29,i) and 'FF'X)*2L^8   + $
               (rec(30,i) and 'FF'X)     
    vel(2,i) = (rec(31,i) and 'FF'X)*2L^16  + $
               (rec(32,i) and 'FF'X)*2L^8   + $
               (rec(33,i) and 'FF'X)     
    orbit(i) = (rec(34,i) and '03'X)*2^8    + $
               (rec(35,i) and 'FF'X)
endfor

;
; Interpret epoch time
;
year  = (epoch and 'F0000000'XL)/2L^28 + 1990
month = (epoch and '0F000000'XL)/2L^24
day   = (epoch and '00F80000'XL)/2L^19
hour  = (epoch and '0007C000'XL)/2L^14
min   = (epoch and '00003F00'XL)/2L^8
sec   = (epoch and '000000FC'XL)/2L^2
nav.epoch = ymdhms2sec(year,month,day,hour,min,sec)

;
; Sign extend for two's complement negative numbers
;
s = where((pos and '00800000'X) gt 0,ns)
if (ns gt 0) then $
    pos(s) = (pos(s) xor 'FF000000'X)
s = where((vel and '00800000'X) gt 0,ns)
if (ns gt 0) then $
    vel(s) = (vel(s) xor 'FF000000'X)
s = where((att and '00008000'X) gt 0,ns)
if (ns gt 0) then $
    att(s) = (att(s) xor 'FFFF0000'X)

;
; Convert to physical units
;
nav.pos = float(pos)/1E3     ; km
nav.vel = float(vel)/1E6     ; km/sec
nav.att = float(att)/1E3     ; deg

return, nav
end
