;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    OCTLM2TEMP returns the temperature value from a telemetry stream.
;
function thermconva, cnts, cal

    a = [3.354e-3,3.1308e-4,7.4503e-7]
    X = 2.0*float(cnts)/cal 
    T = 1.0/(a(0) + a(1)*alog(X) + a(2)*(alog(X))^2) - 273.15

    return, T
end

function thermconvc, cnts, cal

    a = [1.099775e2,-3.961712e0,-1.792193e-2,0,0]
    V = float(cnts)/cal 
    T = (((a(4)*V + a(3))*V + a(2)*V) + a(1)*V) + a(0) - 273.15

    return, T
end

function octlm2temp,tlm

    n    = n_elements(tlm)/120
    temp = fltarr(4,n)

    cal       = (tlm(73,*) and '3FF'X)                  ; thermistor cal
    temp(0,*) = thermconva((tlm(26,*) and '3FF'X), cal)	; OPT Cover
    temp(1,*) = thermconvc((tlm(27,*) and '3FF'X), cal)	; IR Detector
    temp(2,*) = thermconva((tlm(31,*) and '3FF'X), cal)	; SRU 1
    temp(3,*) = thermconva((tlm(32,*) and '3FF'X), cal)	; SRU 2

    ; Note that OCTS L1A documentation suggests SRU 1, 2 are switched
    ; but data does not show that

return,temp
end
