;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    OCTLM2TILT extracts tilt information from octs telemetry data.
;
;------------------------------------------------------------
;
; tilt bit interpretation
;   100 = -20
;   010 =   0
;   001 = +20
;------------------------------------------------------------

function octlm2tilt,tlm,atilt

n = n_elements(tlm)/120

atilt = fltarr(n)

rec = tlm([1,5],*) and 'FF'X

tbit  = ((reform(rec(0,*)) and '70'X)/2^4)
ctilt = tbit * 0 + (tbit eq 1)*20 - (tbit eq 4)*20

;
; Get relevant word for actual tilt
;
tilt   = float(ctilt(0))
wordID = (reform(rec(1,*)) and 'C0'X)/64
word   = (reform(rec(1,*)) and '3F'X)

nstart = 0
while ( wordID(nstart) ne 0 ) do begin
    tilt = float(ctilt(0))
    atilt(nstart) = tilt
    nstart = nstart + 1
endwhile

for i=nstart,n-1 do begin

    case wordID(i) of
      0 : begin
          cnt   = 1
          word1 = word(i)
          end
      1 : begin
          if (cnt eq 1) then begin
              cnt   = 2
              word2 = word(i)
          endif
          end
      2 : begin
          if (cnt eq 2) then begin
              cnt   = 3
              word3 = word(i)
          endif
          end
      3 : begin
          if (cnt eq 3) then begin
              cnt   = 4
          endif
          end
    endcase

    if (cnt eq 4) then begin
        tilt = 0.001373*(float(word1)*2.^12 + float(word2)*2.^6 + float(word3))
        if (tilt gt 180.0) then 	$
            tilt = 2*(tilt - 360.) 	$
        else				$
            tilt = 2*tilt
        print,tilt
    endif

    if (i ge 3) then $
        atilt(i-3:i) = tilt

endfor

return,ctilt
end
