;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    CHANGEL0YEAR changes the year associated with a level 0 file.
;
;------------------------------------------------------------
;------------------------------------------------------------
function l0hdr_str, nstruct

    common l0hdr_str_cmn, defined

;    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { l0hdr_struct	     		, $  ; Structure Name

               id:		bytarr(5)	, $  ;
               type:		0B		, $  ;
               fill1:		bytarr(4)	, $  ;
               tle:		bytarr(150)	, $  ;
               fill2:		bytarr(172)	, $  ;
               start_time:	0L	        , $  ;
               stop_time:	0L      	, $  ;
               numlines:	0L		, $  ;
               fill3:		bytarr(168)	}    ;

       defined = 1 

;    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { l0hdr_struct }, nstruct )
end


;------------------------------------------------------------
;------------------------------------------------------------
function ttag2day, ttag

    s = size(ttag)
    n = s(1)
    if (s(0) eq 2) then $
        nrec = s(2)     $
    else                $
        nrec = 1

    if (n ne 4) then begin
        print,'Invalid Time-Tag field',/info
        return,-1
    endif

    day = long(nrec)
 
    for i=0L, nrec-1 do begin

        daycnt = long(ttag(0,i))
        daycnt = ( ishft(daycnt,3) or ishft(ttag(1,i),-7) )
        
        day(i) = daycnt

    endfor

    if (nrec eq 1) then day = day(0)

    return, day

end        



;------------------------------------------------------------
;------------------------------------------------------------
function scid2mnfnum, scid

    s = size(scid)
    
    if (s(1) ne 2) then begin
        print,'Not a valid spacecraft ID tag'
        return,-1
    endif

    case ( s(0) ) of
      1 : nrec = 1
      2 : nrec = s(2)
      else : begin
          print,'Not a valid spacecraft ID tag'
          return,-1
      endelse
    endcase

    word1 = reform(scid(0,*))
    s1    = intarr(nrec) - 7
    mnf   = byte( ishft( (word1 and '180'XL), s1 ) )

    if (nrec eq 1) then mnf = mnf(0)

    return, mnf
end



;------------------------------------------------------------
;------------------------------------------------------------
pro changel0year,ifile,ofile,delyear

    if (n_elements(delyear) eq 0) then delyear=2L

    numdays = delyear*365L

    hdrlen = 512
    reclen = 21504

    openr,/get_lun,ilun,ifile
    openw,/get_lun,olun,ofile
   
    hdr  = l0hdr_str(1)
    rec  = bytarr(reclen)
    r    = assoc(ilun,bytarr(reclen),hdrlen)
;    indx = getl0indx(ifile)

    readu,ilun,hdr
    print,s2zulu(unix2sec(hdr.start_time))
    hdr.start_time = hdr.start_time + numdays*86400L
    hdr.stop_time  = hdr.stop_time  + numdays*86400L
    print,s2zulu(unix2sec(hdr.start_time))
    writeu,olun,hdr

    f = fstat(ilun)
    nrec = (f.size-hdrlen)/reclen

    mask1 = 2^7-1
    mask2 = 2^3-1

    for i=0,nrec-1 do begin

        rec  = r(i)        

        ttag = fix(rec(7:14),0,4)
        day  = ttag2day(ttag) + long(numdays)
        ttag(0) = ishft(day,-3)
        ttag(1) = (ttag(1) and mask1) or ishft(day and mask2,7)
        rec(7:14) = byte(ttag,0,8)

        scid = fix(rec(3: 6),0,2)
        mnfnum = scid2mnfnum(scid)
        if (mnfnum eq 1) then begin
            gpsyear = fix(rec(39:40),0,1) + fix(delyear)
            rec(39:40) = byte(gpsyear,0,2)
        endif

        writeu,olun,rec

    endfor

    free_lun,ilun
    free_lun,olun

    return
end
        
        
