;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    CHKTILT checks the tilt values.
;
pro chktilt, tlm, tilt, sec, noplot=noplot

    gacID    = 15
    lacID    = 0
    have_gac = 0
    have_lac = 0

    n     = n_elements(tlm)
    nscan = n*5L

    zstart = ttag2zulu(tlm(0).time)
    zstop  = ttag2zulu(tlm(n-1).time)
    ystart = strmid(zstart,0,2)
    ystop  = strmid(zstart,0,2)
    dstart = strmid(zstart,2,3)
    dstop  = strmid(zstop, 2,3)
    sstart = ttag2sec(tlm(0).time)
    sstop  = ttag2sec(tlm(n-1).time)

    type = scid2mnftype(tlm.scid)
    sgac = where(type eq gacID)
    slac = where(type eq lacID)

    if (sgac(0) ne -1) then begin

        have_gac = 1

        gac_tilt = reform( instlm2tilt( tlm(sgac).instlm ), nscan)
        gac_sec  = mnfsec2gscansec( ttag2sec( tlm(sgac).time ) )
        ;
        ; Only the 1st and 3rd scans contain inst tilt
        ; 
        s = where( (lindgen(nscan)+1) mod 3 ne 2)
        gac_tilt = gac_tilt(s)
        gac_sec  = gac_sec(s)

    endif

    if (slac(0) ne -1) then begin

        have_lac = 1

        lac_tilt = instlm2tilt(tlm(slac).instlm)
        lac_sec  = ttag2sec(tlm(slac).time)

    endif

    if (have_gac and have_lac) then begin
        sec  = [gac_sec,lac_sec]
        tilt = [gac_tilt,lac_tilt]
        s    = sort(sec)
        sec  = sec(s)
        tilt = tilt(s)
    endif else if (have_gac) then begin
        sec  = gac_sec
        tilt = gac_tilt
    endif else if (have_lac) then begin
        sec  = lac_sec
        tilt = lac_tilt
    endif

    if (not keyword_set(noplot)) then begin

        s = where(tilt ne -128)
        segplot,sec(s)-sec(0),tilt(s),4.,yr=[-40,40], $
            title  = 'Instrument Tilt Based on INSTLM Tilt Bits', $
            xtitle = 'Seconds from '+zstart, ytitle = 'Tilt (deg)'
        oplot,sec(s)-sec(0),tilt(s),line=1

        s = where(tilt eq -128,ns)
        m = fltarr(ns)+30
        !p.thick = 5
        osegplot,sec(s)-sec(0),m,4,line=0
        !p.thick = 0

        orig_date, 'BA Franz'

    endif

    return
end


