;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    FDR1_STR creates data structure to store fdr1 state of health
;    telemetry data.
;
;========================================================================
; Name: 
;	fdr1_str - creates data structure to store fdr1 SOH telemetry data
;
; Synopsis:
;	fdr1 = fdr1_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	fdr1	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function fdr1_str, nstruct

    common fdr1_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { fdr1_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
;               task_status: 	        0B	, $  ;
;               task_error:		0B	, $  ;
               reserved_1:		0	, $  ;
               reserved_2:		0	, $  ;
               reserved_3:		0	, $  ;
               status:			0	, $  ;
               temperature:		0	, $  ;
               p5_vdc:			0	, $  ;
               p12_vdc:			0	, $  ;
               n12_vdc:			0	, $  ;
               active_ctl:		0	, $  ;
               avail_memory:		0L	, $  ;
               system_error_code:	0	, $  ;
               dram_pwr_stat:		0	, $  ;
               dram_mapping_stat:	0	, $  ;
               current_scrub_delay:	0L	, $  ;
               test_word:		0	, $  ;
               system_error_count:	0	, $  ;
               addr_at_except:		0L	, $  ;
               recent_rx_err_1:		0	, $  ;
               rx_err_count_1:		0	, $  ;
               recent_tx_err_1:		0	, $  ;
               tx_err_count_1:		0	, $  ;
               usage_err_1:		0	, $  ;
               usage_err_count_1:	0	, $  ;
               recent_rx_err_2:		0	, $  ;
               rx_err_count_2:		0	, $  ;
               recent_tx_err_2:		0	, $  ;
               tx_err_count_2:		0	, $  ;
               usage_err_2:		0	, $  ;
               usage_err_count_2:	0	, $  ;
               recent_rx_err_3:		0	, $  ;
               rx_err_count_3:		0	, $  ;
               recent_tx_err_3:		0	, $  ;
               tx_err_count_3:		0	, $  ;
               usage_err_3:		0	, $  ;
               usage_err_count_3:	0	, $  ;
               tot_dram_sbe:		0L	, $  ;
               tot_dram_dbe:		0L	, $  ;
               tot_sram_sbe:		0L	, $  ;
               tot_sram_dbe:		0L	, $  ;
               spare_4a:		0B	, $  ;
               spare_4:			0B	, $  ;
               num_good_slices:		0	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { fdr1_struct }, nstruct )
end
