;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    GETL0IMAGE returns a level 0 image.
;
function getl0image,infile,zstart,zstop,indx=indx,type=type,time=ttag

    ndet = 8

    if (not filefound(infile)) then begin
        message,'File not found: '+infile,/info
        return,-1
    endif

    if (n_elements(indx) eq 0) then $
        indx   = getl0indx(infile)

    if (n_elements(type) eq 0) then begin
        type = 'LAC'
        if (strpos(infile,'GAC') ne -1) then type='GAC'
    endif else begin
        type = strupcase(type)
    endelse
    if (type eq 'HRPT') then type='LAC'

    if (n_elements(zstart) eq 0) then zstart=""
    if (n_elements(zstop)  eq 0) then zstop =""

    s = where(indx.type eq typeconv(type,/id))
    if (zstart eq "") then zstart=s2zulu(min(indx(s).time))
    if (zstop  eq "") then zstop =s2zulu(max(indx(s).time))

    recs = getl0recs(infile,zstart(0),zstop(0),indx=indx,type=type)
    ttag = fix(recs(7:14,*),0,4,n_elements(recs(0,*)))
    nrec = n_elements(recs)/21504L

    case (type) of 
        'LAC'  : begin
                 nx=1285
                 ny=nrec
                 end
        'GAC'  : begin
                 nx= 248
                 ny=nrec*5L
                 end
        'HRPT' : begin
                 nx=1285
                 ny=nrec
                 end
    endcase
        
    map = intarr(nx,ny,ndet)

    for det=0,ndet-1 do begin

        case (type) of 
            'LAC'  : map(*,*,det) = getlacimage( recs, det )
            'GAC'  : map(*,*,det) = getgacimage( recs, det )
            'HRPT' : map(*,*,det) = getlacimage( recs, det )
        endcase
        
    endfor

    return,map

end


