;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    GETSCH reuturns the seawifs command schedule over a time range in a
;    structured array.
;
;-------------------------------------------------------------------------
; Function getsch
;
; Returns the Seawifs command schedule over the specified time range in
; a structured array.
;
; Written by: BA Franz, GSC, 5 March 96
;-------------------------------------------------------------------------
function getsch,zstart,zstop,srec

    path = '/u6/data/sch/'
 
    sec1 = z2sec(zstart)
    sec2 = z2sec(zstop)
    nday = fix((sec2-sec1)/3600./24.) + 2

    year = fix(strmid(zstart(0),0,2))
    day  = fix(strmid(zstart(0),2,3))

    for i=0,nday-1 do begin

        case 1 of
            year ge 10 : y = strtrim(string(year),2) 
            year lt 10 : y = '0'+strtrim(string(year),2) 
        endcase

        case 1 of
            day lt 10  : d = '00'+strtrim(string(day),2)
            day lt 100 : d = '0'+strtrim(string(day),2)
            else       : d = strtrim(string(day),2)
        endcase 

        file = path+'sch'+d+y+'.dat'
        file = findfile(file) & file=file(0)
        if (file ne '') then begin

            spawn,'cat '+file, sch
   
            i1 = 2
            i2 = where(strmid(sch,1,3) eq 'End') & i2 = i2(0) - 1

            case (n_elements(sched)) of
                0 : sched = sch(i1:i2)
             else : sched = [sched,sch(i1:i2)]
            endcase
        
            nextday, year, day

        endif

    endfor
        
    nrec = n_elements(sched)
    
    if (nrec ne 0) then begin

        srec = sch_str(nrec)

        srec.name   = strtrim(strlowcase(strmid(sched,0,20)),2)    
        srec.year   = fix(strmid(sched,32,4))
        srec.day    = fix(strmid(sched,38,3))
        srec.sec    = long(strmid(sched,43,5))
        srec.orbnum = long(strmid(sched,50,5))
        srec.lon    = float(strmid(sched,56,7))
        srec.lat    = float(strmid(sched,63,7))

    endif else begin

        message,'No schedules found.',/info

    endelse

    return, nrec
end



