;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    GHM_STR creates a data structure to store ghm soh telemetry data.
;
;========================================================================
; Name: 
;	ghm_str - creates data structure to store ghm SOH telemetry data
;
; Synopsis:
;	ghm = ghm_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	ghm	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function ghm_str, nstruct

    common ghm_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { ghm_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ; 2
               task_error:		0B	, $  ; 3
               tlm_collect_years:	0B	, $  ; 4
               tlm_collect_months:	0B	, $  ; 5
               tlm_collect_days:	0B	, $  ; 6
               tlm_collect_hours:	0B	, $  ; 7
               tlm_collect_min:		0B	, $  ; 8
               tlm_collect_sec:		0B	, $  ; 9
               aux1:			0	, $  ; 10
               aux2:			0	, $  ; 12
               default_sep_timer:	0	, $  ; 14
               status_flags:		0	, $  ; 16
               state:		    bytarr(2)	, $  ; 18
               gim_error_status:	0	, $  ; 20
               scm_status:		0	, $  ; 22
               scm_error_status:	0	, $  ; 24
               psm_status:		0	, $  ; 26
               psm_error_status:	0	, $  ; 28
               cb_status:	    bytarr(4)	, $  ; 30
               cb_fault_recov:	    bytarr(4)	, $  ; 34
               cb_exec_status:	    bytarr(4)	, $  ; 38
               boot_counter:		0B	, $  ; 42
               boot_version:		0B	, $  ; 43
               fill:		    bytarr(60)	, $  ; 44
               spare_a:			0L	, $  ; 104
               last_boot_years:		0B	, $  ; 108
               last_boot_months:	0B	, $  ; 109
               last_boot_days:		0B	, $  ;
               last_boot_hours:		0B	, $  ;
               last_boot_min:		0B	, $  ;
               last_boot_sec:		0B	, $  ;
               tlm_crc:			0	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { ghm_struct }, nstruct )
end
