;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    GSC_STR creates a data structure to store gsc soh telemetry data.
;
;========================================================================
; Name: 
;	gsc_str - creates data structure to store gsc SOH telemetry data
;
; Synopsis:
;	gsc = gsc_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	gsc	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function gsc_str, nstruct

    common gsc_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { gsc_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ;
               task_error:		0B	, $  ;
               schd_in_use:	0B	, $  ;
               last_schd_valid:	0B	, $  ;
               pending_schd_valid:	0B	, $  ;
               normal_schd_valid:	0B	, $  ;
               safe_haven_schd_valid:	0B	, $  ;
               cap_carry_schd_valid:	0B	, $  ;
               separation_schd_valid:	0B	, $  ;
               spare_schd_valid:	0B	, $  ;
               num_schd_cmds:		0	, $  ;
               schd_first_uniq_id:	0L	, $  ;
               schd_last_uniq_id:	0L	, $  ;
               num_pending_cmds:	0	, $  ;
               pend_first_uniq_id:	0L	, $  ;
               pend_last_uniq_id:	0L	, $  ;
               pend_array_full_count:	0B	, $  ;
               pend_array_not_emptied:	0B	, $  ;
               auto_commit_error:	0B	, $  ;
               commit_addr_error:	0B	, $  ;
               halt_schd_error:		0B	, $  ;
               restart_schd_error:	0B	, $  ;
               use_schd_error:		0B	, $  ;
               purge_schd_error:	0B	, $  ;
               enable_error:		0B	, $  ;
               expired_cmd_count:	0B	, $  ;
               corrupted_cmd_count:	0B	, $  ;
               corrupted_schd_count:	0B	, $  ;
               next_cmd_exec_year:	0B	, $  ;
               next_cmd_exec_month:	0B	, $  ;
               next_cmd_exec_day:	0B	, $  ;
               next_cmd_exec_hour:	0B	, $  ;
               next_cmd_exec_minute:	0B	, $  ;
               next_cmd_exec_seconds:	0B	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { gsc_struct }, nstruct )
end
