;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    GUA_STR creates a data structure to store gua soh telemetry data.
;
;========================================================================
; Name: 
;	gua_str - creates data structure to store gua SOH telemetry data
;
; Synopsis:
;	gua = gua_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	gua	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function gua_str, nstruct

    common gua_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { gua_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ;
               task_error:		0B	, $  ;
               fill:                 bytarr(62)	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { gua_struct }, nstruct )
end
