;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    INSTLM2TILT extracts tilt bit information from instrument telemetry
;    packets.
;
;--------------------------------------------------------------------
; Func INSTLM2TILT
;
; Extracts tilt bit info from instrument telemetry packets.  Returns
; tilt array as -20, 0, 20, or -128 (moving).
;
; Handles (44xn) or (44x5xn) formats, returning (n) or (5xn) tilt
; arrays.  Can not distinguish between inst and ancillary, however.
;
; Written By: BA Franz, GSC, 29 Feb 96
;--------------------------------------------------------------------
function instlm2tilt, instlm, tbits

    n1 = 44
    sz = size(instlm)

    if (sz(1) ne n1) then begin
        message,'Invalid Instrument Telemetry Format',/info
        return,-1
    endif

    case sz(0) of
        1 : begin
            need_reform = 0
            nrec = 1
            end
        2 : begin
            need_reform = 0
            nrec = sz(2)
            end
        3 : begin
            need_reform = 1
            n2   = sz(2)
            n3   = sz(3)
            nrec = n2 * n3
            end
     else : begin
            message,'Invalid Inst. Telemetry Format',/info
            return,-1
            end
    endcase


    if (need_reform) then $
        instlm = reform(instlm,n1,nrec)
        

;    word1 = reform(instlm(5,*))
;    word2 = reform(instlm(6,*))
;    tbits = ishft((word1 and 1),2) + ishft((word2 and 'C0'XL),-6) 
;    tilt  = (fix(tbits eq 5) - fix(tbits eq 6))*20 - fix(tbits eq 7)*128
;
;    s = where(tbits eq 2)
;    if (s(0) ne -1) then tilt(s) = -16000.

    inst  = unpack_instlm(instlm)
    tbits = inst.tilt_nadir_aligned * 4 + $
            inst.tilt_aft_aligned   * 2 + $
            inst.tilt_fwd_aligned   * 1
    tilt  = (fix(tbits eq 5) - fix(tbits eq 6))*20 - fix(tbits eq 7)*128


    if (need_reform) then $
        tilt = reform(tilt,n2,n3)
    
    return, tilt
end

