;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MSG2SOHSUB extracts seawifs state of health subfunction messages from
;    a byte array of s/c messages.
;
;-----------------------------------------------------------------
; msg2sohsub - extract seawifs SOH subfunction messages from a byte 
;	       array of S/C messages. 
;
; Synopsis:
;     subrecs = msg2sohsub( msgs, subname )
;
;     msgs	- SOH messages in S/C message format, stored as
;		  byte array 1034 x n.
;     subname	- SOH subsystem name (e.g., 'SGA', 'SAA', etc)
;     subrecs	- structured array of subsystem messages, broken-
;		  down by telemetry point.
;
; Written By:
;     B. A. Franz, General Sciences Corp., 7/97
;
;
;-----------------------------------------------------------------
function msg2sohsub, msg, subname

    recs      = -1
    nrec      = n_elements(msg(0,*))
    addr_list = fix(msg(14:15,*),0,nrec)
    addr_list = swap_endian(addr_list,/swap_if_little_endian)
    addr_want = getsohinfo( name=subname,/getaddr )

    if (addr_want ne -1) then begin
        s = where(addr_list eq addr_want, n)
        if (n gt 0) then begin
            recs = str_remap(msg(*,s), subname+'_str')
        endif
    endif

    return, recs
end

