;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    PFA_STR creats a data structure to store pfa state of health telemetry
;    data.
;
;========================================================================
; Name: 
;	pfa_str - creates data structure to store pfa SOH telemetry data
;
; Synopsis:
;	pfa = pfa_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	pfa	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function pfa_str, nstruct

    common pfa_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { pfa_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ; 
               frame_header:	     bytarr(8)	, $  ; 
               length:			0	, $  ; 
               dest_addr:		0	, $  ; 
               source_addr:		0	, $  ; 
               control:			0B	, $  ; 
               sequence:		0B	, $  ; 
               func:			0B	, $  ; 
               subfunc:			0B	, $  ; 
               task_status: 	        0B	, $  ; 2
               task_error:		0B	, $  ; 3
               tlm_collect_time:	0L	, $  ; 4
               sib_6hz_event_count:	0L	, $  ; 8
               timeout_event_count:	0	, $  ; 12
               reset_event_count:	0	, $  ; 14
               message_event_count:	0	, $  ; 16
               fdr1_on_off:		0	, $  ; 18
               fdr2_on_off:		0	, $  ; 20
               lac_record_state:	0	, $  ; 22
               curr_lac_partition:	0	, $  ; 24
               lac_start_rec_addr:	0L	, $  ; 26
               lac_frames_to_record:	0L	, $  ; 30
               wrap_lac_part_flag:	0B	, $  ; 34
               lac_part_spans_record:	0B	, $  ; 35
               start_logical_lac_part:	0	, $  ; 36
               end_logical_lac_part:	0	, $  ; 38
               lac_part_start_1:	0L	, $  ; 40
               lac_part_start_2:	0L	, $  ; 44
               lac_part_size_1:		0L	, $  ; 48
               lac_part_size_2:		0L	, $  ; 52
               lac_part_index_1:	0L	, $  ; 56
               lac_part_index_2:	0L	, $  ; 60
               gac_record_state:	0	, $  ; 64
               curr_gac_partition:	0	, $  ; 66
               gac_start_rec_addr:	0L	, $  ; 68
               gac_frames_to_rec:	0L	, $  ; 72
               wrap_gac_part_flag:	0B	, $  ; 76
               gac_part_spans_record:	0B	, $  ; 77
               start_logical_gac_part:	0	, $  ; 78
               end_logical_gac_part:	0	, $  ; 80
               gac_part_start_1:	0L	, $  ; 82
               gac_part_start_2:	0L	, $  ; 86
               gac_part_size_1:		0L	, $  ; 90
               gac_part_size_2:		0L	, $  ; 94
               gac_part_index_1:	0L	, $  ; 98
               gac_part_index_2:	0L	, $  ; 102
               tlm_record_state:	0	, $  ; 106
               curr_tlm_partition:	0	, $  ; 108
               tlm_start_rec_addr:	0L	, $  ; 110
               tlm_frames_to_rec:	0L	, $  ; 114
               wrap_tlm_part_flag:	0B	, $  ; 118
               tlm_part_spans_record:	0B	, $  ; 119
               start_logical_tlm_part:	0	, $  ; 120
               end_logical_tlm_part:	0	, $  ; 122
               fdr1_cmd_purge:		0	, $  ; 124
               fdr2_cmd_purge:		0	, $  ; 126
               tlm_part_start_1:	0L	, $  ; 128
               tlm_part_start_2:	0L	, $  ; 132
               tlm_part_size_1:		0L	, $  ; 136
               tlm_part_size_2:		0L	, $  ; 140
               tlm_part_index_1:	0L	, $  ; 144
               tlm_part_index_2:	0L	, $  ; 148
               soh_pad:		     bytarr(12)	, $  ; 152
               pkt_year:		0B	, $  ; 164
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { pfa_struct }, nstruct )
end
