;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    PSA_STR creates a data sturcture to store psa state of health telemetry
;    data.
;
;========================================================================
; Name: 
;	psa_str - creates data structure to store psa SOH telemetry data
;
; Synopsis:
;	psa = psa_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	psa	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function psa_str, nstruct

    common psa_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { psa_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ;
               task_error:		0B	, $  ;
               state:		    bytarr(6)	, $  ;
               tlm_collection_time:	0L	, $  ;
               sib_6hz_event_count:	0L	, $  ;
               timeout_event_count:	0	, $  ; 
               reset_event_count:	0	, $  ; 
               message_event_count:	0	, $  ; 
               soh_pad:		     bytarr(12)	, $  ; 
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { psa_struct }, nstruct )
end
