;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    RDCONTINGENCY reads seawifs contingency state of health data in a
;    byte array.
;
;-----------------------------------------------------------------
; rdcontingency - reads seawifs contingency SOH data into byte array
;
; Synopsis:
;     msgs = rdcontingency( file, indx )
;
;     file	- input contingency data filename
;     msgs	- SOH messages in S/C message format, stored as
;		  byte array 1034 x n.
;     indx	- optional output list of messages source addresses
;
; Written By:
;     B. A. Franz, General Sciences Corp., 7/97
;
;
;-----------------------------------------------------------------

function rdcontingency,file,indx

    msglen = 1034	; Max message size
    
    openr,/get_lun,lun,file
    f = fstat(lun)

    ;
    ; Create association
    ;
    a = assoc(lun, bytarr(f.size))
    r = a(0)
    
    ;
    ; Create fixed-length storage
    ;
    nmax = f.size/300 + 1
    msg  = bytarr(msglen, nmax)
    indx = intarr(nmax)

    ;
    ; Step through logger messages, save any SOH subsystem msgs
    ;
    p = 0L
    i = 0L
    while (p lt f.size) do begin

        while (p lt f.size-5   and $
               r(p  ) ne 125   and $
               r(p+1) ne   1   and $
               r(p+2) ne 193   and $
               r(p+3) ne  28) do begin
            print,'Resyncing at byte ',p
            p = p+1
        endwhile

        flen = fix(r(p+8:p+8+1),0)
        if (flen gt msglen-10 or flen lt 0) then begin
            print,'File is corrupted.  Unable to recover.'
            goto, continue
        endif

        addr = fix(r(p+8+4:p+8+5),0)
        indx(i) = addr
;        print,flen,addr
        msg(0:1,i) = byte(flen+10,0,2)
        msg(2:2+flen-1,i) = r(p:p+flen-1)
        i = i+1
        p = p+flen+10

    endwhile

continue:

    msg  = msg(*,0:i-1)
    indx = indx(0:i-1)

    return, msg

end

