;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    RDSBANDTLM reads band state of health telemetry data.
;
function rdsbandtlm,file,indx

    hdlclen = 3502        ; HDLC record length
    limitlen = 300	  ; SAC length
    
    ;
    ; Create file association and read entire file into byte array
    ;
    openr,/get_lun,lun,file
    f = fstat(lun)
    r = assoc(lun, bytarr(hdlclen))
    nrecs = f.size/hdlclen

    ;
    ; Step through HDLC records first time, determine number of msgs
    ;
    i = 0L
    maxlen = 0
    for ir=0,nrecs-1 do begin

        p      = 8L
        flen   = fix(r(p:p+1,ir),0)

        repeat begin

            if (flen le 0 or p+flen gt hdlclen) then begin
                print,'Bad length field at record ',ir,' msg ',i,' (',flen,')'
                goto,break
            endif

            maxlen = maxlen > flen < limitlen
            i      = i+1
            p      = p+flen

            if (p lt hdlclen-3) then $
                flen = fix(r(p:p+1,ir),0) $
            else $
                flen = 0

        endrep until (flen le 0 or p ge hdlclen)

        break:

    endfor
    nmax = i

    print,'Reading ',nmax,' messages.  Max length = ',maxlen

    ;
    ; Create fixed-length storage
    ;
    msg   = bytarr(maxlen, nmax)
    indx  = intarr(nmax)
    
    ;
    ; Step through HDLC records, second time
    ;
    i = 0L
    for ir=0,nrecs-1 do begin

        p    = 8L
        flen = fix(r(p:p+1,ir),0)

        repeat begin

            if (flen le 0 or p+flen gt hdlclen) then begin
                print,'Bad length field at record ',i,' (',flen,')'
                goto,break2
            endif

            addr = fix(r(p+14:p+15,ir),0)
            indx(i) = addr
            len     = flen < maxlen
            msg(0:len-1,i) = r(p:p+len-1,ir)
            i = i+1
            p = p+flen

            if (p lt hdlclen-3) then $
                flen = fix(r(p:p+1,ir),0) $
            else $
                flen = 0

        endrep until (flen le 0 or p ge hdlclen)

        break2:

    endfor

;    msg  = msg(*,0:i-1)
;    indx = indx(0:i-1)

    return, msg

end
