;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    READLORECS reads level0 file records into a byte array.
;
;----------------------------------------------------------------------
; Function readL0recs
;
; Synopsis:
;     recs = readL0recs(file[, nrec, offset])
;
; Output:
;     recs - 21504 x n byte array of L0 data
;
; Required Inputs: 
;     file - string specifying the name of a valid L0 file
;
; Optional Inputs:
;     nrec   - number of minor-frames to return (default is all)
;     offset - first minor-frame to read (default is 0)
;
; Written By:
;     BA Franz, GSC, 8 March 1996
;
;----------------------------------------------------------------------
function readL0recs,file,nrec,offset,hdr=hdr

    len = 21504L

    if (n_elements(hdr) eq 0) then $
        hdr = 512L

    openr,/get_lun,lun,file

    f  = fstat(lun)
    n  = (f.size - hdr)/len

    if (n_elements(offset) eq 0) then offset = 0L
    if (n_elements(nrec)   eq 0) then nrec   = n - offset

    r    = assoc(lun, bytarr(len,nrec), hdr+(offset*len))
    recs = r(0)

    free_lun, lun

    return, recs
end
