;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    RXS1_STR creates a data structure to store rxs1 state of health
;    telemetry data.
;
;========================================================================
; Name: 
;	rxs1_str - creates data structure to store rxs1 SOH telemetry data
;
; Synopsis:
;	rxs1 = rxs1_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	rxs1	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function rxs1_str, nstruct

    common rxs1_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { rxs1_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ;
               task_error:		0B	, $  ;
               carrier_offset:		0	, $  ;
               reserved_1:		0	, $  ;
               reference_voltage:	0B	, $  ;
               receiver_temerature:	0B	, $  ;
               program_counter:		0	, $  ;
               cmded_freq_offset:	0	, $  ;
               receiver_reset_count:	0	, $  ;
               prom_check_sum:		0	, $  ;
               fcs_1:			0	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { rxs1_struct }, nstruct )
end
