;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SAA_STR creates a data structure to store state of health saa
;    telemetry data.
;
;========================================================================
; Name: 
;	saa_str - creates data structure to store SOH_SAA telemetry data
;
; Synopsis:
;	saa = saa_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	saa	- saa data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function saa_str, nstruct

    common saa_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { saa_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	 bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_state:		0B	, $  ;
               task_error:		0B	, $  ;
               ace_operating_mode:	0B	, $  ;
               spare_0:			0B	, $  ;
               ps_1_5:			0B	, $  ; Power Supply 1
               ps_1_12:			0B	, $  ;
               ps_2_5:			0B	, $  ; Power Supply 2
               ps_2_12:			0B	, $  ;
               ace0_diag_code:		0B	, $  ;
               ace1_diag_code:		0B	, $  ;
               mw_0_speed:		0	, $  ; Momentum Wheel
               mw_0_torque:		0	, $  ;
               mw_0_brake_torque:	0	, $  ;
               mw_0_current:		0	, $  ;
               mw_0_voltage:		0	, $  ;
               mw_0_enabled:		0B	, $  ;
               mw_0_ad_voltage:		0B	, $  ;
               mw_1_speed:		0	, $  ; Momentum Wheel
               mw_1_torque:		0	, $  ;
               mw_1_brake_torque:	0	, $  ;
               mw_1_current:		0	, $  ;
               mw_1_voltage:		0	, $  ;
               mw_1_enabled:		0B	, $  ;
               mw_1_ad_voltage:		0B	, $  ;
               trd_1_dipole:	    intarr(3)	, $  ; Torque Rod Driver 1
               trd_1_enabled:       bytarr(3)	, $  ;
               trd_1_current:       bytarr(3)	, $  ;
               trd_1_ad_voltage:	0B	, $  ;
               spare_1:			0B	, $  ;
               trd_2_dipole:	    intarr(3)	, $  ; Torque Rod Driver 2
               trd_2_enabled:       bytarr(3)	, $  ;
               trd_2_current:       bytarr(3)	, $  ;
               trd_2_ad_voltage:	0B	, $  ;
               spare_2:			0B	, $  ;
               ss_0_error_status:	0B	, $  ; Sun Sensor 0
               ss_0_diags:		0B	, $  ;
               ss_0_sun_in_fov:		0B	, $  ;
               ss_0_reserved:		0B	, $  ;
               ss_0_axis:	     intarr(2)	, $  ;
               ss_0_timetag:		0L	, $  ;
               ss_1_error_status:	0B	, $  ; Sun Sensor 1
               ss_1_diags:		0B	, $  ;
               ss_1_sun_in_fov:		0B	, $  ;
               ss_1_reserved:		0B	, $  ;
               ss_1_axis:	     intarr(2)	, $  ;
               ss_1_timetag:		0L	, $  ;
               ss_2_error_status:	0B	, $  ; Sun Sensor 2
               ss_2_diags:		0B	, $  ;
               ss_2_sun_in_fov:		0B	, $  ;
               ss_2_reserved:		0B	, $  ;
               ss_2_axis:	     intarr(2)	, $  ;
               ss_2_timetag:		0L	, $  ; 
               mag_0_axis:	     intarr(4)	, $  ; Magnetometer 0
               mag_0_timetag:		0L	, $  ;
               mag_1_axis:	     intarr(4)	, $  ; Magnetometer 1
               mag_1_timetag:		0L	, $  ;
               hs_0_error_status:	0B	, $  ; Horizon Sensor 0
               hs_0_diag:		0B	, $  ;
               hs_0_reserved:		0B	, $  ;
               hs_0_supp_status:	0B	, $  ;
               hs_0_phase:		0	, $  ;
               hs_0_chord:		0	, $  ;
               hs_0_timetag:		0L	, $  ;
               hs_1_error_status:	0B	, $  ; Horizon Sensor 1
               hs_1_diag:		0B	, $  ;
               hs_1_reserved:		0B	, $  ;
               hs_1_supp_status:	0B	, $  ;
               hs_1_phase:		0	, $  ;
               hs_1_chord:		0	, $  ;
               hs_1_timetag:		0L	, $  ;
               diag_codes:	     bytarr(12)	, $  ; Diagnostics
               power_states:	     bytarr(12)	, $  ; Power States
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}


       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { saa_struct }, nstruct )
end
