;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SAC_STR creates a data structure to store state of health sac
;    telemetry data.
;
;========================================================================
; Name: 
;	sac_str - creates data structure to store SOH_SAC telemetry data
;
; Synopsis:
;	sac = sac_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	sac	- sac data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function sac_str, nstruct

    common sac_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { sac_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_state:		0B	, $  ;
               task_error:		0B	, $  ;
               sum_diag:		0B	, $  ;
               pegasus_state:		0B	, $  ;
               acs_mode:		0B	, $  ;
               ss_1_status:		0B	, $  ; Sun Sensor 1
               hs_1_status:		0B	, $  ; Horizon Sensor 1
               ace_operating_mode:	0B	, $  ;
               ps_1_5_vdc:		0B	, $  ; Power Supply 1
               ps_1_12_vdc:		0B	, $  ; Power Supply 1
               yaw_rate_computed:	0.	, $  ;
               pitch_rate_computed:	0.	, $  ;
               roll_rate_computed:	0.	, $  ;
               yaw_error:		0.	, $  ;
               pitch_error:		0.	, $  ;
               roll_error:		0.	, $  ;
               thruster_commands:	0B	, $  ;
               thruster_1_duration:	0B	, $  ;
               thruster_2_duration:	0B	, $  ;
               thruster_3_duration:	0B	, $  ;
               thruster_4_duration:	0B	, $  ;
               orbit_raising_status:	0B	, $  ;
               est_hydrazine_pressure:	0	, $  ;
               mw_1_speed:		0	, $  ;
               mw_2_speed:		0	, $  ;
               reference_time:		0.D	, $  ;
               psi_earth:		0.	, $  ;
               gst:			0.	, $  ; Greenwich Sidereal Time
               yaw_commanded:		0.	, $  ;
               pitch_commanded:		0.	, $  ;
               roll_commanded:		0.	, $  ;
               yaw_estimated:		0.	, $  ;
               pitch_estimated:		0.	, $  ;
               roll_estimated:		0.	, $  ;
               eci_x_position_computed:	0.D	, $  ;
               eci_y_position_computed:	0.D	, $  ;
               eci_z_position_computed:	0.D	, $  ;
               eci_x_velocity_computed:	0.D	, $  ;
               eci_y_velocity_computed:	0.D	, $  ;
               eci_z_velocity_computed:	0.D	, $  ;
               quaternion_1:		0.	, $  ;
               quaternion_2:		0.	, $  ;
               quaternion_3:		0.	, $  ;
               quaternion_4:		0.	, $  ;
               ss_1_x_angle:		0.	, $  ;
               ss_1_y_angle:		0.	, $  ;
               ss_2_x_angle:		0.	, $  ;
               ss_2_y_angle:		0.	, $  ;
               ss_3_x_angle:		0.	, $  ;
               ss_3_y_angle:		0.	, $  ;
               mag_1_x_body:		0.	, $  ;
               mag_1_y_body:		0.	, $  ;
               mag_1_z_body:		0.	, $  ;
               mag_2_x_body:		0.	, $  ;
               mag_2_y_body:		0.	, $  ;
               mag_2_z_body:		0.	, $  ;
               sun_roll:		0.	, $  ;
               sun_pitch:		0.	, $  ;
               local_nadir_roll:	0.	, $  ;
               local_nadir_pitch:	0.	, $  ;
               local_sun_ok:		0B	, $  ;
               local_nadir_ok:		0B	, $  ;
               sensors_ok:		0B	, $  ;
               sensors_valid:		0B	, $  ;
               mw_1_torque_bias:	0.	, $  ; Momentum Wheel 1
               mw_2_torque_bias:	0.	, $  ; Momentum Wheel 2
               mw_1_torque_commanded:	0.	, $  ; Momentum Wheel 1
               mw_2_torque_commanded:	0.	, $  ; Momentum Wheel 2
               tr_1_x_commanded:	0.	, $  ; Torque Rod 1
               tr_1_y_commanded:	0.	, $  ; 
               tr_1_z_commanded:	0.	, $  ; 
               tr_2_x_commanded:	0.	, $  ; Torque Rod 2
               tr_2_y_commanded:	0.	, $  ; 
               tr_2_z_commanded:	0.	, $  ; 
               actuators_ok:		0B	, $  ;
               hold_coarse_pointing:	0B	, $  ;
               mw_1_rate_commanded:	0	, $  ; Momentum Wheel 1
               mw_2_rate_commanded:	0	, $  ; Momentum Wheel 2
               status_flags:		0B	, $  ;
               spare:			0B	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}


       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { sac_struct }, nstruct )
end
