;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SGA_STR creates a data structure to store state of health telemetry data.
;
;========================================================================
; Name: 
;	sga_str - creates data structure to store SOH.SGA telemetry data
;
; Synopsis:
;	sga = sga_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	sga	- sga data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function sga_str, nstruct

    common sga_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { sga_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ;
               task_error:		0B	, $  ;
               month:			0B	, $  ;
               day:			0B	, $  ;
               year:			0	, $  ;
               hours:			0B	, $  ;
               minutes:			0B	, $  ;
               seconds:			0B	, $  ;
               spare_1:			0B	, $  ;
               fractional_seconds:	0L	, $  ;
               latitude:		0L	, $  ;
               longitude:		0L	, $  ;
               height:			0L	, $  ;
               gps_height:		0L	, $  ;
               velocity:		0L	, $  ;
               heading:			0	, $  ;
               current_gps_dop:		0	, $  ;
               gps_dop_type:		0B	, $  ;
               num_sat_visible:		0B	, $  ;
               num_sat_track:		0B	, $  ;
               spare_2:			0B	, $  ;
               ch1_receive_sat_id:	0B	, $  ;
               ch1_receive_track_mode:	0B	, $  ;
               ch1_receive_sig_strength:0B	, $  ;
               ch1_channel_status:	0B	, $  ;
               ch2_receive_sat_id:	0B	, $  ;
               ch2_receive_track_mode:	0B	, $  ;
               ch2_receive_sig_strength:0B	, $  ;
               ch2_channel_status:	0B	, $  ;
               ch3_receive_sat_id:	0B	, $  ;
               ch3_receive_track_mode:	0B	, $  ;
               ch3_receive_sig_strength:0B	, $  ;
               ch3_channel_status:	0B	, $  ;
               ch4_receive_sat_id:	0B	, $  ;
               ch4_receive_track_mode:	0B	, $  ;
               ch4_receive_sig_strength:0B	, $  ;
               ch4_channel_status:	0B	, $  ;
               ch5_receive_sat_id:	0B	, $  ;
               ch5_receive_track_mode:	0B	, $  ;
               ch5_receive_sig_strength:0B	, $  ;
               ch5_channel_status:	0B	, $  ;
               ch6_receive_sat_id:	0B	, $  ;
               ch6_receive_track_mode:	0B	, $  ;
               ch6_receive_sig_strength:0B	, $  ;
               ch6_channel_status:	0B	, $  ;
               ch7_receive_sat_id:	0B	, $  ;
               ch7_receive_track_mode:	0B	, $  ;
               ch7_receive_sig_strength:0B	, $  ;
               ch7_channel_status:	0B	, $  ;
               ch8_receive_sat_id:	0B	, $  ;
               ch8_receive_track_mode:	0B	, $  ;
               ch8_receive_sig_strength:0B	, $  ;
               ch8_channel_status:	0B	, $  ;
               ch9_receive_sat_id:	0B	, $  ;
               ch9_receive_track_mode:	0B	, $  ;
               ch9_receive_sig_strength:0B	, $  ;
               ch9_channel_status:	0B	, $  ;
               ch10_receive_sat_id:	0B	, $  ;
               ch10_receive_track_mode:	0B	, $  ;
               ch10_receive_sig_strength:0B	, $  ;
               ch10_channel_status:	0B	, $  ;
               ch11_receive_sat_id:	0B	, $  ;
               ch11_receive_track_mode:	0B	, $  ;
               ch11_receive_sig_strength:0B	, $  ;
               ch11_channel_status:	0B	, $  ;
               ch12_receive_sat_id:	0B	, $  ;
               ch12_receive_track_mode:	0B	, $  ;
               ch12_receive_sig_strength:0B	, $  ;
               ch12_channel_status:	0B	, $  ;
               receiver_status:		0B	, $  ;
               spare_3:			0B	, $  ;
               ecef_x_pos:		0.D	, $  ;
               ecef_y_pos:		0.D	, $  ;
               ecef_z_pos:		0.D	, $  ;
               ecef_x_vel:		0.D	, $  ;
               ecef_y_vel:		0.D	, $  ;
               ecef_z_vel:		0.D	, $  ;
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { sga_struct }, nstruct )
end
