;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SHM_STR creates a data structure to store shm state of health
;    telemetry data.
;
;========================================================================
; Name: 
;	shm_str - creates data structure to store shm SOH telemetry data
;
; Synopsis:
;	shm = shm_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	shm	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function shm_str, nstruct

    common shm_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { shm_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
               task_status: 	        0B	, $  ; 2
               task_error:		0B	, $  ; 3
               tlm_collect_years:	0B	, $  ; 4
               tlm_collect_months:	0B	, $  ; 5
               tlm_collect_days:	0B	, $  ; 6
               tlm_collect_hours:	0B	, $  ; 7
               tlm_collect_min:		0B	, $  ; 8
               tlm_collect_sec:		0B	, $  ; 9
               aux1:			0	, $  ; 10
               status_flags:		0	, $  ; 12
               scm_status:		0	, $  ; 14
               scm_error_status:	0	, $  ; 16
               gim_status:		0	, $  ; 18
               gim_error_status:	0	, $  ; 20
               cb_loaded_status:    bytarr(4)	, $  ; 22
               cb_enabled_status:   bytarr(4)	, $  ; 26
               cb_exec_status:	    bytarr(4)	, $  ; 30
               boot_counter:		0B	, $  ; 34
               boot_version:		0B	, $  ; 35
               task_table:	    intarr(16)	, $  ; 36
               last_boot_years:		0B	, $  ; 68
               last_boot_months:	0B	, $  ; 
               last_boot_days:		0B	, $  ;
               last_boot_hours:		0B	, $  ;
               last_boot_min:		0B	, $  ;
               last_boot_sec:		0B	, $  ;
               tlm_crc:			0	, $  ; 74
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { shm_struct }, nstruct )
end
