;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SMU_STR creates a data stucture to store smu state of health
;    telemetry data.
;
;========================================================================
; Name: 
;	smu_str - creates data structure to store smu SOH telemetry data
;
; Synopsis:
;	smu = smu_str( nrec )
;
; Inputs:
;	nrec	- number of records desired
;
; Outputs:
;	smu	-  data structure with nrec records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================
function smu_str, nstruct

    common smu_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { smu_struct	     		, $  ; Structure Name
               frame_length:		0	, $  ;
               frame_header:	     bytarr(8)	, $  ;
               length:			0	, $  ;
               dest_addr:		0	, $  ;
               source_addr:		0	, $  ;
               control:			0B	, $  ;
               sequence:		0B	, $  ;
               func:			0B	, $  ;
               subfunc:			0B	, $  ;
;               task_status: 	        0B	, $  ;
;               task_error:		0B	, $  ;
               spare1:			0B	, $
               t1:			0B	, $  ; Bus Panel 1 Temp
               t2:			0B	, $  ; Bus Panel 2 Temp
               t3:			0B	, $  ; Bus Panel 3 Temp
               t4:			0B	, $  ; Bus Panel 4 Temp
               t5:			0B	, $  ; Bus Panel 5 Temp
               t6:			0B	, $  ; Bus Panel 6 Temp
               t7:			0B	, $  ; Batt 1 2 Base Panel 1 3
               t8:			0B	, $  ; Mux0 Calibration Temp
               t9:			0B	, $  ; SIU 2
               t10:			0B	, $  ; GPS Antenna 1 2 Temp
               t11:			0B	, $  ; Avionics Shelf Temp
               t12:			0B	, $  ; GPS Receiver 1 2 Temp
               t13:			0B	, $  ; Payload Shelf Temp
               t14:			0B	, $  ; ACE Assembly Temp
               t15:			0B	, $  ; Torque Rod X Z Temp
               t16:			0B	, $  ; Mux1 Calibration Temp
               t17:			0B	, $  ; CRD 1 2 Temp
               t18:			0B	, $  ; SC Computer PS 1 2 Temp
               t19:			0B	, $  ; Horizon Sensor 1 2 Temp
               t20:			0B	, $  ; CWIFS FPA Temp
               t21:			0B	, $  ; Sun Sensor Assy 1 2 Temp
               t22:			0B	, $  ; MWheel Assy 1 2 Temp
               t23:			0B	, $  ; Tscope Motor Temp
               t24:			0B	, $  ; Mux2 Calibration Temp
               t25:			0B	, $  ; Line Temp 1
               t26:			0B	, $  ; Line Temp 2
               t27:			0B	, $  ; Line Temp 3
               t28:			0B	, $  ; Line Temp 4
               t29:			0B	, $  ; Tank Temp 1
               t30:			0B	, $  ; Tank Temp 2
               t31:			0B	, $  ; Tank Temp 3
               t32:			0B	, $  ; Sun Sensor Assy Aft Temp
               t33:			0B	, $  ; Aft Shelf Outboard Temp
               t34:			0B	, $  ; SIU 1
               t35:			0B	, $  ; 
               t36:			0B	, $  ; Mux4 Calibration Temp
               t37:			0B	, $  ; Valve Bodies 1 Temp
               t38:			0B	, $  ; Valve Bodies 2 Temp
               t39:			0B	, $  ; Valve Bodies 3 Temp
               t40:			0B	, $  ; Valve Bodies 4 Temp
               t41:			0B	, $  ; Thruster Chamber 1 Temp
               t42:			0B	, $  ; Thruster Chamber 1 Temp
               t43:			0B	, $  ; Thruster Chamber 1 Temp
               t44:			0B	, $  ; Thruster Chamber 1 Temp
               press_1_upstream:	0B	, $  ; Pressure 1 Upstream
               press_1_downstream:	0B	, $  ; Pressure 1 Downstream
               analog_gnd_1:		0B	, $  ;
               p28_vdc:			0B	, $  ;
               p5_vdc:			0B	, $  ;
               p12_vdc:			0B	, $  ;
               m12_vdc:			0B	, $  ;
               analog_gnd_2:		0B	, $  ;
               fill:                 bytarr(61) , $  ; Status Words
               pkt_year:		0B	, $  ;
               pkt_month:		0B	, $  ;
               pkt_day:			0B	, $  ;
               pkt_hour:		0B	, $  ;
               pkt_minute:		0B	, $  ;
               pkt_second:		0B	, $  ;
               pad:			0	, $  ;
               crc:			0	}

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { smu_struct }, nstruct )
end
