;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    TLM2INSTLM extracts the instrument telemetry packet from a gac or lac
;    telemetry file.
;
;------------------------------------------------------------------
; Func TLM2INSTLM
;
; Extracts the instrument telemetry packet from a GAC or LAC TLM
; file.  Accounts for the fact that the instrument and ancillary
; telemetry packets are intermixed.  Returns instrument telemetry
; as 44xn integers.  Optionally returns the packet time and index.
;
; Written By: BA Franz, GSC, 29 Feb 1996
;------------------------------------------------------------------
function tlm2instlm, tlm, sec, indx

    ;
    ; Which packet is inst tlm (1) and anc tlm (0), per mnf
    ;
    gacInstMask = [[1,0,1,1,0], $  ; mnf #1
                   [0,1,1,0,1], $  ; mnf #2
                   [1,1,0,1,1]]    ; mnf #3

    ;
    ; Do we have GAC or LAC tlm (structure differs)
    ;
    mnftype = scid2mnftype(tlm.scid)
    sgac = where(mnftype eq 15)
    slac = where(mnftype ne 15)

    if (sgac(0) ne -1) then begin

        ;
        ; GAC TLM
        ;
        tlm2  = tlm(sgac)
        n     = n_elements(tlm2)
        nscan = n*5L

        mnfnum = scid2mnfnum(tlm2.scid)
        mask   = bytarr(5,n)
        for i=0,n-1 do $
            mask(*,i) = gacInstMask(*,mnfnum(i)-1)

        indx   = where(mask)
        instlm = reform(tlm2.instlm, 44, nscan)
        sec    = mnfsec2gscansec(ttag2sec(tlm2.time))
        instlm = instlm(*,indx)
        sec    = sec(indx)

    endif else if (slac(0) ne -1) then begin

        ;
        ; LAC TLM
        ;
        tlm2 = tlm(slac)
        
        mnfnum = scid2mnfnum(tlm2.scid)
        indx   = where(mnfnum ne 2)
        instlm = tlm2(indx).instlm
        sec    = ttag2sec(tlm2(indx).time)

    endif

    return, instlm
end


