;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    TLM2SOHSUB extracts the specified subsystem telemetry packet from a gac
;    or lac telemetry file and returns it as a structured array.
;
;------------------------------------------------------------------
; Func TLM2SOHSUB
;
; Extracts the specified subsystem telemetry packet from a GAC or 
; LAC TLM file.  Returns packet as structured array.
;
; Written By: BA Franz, GSC, 29 Feb 1996
;------------------------------------------------------------------
function tlm2sohsub, tlm, subname, sec, indx

    msghdr  = 0
    strname = subname+'_str'

    ;
    ; Define minor frame number where this subsystem resides, and 
    ; location of subsystem within mnf
    ;
    case (strupcase(subname)) of
      'SGA' : begin
              mnf_wanted = 1
              length     = 170
              start_byte = 0
              end
      'SAC' : begin
              mnf_wanted = 1
              length     = 296
              start_byte = 170
              end
      'SAA' : begin
              mnf_wanted = 1
              length     = 200
              start_byte = 466
              end
      'RXS1' : begin
              mnf_wanted = 1
              length     = 48
              start_byte = 666
              end
      'RXS2' : begin
              mnf_wanted = 1
              length     = 48
              start_byte = 714
              end
      'TXL' : begin
              mnf_wanted = 2
              length     = 67
              start_byte = 0
              end
      'TXS' : begin
              mnf_wanted = 2
              length     = 67
              start_byte = 67
              end
      'SMU' : begin
              mnf_wanted = 2
              length     = 144
              start_byte = 134
              end
      'EPS' : begin
              mnf_wanted = 2
              length     = 205
              start_byte = 278
              end
      'FDR1' : begin
              mnf_wanted = 2
              length     = 126
              start_byte = 483
              end
      'FDR2' : begin
              mnf_wanted = 2
              length     = 126
              start_byte = 609
              end
      'GUA' : begin
              mnf_wanted = 3
              length     = 94
              start_byte = 0
              end
      'GSC' : begin
              mnf_wanted = 3
              length     = 78
              start_byte = 94
              end
      'PSA' : begin
              mnf_wanted = 3
              length     = 64
              start_byte = 172
              end
      'PFA' : begin
              mnf_wanted = 3
              length     = 192
              start_byte = 236
              end
      'SHM' : begin
              mnf_wanted = 3
              length     = 104
              start_byte = 428
              end
       'GHM' : begin
              mnf_wanted = 3
              length     = 144
              start_byte = 532
              end
       else : begin
              message,'Invalid subsystem name: '+subname,/info
              return,-1
              end 
    endcase

    end_byte   = start_byte + length - 1

    ;
    ; Get the SOH data for the desired minor frame, and pull 
    ; subsystem bytes from SOH block.
    ;
    mnfnum = scid2mnfnum(tlm.scid)
    indx   = where(mnfnum eq mnf_wanted, nrec)
    sub    = tlm(indx).soh(start_byte:end_byte)
    sec    = ttag2sec(tlm(indx).time)

    ;
    ; Map subsystem bytes into subsystem record 
    ; (no expansion on bit fields)
    ;
    sub = str_remap(sub,strname,msghdr)

    return, sub
end


