;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    UNPACK_INSTLM unpacks instrument telemetry data.
;
function instlm_str, nstruct

    common instlm_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { instlm_struct	     	, $  ; Structure Name
               time:			0L	, $  ; msec since GPS pulse
               servo_select:		0B	, $  ; 0=B, 1=A 
               ang_mom_comp_on:		0B	, $  ; 0=Off, 1=On
               servo_a_lock:		0B	, $  ; 0=Locked, 1=Unlocked 
               servo_b_lock:		0B	, $  ; 0=Locked, 1=Unlocked 
               timing_select:		0B	, $  ; 0=B, 1=A 
               tilt_a_select:		0B	, $  ; 
               tilt_b_select:		0B	, $  ; 
               tilt_tlm_on:		0B	, $  ; 
               stow_on:			0B	, $  ; 
               stow_aligned:		0B	, $  ; 
               heater_status:		0B	, $  ; 
               solar_door_status:	0B	, $  ; 
               analog_power_status:	0B	, $  ; 
               tilt_platform_limit:	0B	, $  ; 
               tilt_base_limit:		0B	, $  ; 
               tilt_nadir_aligned:	0B	, $  ; 
               tilt_aft_aligned:	0B	, $  ; 
               tilt_fwd_aligned:	0B	, $  ; 
               data_mode_select:	0B	, $  ; 
               mirror_side:		0B	, $  ; 
               image_data_sync_status:	0B	, $  ; 
               ang_mom_com_a_speed:	0B	, $  ; 
               ang_mom_com_b_speed:	0B	, $  ; 
               spare:			0B	, $  ; 
               band_12_fpa_temp:	0.	, $  ; 
               band_34_fpa_temp:	0.	, $  ; 
               band_56_fpa_temp:	0.	, $  ; 
               band_78_fpa_temp:	0.	, $  ; 
               tele_motor_temp:		0.	, $  ; 
               tilt_base_temp:		0.	, $  ; 
               tilt_plat_temp:		0.	, $  ; 
               mirror_motor_temp:	0.	, $  ; 
               ps_a_input_current:	0.	, $  ; 
               ps_b_input_current:	0.	, $  ; 
               p15v_analog_power:	0.	, $  ; 
               n15v_analog_power:	0.	, $  ; 
               p5v_logic_power:		0.	, $  ; 
               ps_temp:			0.	, $  ; 
               b12_postamp_temp:	0.	, $  ; 
               servo_driver_temp:	0.	, $  ; 
               p30v_servo_power:	0.	, $  ; 
               p21v_servo_power:	0.	, $  ; 
               n21v_servo_power:	0.	, $  ; 
               p5v_servo_power:		0.	, $  ; 
               ang_momentum_speed:	0.	, $  ; 
               tilt_plat_pos:		0.	, $  ; 
               tilt_base_pos:		0.	, $  ; 
               p28v_heater:		0.	, $  ; 
               tele_a_motor_current:	0.	, $  ; 
               tele_b_motor_current:	0.	, $  ; 
               mirror_a_motor_current:	0.	, $  ; 
               mirror_b_motor_current:	0.	, $  ; 
               servo_a_phase_error:	0.	, $  ; 
               servo_b_phase_error:	0.	, $  ; 
               ang_mom_comp_a_current:	0.	, $  ; 
               ang_mom_comp_b_current:	0.	  $  ; 
             }

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { instlm_struct }, nstruct )
end

function anlinstlm_str, nstruct

    common anlinstlm_str_cmn, defined

    if ( n_elements(defined) ne 1 ) then begin
 
       rec = { anlinstlm_struct	     	, $  ; Structure Name
               band_12_fpa_temp:	0B	, $  ; 
               band_34_fpa_temp:	0B	, $  ; 
               band_56_fpa_temp:	0B	, $  ; 
               band_78_fpa_temp:	0B	, $  ; 
               tele_motor_temp:		0B	, $  ; 
               tilt_base_temp:		0B	, $  ; 
               tilt_plat_temp:		0B	, $  ; 
               mirror_motor_temp:	0B	, $  ; 
               ps_a_input_current:	0B	, $  ; 
               ps_b_input_current:	0B	, $  ; 
               p15v_analog_power:	0B	, $  ; 
               n15v_analog_power:	0B	, $  ; 
               p5v_logic_power:		0B	, $  ; 
               ps_temp:			0B	, $  ; 
               b12_postamp_temp:	0B	, $  ; 
               servo_driver_temp:	0B	, $  ; 
               p30v_servo_power:	0B	, $  ; 
               p21v_servo_power:	0B	, $  ; 
               n21v_servo_power:	0B	, $  ; 
               p5v_servo_power:		0B	, $  ; 
               ang_momentum_speed:	0B	, $  ; 
               tilt_plat_pos:		0B	, $  ; 
               tilt_base_pos:		0B	, $  ; 
               p28v_heater:		0B	, $  ; 
               tele_a_motor_current:	0B	, $  ; 
               tele_b_motor_current:	0B	, $  ; 
               mirror_a_motor_current:	0B	, $  ; 
               mirror_b_motor_current:	0B	, $  ; 
               servo_a_phase_error:	0B	, $  ; 
               servo_b_phase_error:	0B	, $  ; 
               ang_mom_comp_a_current:	0B	, $  ; 
               ang_mom_comp_b_current:	0B	  $  ; 
             }

       defined = 1 

    endif

    if ( n_elements(nstruct) ne 1 ) then nstruct = 1

return, replicate( { anlinstlm_struct }, nstruct )
end

function instlm_anl_conv

    conv = [ 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	 0.0200,	0.2600,	$ ;
   	 	 0.0200,	0.2600,	$ ;
   	 	 0.0750,	0.0000,	$ ;
   	 	-0.0750,	0.0000,	$ ;
   	 	 0.0250,	0.0000,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	-0.2667,	66.667,	$ ;
   	 	 0.1500,	0.0000,	$ ;
   	 	 0.1044,	0.0000,	$ ;
   	 	-0.1044,	0.0000,	$ ;
   	 	 0.0250,	0.0000,	$ ;
   	 	 8.5200,        -377.0,	$ ;
   	 	 1.4400,	0.0000,	$ ;
   	 	 1.4400,	0.0000,	$ ;
   	 	 0.1400,	0.0000,	$ ;
   	 	 0.0024,	0.0000,	$ ;
   	 	 0.0024,	0.0000,	$ ;
   	 	 0.0024,	0.0000,	$ ;
   	 	 0.0024,	0.0000,	$ ;
   	 	 0.0100,	-1.250,	$ ;
   	 	 0.0100,	-1.250,	$ ;
   	 	 0.0160,	0.0000,	$ ;
   	 	 0.0160,	0.0000  ] ;

    return, reform(conv,2,32)
end


function unpack_instlm, instlm

    nrec = n_elements(instlm(0,*))
    rec  = instlm_str(nrec)
    conv = instlm_anl_conv()

    rec.time = long(byte(instlm(0:3,*)),0,nrec)

    digtlm = reform(reverse(unmask(byte(instlm(4:6,*)))),24,nrec)

    for i=1,24 do $
        rec.(i) = reform(digtlm(i-1,*),nrec)

    anltlm = byte(instlm(7:38,*))

    anlrec = str_remap(anltlm,'anlinstlm_str')

    for i=0,31 do $
        rec.(i+25) = anlrec.(i) * conv(0,i) + conv(1,i)

    return,rec
end
