;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MKINDEX_CROSS_SENSOR generates a resampling index for sensor cross calibration
function mkindex_cross_sensor,file1,file2,fmt1=fmt1,fmt2=fmt2,ds=ds,dl=dl

    if (n_elements(fmt1) eq 0) then fmt1 = 'L2HDF'
    if (n_elements(fmt2) eq 0) then fmt2 = 'L2HDF'
    if (n_elements(ds  ) eq 0) then ds   = 1
    if (n_elements(dl  ) eq 0) then dl   = 360.0

    if (fmt1 eq 'L2HDF' or fmt1 eq 'L1BHDF') then begin
        lon1  = rd_sds(file1,'longitude')
        if (lon1(0) eq -1) then $
            lon1  = rd_sds(file1,'Longitude')
        lat1  = rd_sds(file1,'latitude')
        if (lat1(0) eq -1) then $
            lat1  = rd_sds(file1,'Latitude')
    endif else if (fmt1 eq 'L1BBIN') then begin
        r = readl1(file1)
        lon1 = r.lon
        lat1 = r.lat
    endif else if (fmt1 eq 'L2BIN') then begin
        r = readl2(file1)
        lon1 = r.lon
        lat1 = r.lat
    endif else begin
        print,'Unknown format specification: ',fmt1
        return,-1
    endelse

    if (fmt2 eq 'L2HDF' or fmt2 eq 'L1BHDF') then begin
        lon2  = rd_sds(file2,'longitude')
        if (lon2(0) eq -1) then $
            lon2  = rd_sds(file2,'Longitude')
        lat2  = rd_sds(file2,'latitude')
        if (lat2(0) eq -1) then $
            lat2  = rd_sds(file2,'Latitude')
    endif else if (fmt2 eq 'L1BBIN') then begin
        r = readl1(file2)
        lon2 = r.lon
        lat2 = r.lat
    endif else if (fmt2 eq 'L2BIN') then begin
        r = readl2(file2)
        lon2 = r.lon
        lat2 = r.lat
    endif else begin
        print,'Unknown format specification: ',fmt2
        return,-1
    endelse

    index = sample_lonlat(lon1,lat1,lon2,lat2,ds,dl)

    return, index
end
