;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MKL1PATCH creates a level1 patch.
;
pro mkl1patch, ifile, lon, lat, outdir, xysize=xysize,file=file,status=status

    if (n_elements(outdir) eq 0) then outdir = '.'
    if (n_elements(xysize) ne 2) then xysize=[1,1]

    status=1

    r = readl1(ifile,hdr)

    tvec = lonlat2geovec(lon,lat)             ; target pixel vector
    ovec = lonlat2geovec(r.lon,r.lat)         ; observed pixel vectors
    dist = sqrt( (tvec(0)-ovec(0,*,*))^2 + $  ; flat earth vector differences
                 (tvec(1)-ovec(1,*,*))^2 + $
                 (tvec(2)-ovec(2,*,*))^2 )
    dist = reform(dist)
    min_dist = min(dist)
    if (min_dist gt 2) then begin
        print,'Closest sensor measurement is ',min_dist,' km from target'
        status=0
        return
    endif

    s = where(dist eq min_dist)
    upkwhere,dist,s,i,j & i=i(0) & j=j(0)

    pix1 = (i-xysize(0)/2) > 0
    pix2 = (i+xysize(0)/2) < (hdr.npix-1) 
    rec1 = (j-xysize(1)/2) > 0
    rec2 = (j+xysize(1)/2) < (n_elements(r)-1)
    npix = pix2-pix1+1
    nrec = rec2-rec1+1

    orec = generic_l1_str(nrec,npix)
    len  = str_len(orec)
    ohdr = bytarr(len) 
    ohdr(0: 3) = byte(hdr.sensorID,0,4)
    ohdr(4: 7) = byte(len,0,4)
    ohdr(8:11) = byte(npix,0,4)

    if (n_elements(file) eq 0) then $
	ofile  = outdir+'/'+fileprefix(ifile)+'.L1B_'+num2str(npix) $
    else $
        ofile = file

    openw,olun,ofile,/get_lun
    writeu,olun,ohdr

    orec.year = r(rec1:rec2).year
    orec.day  = r(rec1:rec2).day
    orec.msec = r(rec1:rec2).msec
    orec.lon  = r(rec1:rec2).lon (pix1:pix2)
    orec.lat  = r(rec1:rec2).lat (pix1:pix2)
    orec.sunz = r(rec1:rec2).sunz(pix1:pix2)
    orec.suna = r(rec1:rec2).suna(pix1:pix2)
    orec.senz = r(rec1:rec2).senz(pix1:pix2)
    orec.sena = r(rec1:rec2).sena(pix1:pix2)
    orec.data = r(rec1:rec2).data(*,pix1:pix2)

    ;
    ; Write the new record
    ;
    writeu,olun,orec        

    free_lun,olun
    return
end
