;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MKNLWFILE_CROSS_SENSOR generates an MSl12 calibration target file from an MSl12 output
pro mknlwfile_cross_sensor,index,ifile,ofile

    ix = reform(index(0,*,*))
    iy = reform(index(1,*,*))
    sz = size(index)
    nx = sz(2)
    ny = sz(3)

    if (isHDF(ifile)) then begin
        year = rd_sds(ifile,'year')
        day  = rd_sds(ifile,'day')
        msec = rd_sds(ifile,'msec')
        nlw  = readl2hdf(ifile,'nLw_')
        lw   = readl2hdf(ifile,'Lw_')
        solz = readl2hdf(ifile,'solz')
    endif else begin
        d = readl2(ifile)
        year = d.year
        day  = d.day
        msec = d.msec
        solz = d.sunz
        sz = size(d.nlw)
        nlw = fltarr(sz(2),sz(3),sz(1))
         lw = fltarr(sz(2),sz(3),sz(1))
        for i=0,sz(1)-1 do begin
            nlw(*,*,i)  = reform(d.nlw(i,*))
             lw(*,*,i)  = reform(d.lw (i,*))
        endfor
    endelse

    r = replicate({year:0L,day:0L,msec:0L, $
                   solz:fltarr(nx),        $       
                   lw:fltarr(8,nx),        $
                   nlw:fltarr(8,nx)}, ny)

    r.year = year(reform(iy(0,*)))
    r.day  = day (reform(iy(0,*)))
    r.msec = msec(reform(iy(0,*)))
    r.solz = solz(ix,iy)
    r.lw   = 0.0
    r.nlw  = 0.0

    sz = size(nlw)
    n = sz(3)

    for i=0,n-1 do begin
        t = nlw(*,*,i) & t = t(ix,iy)
        r.nlw(i,*) = reform(t,1,nx,ny)
    endfor

    len = str_len(r)
    hdr = {sensorID:0L,reclen:len,npix:nx,format:0L,nscans:ny, $
             fill:bytarr(len-20)}

    openw,/get_lun,lun,ofile
    writeu,lun,hdr
    writeu,lun,r
    free_lun,lun

    return
end

