;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MKSUBSCENE creates a sub scene with a given range for latitude and
;    longitude.
;
;** Note: this stuff will not work across the date line.
;
; lonrange,latrange=[ul,ur,ll,lr]
; npix = input file pixPerScan
;

function fixlon,lon
    s = where(lon gt  180)
    if (s(0) ne -1) then lon(s) = lon(s)-360.
    s = where(lon lt -180)
    if (s(0) ne -1) then lon(s) = lon(s)+360.
    return,lon
end


pro mksubscene, ifile, outdir, lonrange, latrange

    hdr={sensorID:0L,length:0L,npix:0L,format:0L}

    openr,ilun,ifile,/get_lun

    readu,ilun,hdr
    if (hdr.length le 0 or hdr.length gt 1000000 or $
        hdr.npix   le 0 or hdr.npix   gt 10000) then begin
        print,'Header seems wacky.'
        print,'Sensor ID : ',hdr.sensorID
        print,'Length    : ',hdr.length
        print,'Npix      : ',hdr.npix
        return
    endif

    r = generic_l1_str(1,hdr.npix,hdr.format) & r=r(0)

    len  = str_len(r)
    a    = assoc(ilun,r,len)
    f    = fstat(ilun)
    nrec = f.size/len - 1

    lon1 = min(lonrange)    
    lon2 = max(lonrange)    
    lat1 = min(latrange)    
    lat2 = max(latrange)    

    ;
    ; Identify corner coordinates
    ;
    ul_lon = lonrange(0)
    ul_lat = latrange(0)
    ur_lon = lonrange(1)
    ur_lat = latrange(1)
    ll_lon = lonrange(2)
    ll_lat = latrange(2)
    lr_lon = lonrange(3)
    lr_lat = latrange(3)

    ;
    ; Derive linear functions to define each boundary
    ;
    fup = fltarr(2)
    fdn = fltarr(2)
    flf = fltarr(2)
    frt = fltarr(2)

    fup(0) = (ur_lat-ul_lat)/(ur_lon-ul_lon)
    fup(1) = ul_lat - fup(0) * ul_lon

    fdn(0) = (lr_lat-ll_lat)/(lr_lon-ll_lon)
    fdn(1) = ll_lat - fdn(0) * ll_lon

    flf(0) = (ul_lon-ll_lon)/(ul_lat-ll_lat)
    flf(1) = ll_lon - flf(0) * ll_lat

    frt(0) = (ur_lon-lr_lon)/(ur_lat-lr_lat)
    frt(1) = lr_lon - frt(0) * lr_lat

    pix1 =  9999
    pix2 = -9999
    indx = lonarr(3,nrec)
    cnt  = 0

    ;
    ; Locate scans and pixel ranges which fall into the minumum
    ; square lon, lat box that encompasses the corner coordinates.
    ;
    for i=0L,nrec-1 do begin
        r = a(i)
        r.lon = fixlon(r.lon)
        s = where(r.lon ge lon1 and r.lon le lon2 and $
                  r.lat ge lat1 and r.lat le lat2, ns)
        if (s(0) ne -1) then begin
;            print,i,s(0),s(ns-1)
            pix1 = min([pix1,s(0)])
            pix2 = max([pix2,s(ns-1)])
            indx(0,cnt) = i
            indx(1,cnt) = s(0)
            indx(2,cnt) = s(ns-1)
            cnt = cnt+1
        endif
    endfor

    ofile  = outdir+'/'+fileprefix(ifile)+'.L1B_'+num2str(pix2-pix1+1)
    openw,olun,ofile,/get_lun

    print,'Matching records: ',cnt
    if (cnt eq 0) then return
    print,'Scan range:  ',indx(0,0),' - ',indx(0,cnt-1)
    print,'Pixel range: ',pix1,' - ',pix2
    print,'Writing ',ofile,' with npix = ',pix2-pix1+1

    ;
    ; Allocate space for one record the the minimum required num pixels
    ; 
    npix = pix2-pix1+1
    orec = generic_l1_str(1,npix,hdr.format)
    len  = str_len(orec)
    ohdr = bytarr(len) 
    ohdr(0: 3) = byte(hdr.sensorID,0,4)
    ohdr(4: 7) = byte(len,0,4)
    ohdr(8:11) = byte(npix,0,4)
    ohdr(12:15)= byte(hdr.format,0,4)
    writeu,olun,ohdr

    ;
    ; Read input file records of intrest, extract pixel range
    ; of interest, and write.
    ;
    for i=0L,cnt-1 do begin

        r = a(indx(0,i))

        ;
        ; Blank the data outside the square lon-lat boundaries
        ;
;        if (indx(1,i) gt 0) then $
;            r.data(*,0:indx(1,i)-1) = 0.0
;        if (indx(2,i) lt npix-1) then $
;            r.data(*,indx(2,i)+1:npix-1) = 0.0

        orec.year = r.year
        orec.day  = r.day
        orec.msec = r.msec
        orec.lon  = fixlon(r.lon(pix1:pix2))
        orec.lat  = r.lat (pix1:pix2)
        orec.sunz = r.sunz(pix1:pix2)
        orec.suna = r.suna(pix1:pix2)
        orec.senz = r.senz(pix1:pix2)
        orec.sena = r.sena(pix1:pix2)
        orec.data = r.data(*,pix1:pix2)

        if (hdr.format ne 0) then begin
            orec.tsunz = r.tsunz(*,pix1:pix2)
            orec.tsenz = r.tsenz(*,pix1:pix2)
            orec.traz  = r.traz (*,pix1:pix2)
        endif

        ;
        ; Now blank the data outside the boundaries defined
        ; by lines connecting the corner coordinates.
        ;
        uplat = fup(0)*orec.lon+fup(1)
        dnlat = fdn(0)*orec.lon+fdn(1)
        lflon = flf(0)*orec.lat+flf(1)
        rtlon = frt(0)*orec.lat+frt(1)

        s = where( (orec.lat gt uplat+0.001) or (orec.lat lt dnlat-0.001) or $
                   (orec.lon lt lflon-0.001) or (orec.lon gt rtlon+0.001) )

;        if (s(0) ne -1) then begin
;            print,i,s
;            print,i,orec.lon(s)
;            print,i,rtlon(s)
;        endif

        if (s(0) ne -1) then $
            for ib=0,7 do begin
                data = reform(orec.data(ib,*))
                data(s) = 0.0
                orec.data(ib,*) = data
            endfor

        ;
        ; Write the new record
        ;
        writeu,olun,orec        

    endfor

    free_lun,ilun
    free_lun,olun

    return
end
