;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    READ_TARGET reads a calibration target file
function read_aerfile,infile,filehdr,recnum=recnum,status=status

    common read_aerfile_cmn, filename, lun, hdr, rec, nrecs

    if (n_elements(recnum)   eq 0) then recnum   = -1
    if (n_elements(filename) eq 0) then filename = ''
    if (n_elements(lun)      eq 0) then lun      = -1

    if (filename ne infile) then begin

        if (lun ne -1) then free_lun,lun

        hdr={sensorID:0L,reclen:0L,npix:0L,format:0L,nscans:0L}
        openr,/get_lun,lun,infile
        readu,lun,hdr
print,hdr.npix,hdr.nscans,hdr.reclen

        if (hdr.npix    gt   5000     or $
            hdr.reclen  gt 1000000    or $
            hdr.npix    lt 1          or $
            hdr.reclen  lt 1        ) then begin
            print,'Header values seem wacky'
            print,'Record Length:   ',hdr.reclen
            print,'Pixels per Scan: ',hdr.npix
            status = 0
            return,-1
        endif

        f     = fstat(lun)
        nrecs = f.size/hdr.reclen - 1
        nband = 16
        rec   =  { amodmin:lonarr(hdr.npix),    $	
                   amodmax:lonarr(hdr.npix),    $
                   amodrat:fltarr(hdr.npix),    $
                   taua:fltarr(nband,hdr.npix)}

        filename = infile

    endif

    filehdr = hdr

    if (recnum ge nrecs or recnum lt -1) then begin
       status = 0
       free_lun,lun
       lun      = -1
       filename = ''
       return, rec
    endif else if (recnum eq -1) then begin
       status = 1
       a = assoc(lun,replicate(rec,nrecs),hdr.reclen)
       r = a(0)
       free_lun,lun
       lun      = -1
       filename = ''
       return,r
    endif else begin
       status = 1
       a   = assoc(lun,rec,hdr.reclen)
       rec = a(recnum)
       if (recnum eq nrecs-1) then begin
           free_lun,lun
           lun      = -1
           filename = ''
       endif
       return,rec
    endelse
            
end
