;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    STR_READ_LIST performs a structured read on an input structured
;    definition list.
;
function str_read_list,files,struct,hdrlen=hdrlen

stat   = execute('rec = '+struct+'(1)')
len    = str_len(rec)
nfiles = n_elements(files)
nrecs  = lonarr(nfiles)
status = 1

for i=0,nfiles-1 do begin

    filename = files(i)

    ;
    ; Check that file exists
    ;
    if (n_elements(findfile(filename)) eq 0) then begin
        print,'File not found: ',filename
        status = 0
    end

    ;
    ; File exists, open it.
    ;
    openr,lun,/get_lun,filename

    ;
    ; Get file attributes
    ;
    f = fstat(lun)
    nrecs(i) = long(f.size/len)
    free_lun,lun

    ;
    ; If file has no records
    ;
    if (nrecs(i) le 0) then begin
        print,'File has no records.' 
        status = 0
    endif
    
endfor

if (not status) then $
    return,-1

numrecs = total(nrecs)
stat    = execute('rec = '+struct+'(numrecs)')
n1	= 0

for i=0,nfiles-1 do begin

    print,n1
    n2 = n1 + nrecs(i)
    r = str_read(files(i),struct,hdrlen=hdrlen)
    rec(n1:n2-1) = r
    n1 = n2

endfor

return,rec
end
