;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    STR_REMAP remaps a byte array into a structured array.
;
;========================================================================
; 
; Name: 
;	str_remap - remaps a byte array into a structured array
;
; Synopsis:
;	rec_array = str_remap( array, strname )
;
; Inputs:
;	array 	- array of bytes
;	strname - string containg structure name
;
; Outputs:
; 	rec_array - array of records
;
; Author:
;	BA Franz, General Sciences Corp., 29 January 96
;
;========================================================================

function str_remap, arr, strname, offset

    if (n_elements(offset) eq 0) then offset=0

    sz = size(arr)
    case (sz(0)) of
       1 : begin
           nrec   = 1
           nbytes = sz(1) 
           end
       2 : begin
           nrec   = sz(2)
           nbytes = sz(1) 
           end
    endcase

    rec    = call_function(strname, nrec)
    ntag   = n_tags(rec)
    name   = strlowcase(tag_names(rec))
    case nrec of
          0 : shft = -1
       else : shft = bytarr(nrec) - 1
    endcase

    p = offset	; data byte position

    for i=0,ntag-1 do begin

	;
	; Determine field type
	;
	sz  = size(rec(0).(i))
	typ = sz(n_elements(sz)-2)

        ;
        ; Extract field and cast to proper type
        ;
        case typ of
    	    1 : begin	; Byte
                n = 1
                case sz(0) of
                    0 : begin
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = byte(tmparr, 0, nrec)
                        end
                    1 : begin
                        d1 = sz(1)
                        n = n * d1
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = byte(tmparr, 0, d1, nrec)
                        end
                    endcase
                end
            2 : begin	; Integer (2 Bytes)
                n = 2
                case sz(0) of
                    0 : begin
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = fix(tmparr, 0, nrec)
                        end
                    1 : begin
                        d1 = sz(1)
                        n = n * d1
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = fix(tmparr, 0, d1, nrec)
                        end
                    endcase
                    rec.(i) = swap_endian(rec.(i),/swap_if_little_endian)
                end
            3 : begin	; Long Integer (4 Bytes)
                n = 4
                case sz(0) of
                    0 : begin
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = long(tmparr, 0, nrec)
                        end
                    1 : begin
                        d1 = sz(1)
                        n = n * d1
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = long(tmparr, 0, d1, nrec)
                        end
                    endcase
                    rec.(i) = swap_endian(rec.(i),/swap_if_little_endian)
                end
            4 : begin	; Float (4 Bytes)
                n = 4
                case sz(0) of
                    0 : begin
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = float(tmparr, 0, nrec)
                        end
                    1 : begin
                        d1 = sz(1)
                        n = n * d1
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = float(tmparr, 0, d1, nrec)
                        end
                    endcase
                    rec.(i) = swap_endian(rec.(i),/swap_if_little_endian)
                end
            5 : begin	; Double float (8 Bytes)
                n = 8
                case sz(0) of
                    0 : begin
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = double(tmparr, 0, nrec)
                        end
                    1 : begin
                        d1 = sz(1)
                        n = n * d1
                        tmparr = reform(arr(p:p+n-1,*))
                        rec.(i) = double(tmparr, 0, d1, nrec)
                        end
                    endcase
                    rec.(i) = swap_endian(rec.(i),/swap_if_little_endian)
                end
           8 : begin
               n = str_len(rec(0).(i)) * n_elements(rec(0).(i))
               tmparr  = reform(arr(p:p+n-1,*))
               rec.(i) = str_remap(tmparr,tag_names(rec.(i),/struct))
               end
         else : begin
                message,'Invalid data type.',/info
                return,-1
                endelse
        endcase

        ;
        ; Update byte pointer
        ;
        p = p + n

    endfor

return, rec
end
