;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    STR_WRITE performs a structured write using an input structure definition.
;
;--------------------------------------------------------------------
; Function STR_WRITE
;
; IDL procedure to perform a structured read using a user specified
; IDL structure definition.  
;
; Written by: BA Franz
;
; The following procedure will create an
; IDL record definition from a standard RDF found in the COBE Data
; Dictionary.
;
;   $ DMU
;   DMU> lis/full/out=BCI_CIRSSM.DDL BCI_CIRSSM
;   DMU> exit
;   $ UIDL
;   UIDL> status = DDL_STRUCT( ddl='bci_cirssm' )
;
;   The result of this procedure will be to produce a file called
;   bci_cirssm_str.pro in your default directory.  The prefix of
;   this file is passed as a string parameter to STR_WRITE.  The
;   file may exist anywhere in your IDL path.
;
; 
; Inputs:
;     strarr   - array of records of structure struct
;     filename - name of file you wish to write
;     struct   - string containing the structure name
;
;--------------------------------------------------------------------

pro str_write,strarr,filename,struct

nrecs  = n_elements(strarr)
reclen = str_len(strarr)

;
; Open file for fixed recordlength write
;
openw,/get_lun,lun,filename,reclen,/fixed

;
; Execute associated write.
;
rec = assoc(lun,strarr)    ; Associate record with lun
rec(0) = strarr            ; Write complete block

;
; Clean-up
;
free_lun,lun

return
end
