;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    TTAG2MJUL converts seawifs telemetry time tag to julian day.
;
function ttag2mjul, ttag

    s = size(ttag)
    n = s(1)
    if (s(0) eq 2) then $
        nrec = s(2)     $
    else                $
        nrec = 1

    if (n ne 4) then begin
        print,'Invalid Time-Tag field'
        return,-1
    endif

    word1 = long(reform(ttag(0,*)))
    word2 = long(reform(ttag(1,*)))
    word3 = long(reform(ttag(2,*)))
    word4 = long(reform(ttag(3,*)))
 
    s1    = intarr(nrec) + 3
    s2    = intarr(nrec) - 7
    day   = ( ishft(word1,s1) or ishft(word2,s2) )
        
    s1    = intarr(nrec) + 20
    s2    = intarr(nrec) + 10
    msec  = ( ishft(word2 and '7F'XL,s1) or ishft(word3,s2) or word4 )

    mjul  = double(day) + (2449000.5 - 2400000.5) 	$
                        + double(msec)/86400./1000.

    if (nrec eq 1) then mjul = mjul(0)

    return, mjul

end        
