;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    YDS2SEC converts year, day, seconds to t68 seconds.
;
;--------------------------------------------------------------
; Function yds2sec
; 
; Converts from Year, Day, and Seconds of day to T68 seconds.
;
; Inputs:
;     year - 4-digit year, scalar or array
;     day  - day number, scalar or array
;     sec  - seconds of day, scalar or array
;
; Output:
;     sec - seconds since January 0, 1968 00:00.00000
;
; Written By: BA Franz, GSC, July 1996
;
;--------------------------------------------------------------
function yds2sec,year,day,sec

    common yds2sec_cmn, year_day

    if (n_elements(year_day) eq 0) then begin
        ;
        ; Make table of number of days since 1968
        ;
        year_day  = dblarr(2035-1968+1)
        for yr = 1969,2035 do begin
            i = yr - 1968
            if (leapchk(yr-1)) then			$
                year_day(i) = year_day(i-1) + 366	$
            else					$
                year_day(i) = year_day(i-1) + 365
        endfor
    endif

    i = year - 1968
    totsec = (year_day(i) + (day-1)) * 86400.D + sec

    return, totsec
end

