;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    YMDHMS2SEC converts year, month, day, hour, minute, seconds into t68 sec.
;
;----------------------------------------------------------------
; Function ymdhms2sec
;
; Converts, year, month, day, hour, minute, second format into T68 
; seconds. Inputs can be scalar or arrays of bytes.  Input month
; is 1-12 = Jan-Dec.
;
; Written by: BA Franz, GSC, 5 March 1996 
;----------------------------------------------------------------
function ymdhms2sec,year,month,day,hour,minute,second

    mdays = [0,31,59,90,120,151,181,212,243,273,304,334]

    ;
    ; Convert year to a zulu string
    ;
    zulu = strtrim(string(fix(year)),2)+'0010000000'

    ;
    ; Get T68 seconds to first day of year
    ; 
    sec  = timeconv(zulu,infmt='z',outfmt='s')

    ;
    ; Add additional seconds
    ;
    sec = sec + mdays(month-1)*86400. 	$
              + (day-1)*86400.		$
              + hour*3600.		$
              + minute*60.		$
              + second

    ;
    ; Adjust for leap years
    ;
    s = where((year mod 4 eq 0) and (month gt 2))
    if (s(0) ne -1) then $
        sec(s) = sec(s) + 86400.

    return,sec
end
