;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    Z2SEC converts a zulu time array, given a start time, and converts to sec.
;
;----------------------------------------------------------
; Function Z2SEC
;
; Interface to TIMECONV which takes in an array of zulu times and
; a zulu start time and returns an array of seconds since the
; specified start time.
;
; Written By:  BA Franz
;
; Inputs:
;     zulu     - array of zulu times
;     zstart  - optional start time in zulu format
;
; Outputs:
;     seconds - array of times in seconds since zstart
;
; Example:
;     seconds = z2sec(zulu,'19900010000')
;
;----------------------------------------------------------
;
function z2sec,zulu,zstart

if (n_params(0) eq 0) then begin
    print,' '
    print,'Usage:  seconds = zulu2sec(zulu,[zstart])'
    print,' '
    return,0
endif else if (n_params(0) gt 1) then begin
    tstart = timeconv(zstart,infmt='z',outfmt='s')
endif else begin
    tstart = 0.
endelse

sec = timeconv(zulu,infmt='z',outfmt='s') - tstart

return,sec
end
