;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    INDXTIME finds the nearest element of target array that precedes each
;    value of the input array.
;
;------------------------------------------------------------------------
;
; Function INDXTIME
;
; IDL function to find the nearest element of the target array which 
; precedes the value of each input array element. THE TARGET ARRAY MUST
; BE IN ASCENDING ORDER. This is useful for matching non-MF times to
; MF times (e.g., to allow correlation of IRS data from a BIT record with 
; engineering quantities from a MF).
;
; Written By:  BA Franz
; Date:        1-Nov-1991
;
; Inputs:
;   target     - Array to be indexed to.
;   input      - Input array.
;
; Outputs:
;   index       - Index array of "target" elements which precede the value 
;                of each input array element. 
;
;------------------------------------------------------------------------

function indxtime,input,target,istat

if (n_params(0) lt 2) then begin
    print,' '
    print,'Usage: index = indx_time(input_array,target_array)'
    print,' '
    return,-1
endif

npts  = n_elements(input)
jmax  = n_elements(target) - 1
index = lonarr(npts)

if (max(input) gt max(target)) then print,$
    'Indx_Time Warning: Input array is not within range of target..'

if (min(input) lt min(target)) then begin
    print,'Indx_Time Error: First element of input array is less than range of target..'
    return,-1
endif

j = 0
for i = 0L,npts-1 do begin
     if (i ne 0) then j = index(i-1)
     while((target(j) le input(i)) and (j lt jmax)) do j=j+1
     index(i) = j-1
endfor


return,index
end
