; 
; name:		loadsb.pro
; date:		5.17.2001
; author:	PJW, SSAI
; usage:	loadsb, file=[input file], struc=[output structure], hdrs=[file headers]
; 

pro loadsb, file=file, struc=struc, hdrs=hdrs, jd=jd

; store headers into a structure
hdrs = loadhdrs(file)
fields = hdrs.fields

; replace hyphens with underscores
while (((i = strpos(fields, '-'))) ne -1) do strput, fields, '_', i

; replace decimal points with underscores
while (((i = strpos(fields, '.'))) ne -1) do strput, fields, '_', i

; replace a*ph with asph
while (((i = strpos(fields, '*'))) ne -1) do strput, fields, 's', i

; build array of fields
fields = strsplit(strupcase(fields), ',', /extract)
ncols = n_elements(fields)

; find number of lines in the data file
nrows = nlines(file)

; get beyond headers
openr, lun, /get_lun, file
line = ''
repeat begin readf, lun, line
endrep until strmid(line,0,11) eq '/end_header'

; read data into string array and close file
data = strarr(nrows)
for i = 0L, nrows-1 do begin
	readf, lun, line
	if strtrim(line,2) ne '' then data[i] = line
endfor

free_lun, lun

sarr = ['STATION','CHORS_ID','SAMPLE','CRUISE','TYPE','FILE','INSTRUMENT']
ns = n_elements(sarr)

; create output structure
cmd = 'struc = {'
dateexists = 0
timeexists = 0

for i = 0L, ncols-1 do begin
	
	type = 'fltarr'
	for j = 0, ns-1 do if strpos(fields(i),sarr(j)) ne -1 then type = 'strarr' 

	if fields(i) eq 'DATE' THEN begin
		type = 'lonarr'
		dateexists = 1
	endif		

	if fields(i) eq 'TIME' THEN begin
		type = 'strarr'
		timeexists = 1
	endif
	
	if i eq ncols-1 then comma = '' else comma = ','
	column = fields(i) + ':' + type + '(' + string(nrows) + ')' + comma
	cmd = cmd + column

endfor

if dateexists eq 1 THEN begin
	year = ','+'YEAR'+':'+'intarr'+ '(' + string(nrows) + ')'
	month = ','+'MONTH'+':'+'intarr'+ '(' + string(nrows) + ')'
	day = ','+'DAY'+':'+'intarr'+ '(' + string(nrows) + ')'
	cmd = cmd + year + month + day
endif		

if timeexists eq 1 THEN begin
	hour = ','+'HOUR'+':'+'intarr'+ '(' + string(nrows) + ')'
	minute = ','+'MINUTE'+':'+'intarr'+ '(' + string(nrows) + ')'
	second = ','+'SECOND'+':'+'intarr'+ '(' + string(nrows) + ')'
	cmd = cmd + hour + minute + second
endif

; locate columns for jd calculation
iyy = -1
imm = -1
idd = -1

if keyword_set(jd) then begin

	for i = 0, ncols-1 do begin
		if strupcase(fields(i)) eq 'YEAR'  then iyy = i
		if strupcase(fields(i)) eq 'MONTH' then imm = i
		if strupcase(fields(i)) eq 'DAY'   then idd = i
	endfor

	cmd = cmd + ','+'JD'+':'+'lonarr'+ '(' + string(nrows) + ')'

endif
	
cmd = strcompress(cmd + '}', /remove_all)
void = execute(cmd)

; determine delimiter
delimiter = ' '
if hdrs.delimiter eq 'comma' then delimiter = ','

if keyword_set(jd) then struc.jd(*) = 0L

; read data array into structure
for i = 0L, nrows-1 do begin

	line = strsplit(strtrim(strcompress(data(i)),2), delimiter, /extract)

	for j = 0L, ncols-1 do begin

		; don't check for missing values in some columns
		for k = 0, ns-1 do begin
			if strpos(fields(j), sarr(k)) ne -1 then begin
				struc.(j)(i) = line(j)
				goto, next
			endif
		endfor

		if (fields(j) eq 'TIME') THEN BEGIN
			struc.hour(i)   = strmid(line(j),0,2)
			struc.minute(i) = strmid(line(j),3,2)
			struc.second(i) = strmid(line(j),6,2)
		ENDIF

		if (fields(j) eq 'DATE') THEN BEGIN
			struc.year(i)  = strmid(line(j),0,4)
			struc.month(i) = strmid(line(j),4,2)
			struc.day(i)   = strmid(line(j),6,2)
			if keyword_set(jd) then struc.jd(i) = ymd2jd(struc.year(i),struc.month(i),struc.day(i))
		ENDIF

		; check for missing values in all other columns
		struc.(j)(i) = !values.f_nan
		if line(j) ne hdrs.missing then struc.(j)(i) = line(j)

		next:
	endfor

	if keyword_set(jd) then begin
		
		if iyy ge 0 and imm ge 0 and idd ge 0 then $
		if line(iyy) ne hdrs.missing and line(imm) ne hdrs.missing and line(idd) ne hdrs.missing then $
		struc.jd(i) = ymd2jd(line(iyy),line(imm),line(idd)) 
			
	endif

endfor

; make depth and pressure increasing positive
depth_idx = tag_index(fields,'DEPTH')
if depth_idx ne -1 then struc.DEPTH = abs(struc.DEPTH)
pressure_idx = tag_index(fields,'PRESSURE')
if pressure_idx ne -1 then struc.PRESSURE = abs(struc.PRESSURE)

end
