;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    REMCHAR removes all appearances of a character from a string.
;
; NAME:
;    REMCHAR removes all appearances of a character from a string
;
; PURPOSE:
;    Remove all appearances of character (char) from string (st)
;
; CALLING SEQUENCE:
;    REMCHAR, ST, CHAR
;
; INPUTS:
;    ST  - String from which character will be removed.  
;    CHAR- Character to be removed from string. 
;
; EXAMPLE:
;    If a = 'a,b,c,d,e,f,g' then IDL> remchar,a, ','
;      will give a = 'abcdefg'
;
; REVISIONS HISTORY
;    Written D. Lindler October 1986
;    Test if empty string needs to be returned   W. Landsman  Feb 1991
;
;spr 10448
;.title
;Routine REMCHAR
;-
pro remchar,st,char	;Remove character
 bst = byte(st)                                 ;Convert string to byte

 bchar = byte(char) & bchar = bchar(0)          ;Convert character to byte

 good = where( bst NE bchar, Ngood)
 if Ngood GT 0 then st = string(bst(good)) else st = ''

 return
 end
;DISCLAIMER:
;
;This software was written at the Cosmology Data Analysis Center in
;support of the Cosmic Background Explorer (COBE) Project under NASA
;contract number NAS5-30750.
;
;This software may be used, copied, modified or redistributed so long
;as it is not sold and this disclaimer is distributed along with the
;software.  If you modify the software please indicate your
;modifications in a prominent place in the source code.  
;
;All routines are provided "as is" without any express or implied
;warranties whatsoever.  All routines are distributed without guarantee
;of support.  If errors are found in this code it is requested that you
;contact us by sending email to the address below to report the errors
;but we make no claims regarding timely fixes.  This software has been 
;used for analysis of COBE data but has not been validated and has not 
;been used to create validated data sets of any type.
;
;Please send bug reports to CGIS@COBECL.DNET.NASA.GOV.


