;+NAME/ONE LINE DESCRIPTION: 
;    REPCHR replaces one character with another in a text string.
;
; PURPOSE: 
;   Replace all occurences of one character with another
;   in a text string.   (Use the procedure REPSTR to replace
;   more than one character.)
;
; CALLING SEQUENCE: 
;   NEW = REPCHR(OLD, C1, [C2])
;
; INPUTS:
;   OLD = text string to edit, scalar or vector
;   C1 = character to replace.
; OPTIONAL INPUTS:
;   C2 = character to insert (def = ' ' = space).
;
; OUTPUTS:
;   NEW = edited string.
;
; EXAMPLE:
;   If OLD = 'THIS_IS_THE_TEXT', C1 = '_'
;   then NEW = REPCHR(OLD,C1) ==> NEW = 'THIS IS THE TEXT'
; MODIFICATION HISTORY: 
;   R. Sterner.  28 Oct, 1986.
; Vidya Sagar (ARC) Aug 1991
; Improved Help documentation 
;
;.TITLE
;Routine REPCHR
;-
FUNCTION REPCHR, OLD, C1, C2
B = BYTE(OLD)			   ; convert string to a byte array.
CB1 = BYTE(C1)			   ; convert char 1 to byte.
W = WHERE(B EQ CB1(0),NFOUND)	   ; find occurrences of char 1.
IF NFOUND EQ 0 THEN RETURN, OLD	   ; if none, return old string.
IF N_PARAMS(0) LT 3 THEN C2 = ' '  ; default char 2 is space.
CB2 = BYTE(C2)			   ; convert char 2 to byte.
B(W) = CB2(0)			   ; replace char 1 by char 2.
RETURN, STRING(B)		   ; return new string.
END
;DISCLAIMER:
;
;This software was written at the Cosmology Data Analysis Center in
;support of the Cosmic Background Explorer (COBE) Project under NASA
;contract number NAS5-30750.
;
;This software may be used, copied, modified or redistributed so long
;as it is not sold and this disclaimer is distributed along with the
;software.  If you modify the software please indicate your
;modifications in a prominent place in the source code.  
;
;All routines are provided "as is" without any express or implied
;warranties whatsoever.  All routines are distributed without guarantee
;of support.  If errors are found in this code it is requested that you
;contact us by sending email to the address below to report the errors
;but we make no claims regarding timely fixes.  This software has been 
;used for analysis of COBE data but has not been validated and has not 
;been used to create validated data sets of any type.
;
;Please send bug reports to CGIS@COBECL.DNET.NASA.GOV.


