;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    STRNUMBER determines if a string is a valid numeric value.
;
; NAME:
;   STRNUMBER
; PURPOSE:
;   Function to determine if a string is a valid numeric value.
; CALLING SEQUENCE:
;	result = strnumber( st, [val] )
; INPUTS:
;	st - string
; OUTPUTS:
;	1 is returned as the function value if the string st has a
;	valid numeric value, otherwise, 0 is returned.
; OPTIONAL OUTPUT:
;	val - (optional) value of the string.  real*8
; WARNING:
;    (1)   Note that (as of Version 2.2.2) a blank string (e.g. " ") is not
;          a valid numeric value, although an empty string ("") is.
;    (2)   As of V2.2.2 there is a bug in the IDL ON_IOERROR procedure that
;          will cause the following statement to hang up IDL
;
;            IDL> print,'' + string( strnumber('xxx') )
; HISTORY:
;	version 1  By D. Lindler Aug. 1987
;-
function strnumber,st,val
if N_params() EQ 0 then begin
     print,'Syntax - result = strnumber( st, [val] )
     return, 0
endif

On_IOerror,L1			;Go to L1 if conversion error occurs
val = double(st)
return, 1			;No conversion error
L1: return, 0			;Conversion error occured
end
;DISCLAIMER:
;
;This software was written at the Cosmology Data Analysis Center in
;support of the Cosmic Background Explorer (COBE) Project under NASA
;contract number NAS5-30750.
;
;This software may be used, copied, modified or redistributed so long
;as it is not sold and this disclaimer is distributed along with the
;software.  If you modify the software please indicate your
;modifications in a prominent place in the source code.  
;
;All routines are provided "as is" without any express or implied
;warranties whatsoever.  All routines are distributed without guarantee
;of support.  If errors are found in this code it is requested that you
;contact us by sending email to the address below to report the errors
;but we make no claims regarding timely fixes.  This software has been 
;used for analysis of COBE data but has not been validated and has not 
;been used to create validated data sets of any type.
;
;Please send bug reports to CGIS@COBECL.DNET.NASA.GOV.


