;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    UNIQUE_LIST converts a soprted array into a uniquely sorted array and
;    returns index range of each unique element in array.
;
;--------------------------------------------------------------------
; Procedure unique_list
;
; IDL procedure to convert a sorted array of elements into a sorted 
; array of unique elements and return the index range of each unique
; element within the original array.  This is useful when grouping
; pixel observations for averaging.
;
; Writen By: BA Franz
;
; Inputs:
;     inlist - input array of elements (must be sorted)
;
; Outputs:
;     outlist - output array of unique elements of inlist
;     index   - a 2xN_Unique array containing the index of the 1st and
;               last occurance of each element of outlist within inlist.
;
;--------------------------------------------------------------------
;
pro unique_list,inlist,outlist,index

nobs = n_elements(inlist)
index = lonarr(2,nobs)
outlist = inlist

i1 = 0L
count = 0L
for i = 1L,nobs-1 do begin
    if (inlist(i) ne inlist(i1)) then begin
        outlist(count) = inlist(i1)
        index(0:1,count) = [i1,i-1]
        count = count+1
        i1 = i
    endif
endfor
index(0:1,count) = [i1,nobs-1]
outlist(count) = inlist(i1)

outlist = outlist(0:count)
index = index(0:1,0:count)

return
end
