function applyftable, SDRfile1, LUTfile1, LUTfile2

; Apply ratio of f-tables to transform one radiance array into another.
; This routine attempts to apply high- or low-gain LUT values as appropriate.
; Gwyn Fireman, August 2012

; SDR1 was processed using LUT1.  Use the LUT2/LUT1 ratio to scale SDR1 into SDR2.
; SDR2/SDR1 = LUT2/LUT1
; SDR2 = (LUT2/LUT1) * SDR1


; load SDR & get dimensions
SDR1 = load_sdr(SDRfile1)
QF = SDR1.quality               ; [npix,ndet*nscan]
s = size(QF,/dim)
npix  = s[0]
ndet  = 16                      ; for M bands
nscan = s[1]/ndet

; load info for this band
band = SDR1.BAND
band_info=bandinfo()
i = where(band_info.band eq band)
gainswitch = band_info[i].Lmid

; load F-LUTs
LUT1 = load_ftable(LUTfile1,band) ; [MS,gain,det]
LUT2 = load_ftable(LUTfile2,band) ; MS 0=A, 1=B; gain 0=hi, 1=lo

; find correction factor to apply to each pixel
hilut = reform((LUT2/LUT1)[*,0,*]) ; high gain only -> [MS,det]
lolut = reform((LUT2/LUT1)[*,1,*]) ; low gain only  -> [MS,det]
hicorr = dblarr(npix,ndet,nscan) ; correction for each pixel
locorr = hicorr
for MS=0,1 do begin
  thisMS = where(SDR1.MS eq MS, nlines) ; MS 0=A, 1=B
  hicorr[*,*,thisMS] = rebin(hilut[MS,*],npix,ndet,nlines,/sample)
  locorr[*,*,thisMS] = rebin(lolut[MS,*],npix,ndet,nlines,/sample)
end

; find overall correction according to radiance level
higain = SDR1.radiance lt gainswitch ; high gain applies to low radiance
logain = 1-higain
corr = higain*hicorr + logain*locorr
corr = reform(corr,npix,ndet*nscan) ; restore image dimensions

; don't change value of bad pixels
bad = where(QF gt 1, nbad)
if nbad gt 0 then corr[bad] = 1

; apply to initial radiance
Lcorr = float(SDR1.radiance * corr)

return, Lcorr
end
