function bandinfo
; returns structure containing VIIRS band-related constants
; Gwyn Fireman, July 2012

; Radiance limits from:
;; VIIRS Radiometric Calibration Algorithm Theoretical Basis Document ATBD (ref Y3261)
;; Document Number: D43777
;; Revision: F
;; (aka)
;; ATBD VIIRS Radiometric Cal
;; 474-00027
;; Effective Date: February 15, 2012
;; Revision A

; Lmid = gain-switch radiance for dual-gain bands
;      = Lmax for single-gain bands

;	Band	λc (nm)	Lmin	Lmid	Lmax
data = ['M1	412	30	135	615	',$ ; Reflective Bands
        'M2	445	26	127	687	',$ ; spectral radiance in W m-2 sr-1 μm-1
        'M3	488	22	107	702	',$
        'M4	555	12	78	667	',$
        'M5	672	8.6	59	651	',$
        'M6	746	5.3	41.0	41.0	',$
        'M7	865	3.4	29	349	',$
        'M8	1240	3.5	164.9	164.9	',$
        'M9	1378	0.6	77.1	77.1	',$
        'M10	1610	1.2	71.2	71.2	',$
        'M11	2250	0.12	31.8	31.8	',$
        'I1	640	5	718	718	',$
        'I2	865	10.3	349	349	',$
        'I3	1610	1.2	72.5	72.5	',$
        'M12	3700	230	353	353	',$ ; Emissive Bands
        'M13	4050	230	634	634	',$ ; brightness temperature in K
        'M14	8550	190	336	336	',$
        'M15	10763	190	343	343	',$
        'M16	12013	190	340	340	',$
        'I4	3740	210	353	353	',$
        'I5	11450	190	340	340	']

bandstr = {bandinfo, $
           Band:'', Wcen:0, $
           Lmin:0.0, Lmid:0.0, Lmax:0.0, $
           Units:''}
nbands = n_elements(data)
bandinfo = replicate(bandstr, nbands)

for i=0,nbands-1 do begin
  v = strsplit(data[i],/extract)
  bandinfo[i] = {bandinfo, $
                 v[0],fix(v[1]), $
                 float(v[2]),float(v[3]),float(v[4]), $
                 ''}
endfor

RSB = where(bandinfo.wcen lt 3000, complement=TEB)
bandinfo[RSB].units = 'W m-2 sr-1 μm-1'
bandinfo[TEB].units = 'K'

return, bandinfo[sort(bandinfo.wcen)]
end
