function load_ftable, file, band
; load static VIIRS-SDR-F-LUT values from a binary file
; returns values for a single band, or bands M1-M11 if not specified
; Gwyn Fireman, July 2012

; define constants and dimensions
bands = ['I1','I2','I3','I4','I5', $
         'M1','M2','M3','M4','M5','M6','M7','M8', $
         'M9','M10','M11','M12','M13','M14','M15','M16', $
         'DNB']
NUM_VIIRS_BAND   = 22
MAX_NUM_DETECTOR = 32
MAX_NUM_GAIN     =  3
NUM_MIRROR_SIDES =  2

; read lut
lut = dblarr(NUM_MIRROR_SIDES,MAX_NUM_GAIN,MAX_NUM_DETECTOR,NUM_VIIRS_BAND)
openr, lun, /get_lun, file, /swap_if_little_endian
readu, lun, lut
free_lun, lun

; extract desired band(s)
if n_elements(band) ne 1 then begin
  b0 = where(bands eq 'M1')
  b1 = where(bands eq 'M11')
  newlut = lut[*,0:1,0:15,b0:b1] ; extract M1-M11

endif else begin
  b0 = where(bands eq band)
  ndets = strmid(band,0,1) eq 'M' ? 16 : 32
  newlut = lut[*,0:1,0:ndets-1,b0]
endelse

return, newlut
end
