function load_sdr, file
; Gwyn Fireman, May 2012

; read SDR data from a single file
info = read_viirs(file)

Q = info.QF1_VIIRSMBANDSDR
good = where(Q lt 2, complement=bad) ; lowest 2 bits: 0=good, 1=poor, 2=no calibration

; convert radiance and reflectance to physical values
L = info.radiance
if size(L,/tname) ne 'FLOAT' then begin
  f = info.radiancefactors
  L = float(L) * f[0] + f[1]
  L[bad] = info.radiance[bad]   ; de-scale bad values
endif
R = info.reflectance
if size(R,/tname) ne 'FLOAT' then begin
  f = info.reflectancefactors
  R = float(R) * f[0] + f[1]
  R[bad] = info.reflectance[bad] ; de-scale bad values
endif

; return values in a structure
return, { BAND: info.BAND_ID, $
          QUALITY: Q, $
          RADIANCE: L, $
          REFLECTANCE: R, $
          MS: info.QF2_SCAN_SDR, $ ; Half-Angle Mirror side A=0, B=1
          IET_BEG: info.N_BEGINNING_TIME_IET, $
          IET_END: info.N_ENDING_TIME_IET }
end
