; Read most VIIRS h5 files into a flat structure
; Gwyn Fireman, September 2011

;-----------------------------------------------------------
function clean_h5_str, struct

tags = tag_names(struct)
ntags = n_elements(tags)
cmd = ''

for i = 0, ntags-1 do begin
  tagname = tags(i)
  if (size(struct.(i),/type) eq 8) and (strmid(tagname,0,1) ne '_') then begin
    cmd += ','+tagname+':'
    nval = struct.(i)._NELEMENTS
    vals = '(struct.('+strtrim(i,2)+')._DATA)'
    cmd += (nval eq 1) ? vals+'[0]' : 'reform('+vals+')'
  endif
endfor

cmd = 'newstruct = {'+strmid(cmd,1)+'}'
result = execute(cmd)
return, newstruct
end

;-----------------------------------------------------------
function read_viirs, file

; read entire file
info = h5_parse(file,/read_data)

; get data product name and attributes
tags = tag_names(info.Data_Products)
itag = (where(strmid(tags,0,1) ne '_'))[0]
prod = tags[itag]
jtag = (where(tag_names(info.Data_Products.(itag)) eq prod+'_GRAN_0'))[0]
atts = info.Data_Products.(itag).(jtag)
name = info.Data_Products.(itag)._NAME

; get data
tags = tag_names(info.All_Data)
itag = (where(tags eq prod+'_ALL'))[0]
data = info.All_Data.(itag)

; clean up structures
atts = clean_h5_str(atts)
data = clean_h5_str(data)

; return concatenated structures
return, create_struct('_FILE',file, '_NAME',name, atts, data)
end
;-----------------------------------------------------------
