function read_viirs_lut, file, type=lut_type

; Read a VIIRS SDR binary lookup table
; Gwyn Fireman, November 2012

; check that file exists and is readable
finfo = file_info(file)
if not finfo.read then begin
  msg = 'File '+file+' '
  msg += finfo.exists ? 'cannot be read.' : 'does not exist.'
  print, msg
  return, -1
endif

; parse filename to find LUT type
if n_elements(lut_type) eq 0 then begin
  nameparts=stregex(file,'(VIIRS-.*)_npp_',/subexpr,/extract)
  if n_elements(nameparts) lt 2 then begin
    print, 'Cannot identify LUT type; specify TYPE keyword.'
    return, -1
  endif
  lut_type=nameparts[1]
endif

; define data structure according to LUT type
lut=define_viirs_lut(lut_type)

; read lookup table from binary file
openr, lun, /get_lun, file, /swap_if_little_endian
readu, lun, lut
free_lun, lun

return, lut
end
