;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    BOX_DRAW draws a box on display.
;
; NAME:	
;	BOX_DRAW
; PURPOSE:
;	Draws a box on the display.
; CATEGORY:
;	Display.
; CALLING SEQUENCE:
;	box_draw, x1, y1, x2, y2 [, color]
; INPUTS:
;	x1,y1 = lower left corner of the box
;	x2,y2 = upper right corner of the box
;	optional:
;	color = color used to draw box
; OUTPUTS:
;	none
; COMMON BLOCKS:
;	box
; SIDE EFFECTS:
; RESTRICTIONS:
;	For use with ZOOMW.
;	Intended for TV devices.
; PROCEDURE:
;	Straightforward.
; MODIFICATION HISTORY:	
;Frank Varosi NASA/GSFC 1989
;-
pro box_draw, x1,y1, x2,y2, color

  common box, Lox,Loy,Hix,Hiy, sav_Horiz_B, sav_Horiz_T, sav_Vert_L, sav_Vert_R

	Lox = (x1 < x2)
	Loy = (y1 < y2)

	Hix = (x1 > x2)
	Hiy = (y1 > y2)

	xsiz = Hix - Lox +1
	ysiz = Hiy - Loy +1

	sav_Horiz_B = tvrd( Lox,Loy, xsiz,1 )
	sav_Horiz_T = tvrd( Lox,Hiy, xsiz,1 )

	sav_Vert_L = tvrd( Lox,Loy, 1,ysiz )
	sav_Vert_R = tvrd( Hix,Loy, 1,ysiz )

	if N_elements( color ) NE 1 then  color = !D.n_colors-1
	color = byte( color )

	horiz = replicate( color, xsiz, 1 )
	vert = replicate( color, 1, ysiz )

	tv, horiz, Lox,Loy
	tv, vert, Lox,Loy
	tv, horiz, Lox,Hiy
	tv, vert, Hix,Loy

return
end
