;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    CAPTION inserts a caption on a plot.
;
;-------------------------------------------------------------------
; Procedure CAPTION
;
; IDL procedure to insert a caption on a plot.  The caption will be
; centered on the page regardless of the value of p.multi.
;
; Written By: BA Franz
;
; Inputs:
;    text - string containing the caption
;    yloc - vertical location of the caption in normalized device units.
;           (0.98=Top of Page, 0.02=Bottom, Default=0.98)
;
;-------------------------------------------------------------------
;     
pro caption,text,yloc,size=size

;
; Need data coords on linear scale
;
save_x    = !x.type
save_y    = !y.type
!x.type = 0    ; Linear plot scale
!y.type = 0    ; Linear plot scale

if (n_elements(size) eq 0) then size=!p.charsize

;
; Get lower left and upper right of device window
;
ll = [0,0]
ur = [!d.x_vsize,!d.y_vsize]

;
; Locate desired caption position
;
if (n_elements(yloc) eq 0) then yloc = 0.98
xs = ll(0) + 0.50*(ur(0)-ll(0))
ys = ll(1) + yloc*(ur(1)-ll(1))

;
; Write text to window
;
xyouts,xs,ys,text,size=size,align=0.5,/dev

;
; Reset axis scale
;
!x.type = save_x
!y.type = save_y

return
end
