;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    DIRBE_SLICE provide overlay outline of DIRBE IP galactic slice for use 
;    with either greyscales or contours, here for unfolded cube only.
;
;From:	COBECL::STEMWEDEL    20-SEP-1992 22:37:55.66
;To:	WEILAND,TOLLER
;CC:	
;Subj:	DIRBE IP outline
;
;Janet, Gary:
;
;Have devised an outline of the unfolded cube (right) and the DIRBE IP
;Galactic slice to overlay on greyscale images, maybe even contours of IP.
;
;Some refinement will be necessary to get it to fit greys exactly.  
;
;The UIMAGE contours of unfolded cubes currently have axes that drive
;me nuts (1200 x 800, with hash marks irrelevant to cube faces).  I 
;hope you can suggest something like this overlay as a better presentation.
;
;Please try this, and send suggestions.  Thanks.
;Sally
;-----------------------------------------------------------------------------------
;
pro dirbe_slice
;
; provide overlay outline of DIRBE IP galactic slice for use with either 
;    greyscales or contours, here for unfolded cube only
; ***needs to be sized, positioned to overlay on greyscale****
;
; make coord array
;
gncoor=fltarr(368,2)
gscoor=fltarr(368,2)
for i=0,30 do begin
gncoor(i,0)=float(i)
gncoor(i,1)=15.
gscoor(i,0)=float(i)
gscoor(i,1)=-15.
endfor
for i=330,359 do begin
gncoor(i,0)=float(i)
gncoor(i,1)=15.
gscoor(i,0)=float(i)
gscoor(i,1)=-15.
endfor
for i=31,329 do begin
gncoor(i,0)=float(i)
gncoor(i,1)=10.
gscoor(i,0)=float(i)
gscoor(i,1)=-10.
endfor
for i=0,3 do begin
gncoor(360+i,0)=30. 
gncoor(360+i,1)=11.+float(i)
gncoor(364+i,0)=330.
gncoor(364+i,1)=11.+float(i)
gscoor(360+i,0)=30. 
gscoor(360+i,1)=-11.-float(i)
gscoor(364+i,0)=330.
gscoor(364+i,1)=-11.-float(i)
endfor
;
; convert coordinates of outline to pixels and pixels to raster positions
gnpix=coorconv(gncoor,infmt='L',inco='G',outfmt='P',outco='B')
gspix=coorconv(gscoor,infmt='L',inco='G',outfmt='P',outco='B')
pix2xy,gnpix,nx,ny,res=9
pix2xy,gspix,sx,sy,res=9
;
; set up matching face number vectors from pixel numbers
nf=bytarr(n_elements(gnpix))
sf=bytarr(n_elements(gspix))
nf(where(gnpix lt 65536))=0
nf(where(gnpix ge 131072 and gnpix lt 196608))=2
nf(where(gnpix ge 262144 and gnpix lt 327680))=4
nf(where(gnpix ge 327680))=5
sf(where(gspix lt 65536))=0
sf(where(gspix ge 131072 and gspix lt 196608))=2
sf(where(gspix ge 262144 and gspix lt 327680))=4
sf(where(gspix ge 327680))=5
;
; use raster positions to fill a byte array
outarr=bytarr(1024,768)
for i=0,367 do begin
outarr(nx(i),ny(i))=2
outarr(sx(i),sy(i))=2
endfor
;
; add to array outline of unfolded cube
for i=0,767 do begin
outarr(i,255)=1
outarr(i,511)=1
outarr(1023,i)=1
endfor
for i=0,255 do begin
outarr(i+767,0)=1
outarr(i+767,767)=1
outarr(0,i+255)=1
outarr(767,i)=1
outarr(767,i+511)=1
endfor
;
; set up face edge mark position vectors
xmark=[255,255,511,511,767,767,1023,1023]
ymark=[255,511,255,511,255,511,255,511]
;
; set terminal type, and basic plot parameters
; set_plot,'tek'                    ; commented out by JP for adaptability
!p.position=[0.,1.0,0.0,0.75]
!x.style=-1
!y.style=-1
!x.range=[0,1024]
!y.range=[0,768]
contour,outarr,levels=[1,2]
oplot,xmark,ymark,psym=1,symsize=1.2

return
end
