;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    MAPSCENE adds a map overlay to a particular image.
;
function mapscene,scene,lon,lat,npix,lonrange=lonrange,latrange=latrange,continents=continents

    if (n_elements(lonrange) eq 0) then begin
        lonmin = min(lon)
        lonmax = max(lon)
    endif else begin
        lonmin = float(lonrange(0))
        lonmax = float(lonrange(1))
    endelse

    if (n_elements(latrange) eq 0) then begin
        latmin = min(lat)
        latmax = max(lat)
    endif else begin
        latmin = float(latrange(0))
        latmax = float(latrange(1))
    endelse

    aspect = (lonmax-lonmin)/(latmax-latmin)

    nlon = npix
    nlat = long(nlon/aspect)
    
    dlon = (lonmax - lonmin)/nlon
    dlat = (latmax - latmin)/nlat

    s = size(scene)
    case (s(n_elements(s)-2)) of
        4 : map  = fltarr(nlon,nlat)
        3 : map  = lonarr(nlon,nlat)
        2 : map  = intarr(nlon,nlat)
        else : map  = bytarr(nlon,nlat)
    endcase

    ix = (lon - lonmin)/dlon
    iy = (lat - latmin)/dlat
help,ix,iy,scene,lon,lat

    map(ix,iy) = scene

    if (keyword_set(continents)) then begin

        savedev = !d.name
        set_plot,'z'
        device,set_resolution=[nlon,nlat]

        pos = [0.,0.,1.,1.]
        limit=[latmin,lonmin,latmax,lonmax]
        p0lat = 0.
        p0lon = 0.
        MAP_SET, p0lat, p0lon, /CYL, POSITION=pos, LIMIT=limit, $
                         /NOBORDER
        tv,map
        map_continents,/hires,color=254
;        map_grid
        map = tvrd()
        set_plot,savedev

    endif

    return,map
end


