;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    ORIG_DATE annotates a plot with the origination date and originator if
;    specified.
;
;---------------------------------------------------------------
; Procedure ORIG_DATE
;
; IDL procedure to annotate a plot with the origination date and,
; optionally, the name of the originator.  Places the label on 
; the lower left corner of the device window.
;
; Written By:  BA Franz
; Date:        08 April 1992
;
;---------------------------------------------------------------
;
pro orig_date,name,time=time,bottom=bottom

if (n_params(0) eq 0) then name = ''

save_font = !p.font
save_x    = !x.type
save_y    = !y.type

!p.font = -1   ; Need vector-drawn fonts
!x.type = 0    ; Linear plot scale
!y.type = 0    ; Linear plot scale

;
; Get system date/time
;
if (not keyword_set(time)) then begin
    date  = systime(0)
    date  = strmid(date,4,6)+', '+strmid(date,20,4)
endif else date = get_systime(/vax)

;
; Get corners of device window in data coords
;
ll = convert_coord([0,0],/device,/to_data) 
ur = convert_coord([!d.x_vsize,!d.y_vsize],/device,/to_data) 

;
; Write Date
;
xs = ur(0)
ys = ll(1)
xyouts,xs,ys,date,siz=0.5,align=1

;
; Write Name
;
if (keyword_set(bottom)) then begin
    xs = ll(0)
    ys = ll(1)
    xyouts,xs,ys,name,siz=0.5,align=0
endif else begin
    xs = ur(0)
    ys = ll(1) + 0.02*(ur(1)-ll(1))
    xyouts,xs,ys,name,siz=0.5,align=1
endelse

!p.font = save_font
!x.type = save_x
!y.type = save_y

return
end
