;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SHOW_IMAGE displays a given input image.
;
pro show_image,map,bad_data=bad_data,range=range, $
    title=title,subtitle=subtitle,log=log,noint=noint,gif=gif,ps=ps

if (n_elements(bad_data) eq 0) then bad_data = -9999.
if (n_elements(title   ) eq 0) then title = ''
if (n_elements(subtitle) eq 0) then subtitle = ''
if (n_elements(gif     ) eq 0) then gif = ''
if (n_elements(ps      ) eq 0) then ps = ''

if (gif ne '' or ps ne '') then begin
    savedev = !d.name
    set_plot,'z'
    tvlct,r,g,b,/get
endif

;
; Get image parameters
;
s    = size(reform(map))
ndim = s(0)
nx   = s(1)
ny   = s(2)

xsize = nx
ysize = ny+90

if (!d.name eq 'WIN' or !d.name eq 'X') then begin
    window,/free,xsize=xsize,ysize=ysize
endif

if (!d.name eq 'Z') then begin
    device,set_resolution=[xsize,ysize]
    erase
endif

ximage = nx
yimage = ny
image  = reform(map)

if (keyword_set(log)) then begin
    s = where(image le 0.01)
    image(s) = -100.0
    s = where(image gt 0.01)
    image(s) = alog10(image(s))
endif

if (n_elements(range) ne 2) then begin
    select = where(map gt bad_data)
    mx = max(map(select))
    mn = min(map(select))
endif else begin
    mx = range(1)
    mn = range(0)
endelse

tv,bytscl(image,mn,mx),0,0
c = textcolor()

xyouts,/dev,0.15*xsize,ysize-20,color=c,align=0.5,strtrim(string(mn,format='(f10.3)'),2),size=0.7
xyouts,/dev,0.85*xsize,ysize-20,color=c,align=0.5,strtrim(string(mx,format='(f10.3)'),2),size=0.7
xyouts,/dev,10,ysize-50,color=c,align=0,title,size=0.8
xyouts,/dev,10,ysize-70,color=c,align=0,subtitle,size=0.8

bar

if (ps ne '' or gif ne '') then begin
    img = tvrd()
    if (gif ne '') then begin
        write_gif,gif,img,r,g,b
    endif
    if (ps ne '') then begin
        pstek2sd,img,rc=r,gc=g,bc=b,out=ps
    endif
    set_plot,savedev
endif

return
end


