;+NAME/ONE LINE DESCRIPTION OF ROUTINE:
;    SHOW_MAP displays an input map.
;
pro show_map,map,bad_data=bad_data,range=range,title=title,log=log,noint=noint

if (n_elements(bad_data) eq 0) then bad_data = -100.
if (n_elements(title) eq 0)    then title = ''

;
; Get image parameters
;
s    = size(map)
ndim = s(0)
nx   = s(1)
ny   = s(2)

if (nx le 512) then       $
    xsize = 512           $
else if (nx le 1024) then $
    xsize = nx            $
else begin
    print,'Dimensions of input map = ',nx,' x ',ny
    print,'Max dimension must be less than 1024'
    return
endelse

if (ny le 512) then  $
    ysize = 600           $
else if (ny le 768) then  $
    ysize = 768           $
else begin
    print,'Dimensions of input map = ',nx,' x ',ny
    print,'Max dimension must be less than 1024 x 768'
    return
endelse

if (!d.name eq 'WIN' or !d.name eq 'X') then begin
    window,/free,xsize=xsize,ysize=ysize
endif

f = min([fix(xsize/nx),fix(ysize/ny)])
ximage = f*nx
yimage = f*ny

if (keyword_set(noint)) then $
    image = rebin(map,ximage,yimage,/sample) $
else $
    image = rebin(map,ximage,yimage)

if (keyword_set(log)) then begin
    s = where(image le 0.01)
    image(s) = -100.0
    s = where(image gt 0.01)
    image(s) = alog10(image(s))
endif

if (n_elements(range) ne 2) then begin
    select = where(map gt bad_data)
    mx = max(map(select))
    mn = min(map(select))
endif else begin
    mx = range(1)
    mn = range(0)
endelse

tv,bytscl(image,mn,mx),0,0

xyouts,/dev,0.15*xsize,0.95*ysize,color=200,align=0.5,strtrim(string(mn,format='(f7.3)'),2)
xyouts,/dev,0.85*xsize,0.95*ysize,color=200,align=0.5,strtrim(string(mx,format='(f7.3)'),2)
xyouts,/dev,0.50*xsize,0.90*ysize,color=200,align=0.5,title,size=1

bar

return
end


