/*  Create digital file with scanline number from BDS  */
/*  07/01/97 Kam-Pui Lee   */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
/* #include <export.h> */
 
#include <hdf.h>
#include "HDF_Interface.h"

#define Conv_Digital1_Vdata_Name "Converted Digital Data"
#define Conv_Digital_Vdata_Name "Converted Instrument Status Data"
#define Raw_Digital1_SDS_Name "BDS Raw Digital Status Measurement"
#define Raw_Digital_SDS_Name "Raw Instrument Status Data"
#define QA_Flags1_SDS_Name "BDS Quality Flags"
#define QA_Flags_SDS_Name "Radiance and mode flags"
#define Time_Indices_SDS_Name "Julian Date and Time"

/* #define Digital_Location_File "/CERES/instrument/data/ancillary/static/Digital_Location.file" */
/* #define Digital_Location_File "/CERES/scratch/kplee/snap/Digital_Location.file" */
#define Digital_Location_File "Digital_Location.file"
#define DEFAULT_DIGITAL_NAME "digital_data.dat"

#define DIGITAL_WORD_COUNT 185
#define MAX_FIELD 240
#define MAX_SAMPLE 660
#define MAX_QA 10
#define MAX_AQA1 12
#define MAX_AQA2 10

typedef struct Converted_Digital_Record_Definition
{
  uint16 Packet_Counter;
} Converted_Digital_Record;

typedef struct Digital_Data_Record_Definition
{
  char name[50];
  int32 word_number;
  int32 first_bit;
  int32 last_bit;
  int32 note;
  int32 position;
} Digital_Data_Record;

typedef struct Out_Record_Definition
{
  char name[50];
  int32 position;
} Out_Record;
 
typedef struct {
   unsigned short slen;         /* length of the string         */
   short stype;                 /* Type of string               */
   char *s;                     /* Pointer to chararcter array  */
} STRING;

typedef struct QA_Flag_Record_Definition
{
  char name[50];
  int32 first_bit;
  uint32 mask;
} QA_Flag_Record;

 
/* ===========================================================================
GLOBAL VARIABLE Declarations
============================================================================*/
HDF BDS_HDF;
SD BDS_SD;
Vdata Conv_Digital;
SDS Time_Indices;
SDS Raw_Digital;
SDS QA_Flags;

int32 BDS_Total_Records;

Converted_Digital_Record *Converted_Digital_Table;
float64 (*Julian_Times_Array)[2];
int32 (*Digital_Data_Variables)[MAX_FIELD];
uint32 (*QA_Flags_Array)[MAX_SAMPLE];
char *BDS_File_Name;

/* ===========================================================================
FUNCTION PROTOTYPING
============================================================================*/
int32 get_note(int32 note , int32 para1, char ninfo[]);
void Error_Message(char *Message);
void Initialize(void);
void Initialize_Vdata(Vdata *Vdata_In);
void Initialize_SDS(SDS *SDS_In);
void Open_BDS(char *File_Name);
int Close_BDS(void);
int Open_Vdata(Vdata *Vdata_In);
void Close_Vdata(Vdata *Vdata_In);
int Open_SDS(SDS *SDS_In);
void Close_SDS(SDS *SDS_In);
int Close_and_Exit(void);
BOOLEAN Structures_Match(void);
BOOLEAN Build_Data_Arrays(void);
void Free_Data_Arrays(void);
int Initialize_Read_Vdata(Vdata *Vdata_In);
int Read_CD_Vdata(Vdata *Vdata_In);
int Read_JT_SDS(SDS *SDS_In);
int Read_SDS(SDS *SDS_In, void *Data_Array);
int Open_All_BDS_Structures(void);
Digital_Data_Record Read_Digital_Location_File(int32 index, int32 instr_id, int32 *number_variables);
uint16 Assign_Digital_Mask_Value(Digital_Data_Record Digital_Data_Inform);
QA_Flag_Record Assign_QA_Mask_Value(int32 index);
QA_Flag_Record Assign_AQA1_Mask_Value(int32 index);
QA_Flag_Record Assign_AQA2_Mask_Value(int32 index);

/* ===========================================================================
PROGRAM get_digital_data
============================================================================*/
int get_digital_data(int argc, void *argv[])
{

int32 number_variables;
int32 Array_Size;
int32 Record_Size;
int Main_Status = 0;
int32 i, j, k;
uint16 Digital_Word;
uint16 Digital_Value;
int32 word_number;
int32 first_bit;
int32 Digital_Data_Var;
size_t length;
Digital_Data_Record Digital_Data_Inform;
uint16 variable_mask;
uint16 (*Digital_Data_Array)[DIGITAL_WORD_COUNT];
uint8 *ptr_int32;
STRING *filename;
int32 *index;
int32 *num_record;
int32 *instr_id;
void *output_data;

    if(argc != 5)
    {
       fprintf(stderr,"get_digital_data: Incorrect number of arguments\r\n");
       return(-1);  /* Signal an error */
    }

    filename        =(STRING *)argv[0];
    index      	    =(int32 *)argv[1];
    num_record 	    =(int32 *)argv[2];
    instr_id        =(int32 *)argv[3];
    output_data     =(void *) argv[4];

  length = strlen(filename->s);
  BDS_File_Name = malloc(length + 1);
  if(BDS_File_Name == NULL)
  {
    fprintf(stderr, "Unable to allocate memory for BDS_File_Name.\n");
    return (-1);
  }

  strcpy(BDS_File_Name, filename->s);

  if (!Hishdf(BDS_File_Name))
  {
    fprintf(stderr, "ERROR - specified file is not an HDF file.\n");
    return (-1);
  }
    strcpy(Raw_Digital.Name, Raw_Digital_SDS_Name);
    Initialize_SDS(&Raw_Digital);
    Open_BDS(BDS_File_Name);

    if (!Open_SDS(&Raw_Digital))
    {
      strcpy(Raw_Digital.Name, Raw_Digital1_SDS_Name);
      Initialize_SDS(&Raw_Digital);
      if (!Open_SDS(&Raw_Digital))
      {
	 Error_Message("ERROR - Unable to open Raw_Digital SDS.");
	 Close_and_Exit();
      }
    }

    BDS_Total_Records = Raw_Digital.Rows;
 
    Array_Size = sizeof(uint16) * DIGITAL_WORD_COUNT;
    Digital_Data_Array = calloc(*num_record, Array_Size);
    if (Digital_Data_Array == NULL)
    {
      Error_Message("ERROR - Unable to allocate Digital_Data_Array.");
      Close_and_Exit();
    }

    if( Raw_Digital.Columns != DIGITAL_WORD_COUNT)
    {
      fprintf(stderr, "ERROR - The number of words (%d) in Raw Digital Data is wrong!\n", \
        Raw_Digital.Columns);
      free(Digital_Data_Array);
      Close_and_Exit();
    }

      /* ======================================================================
	 BEGIN MAIN PROCESSING CODE HERE
      =======================================================================*/

      Main_Status = Read_SDS(&Raw_Digital, (*Digital_Data_Array));
      if (Main_Status == FAILURE)
      {
	fprintf(stderr, "ERROR - Unable to read Raw_Digital SDS.\n");
	free(Digital_Data_Array);
	return(-1);
      }

      Digital_Data_Inform = Read_Digital_Location_File(*index, *instr_id, &number_variables);
      if (Digital_Data_Inform.word_number < 0)
      {
	 fprintf(stderr, "ERROR - Unable to read Digital variable names.\r\n");
	 free(Digital_Data_Array);
	 return(-1);
      }

      if (number_variables > MAX_FIELD)
      {
	 fprintf(stderr, "ERROR - The number (%d) of Digital variable is wrong.\r\n", \
            number_variables);
	 free(Digital_Data_Array);
	 return(-1);
      }

      variable_mask = Assign_Digital_Mask_Value(Digital_Data_Inform);

      Record_Size = sizeof(int32);
      ptr_int32 = (uint8 *)output_data;
      for (i = 0 ; i < *num_record ; i++)
      {
         word_number = Digital_Data_Inform.word_number;
         first_bit = Digital_Data_Inform.first_bit;
	 Digital_Word = Digital_Data_Array[i][word_number];
	 Digital_Value = Digital_Word & variable_mask;
	 switch(*index)
	 {
		case 104:
		case 107:
		case 108:
		case 109:
		case 168:
		case 184:
	 	    Digital_Data_Var = (int32)((int16)(Digital_Value >> first_bit));
		    break;
		default:
	 	    Digital_Data_Var = (int32)(Digital_Value >> first_bit);
	 }
	 memcpy(ptr_int32, &Digital_Data_Var, Record_Size);
	ptr_int32 += Record_Size;
      }

      free(Digital_Data_Array);
      Close_BDS();

     return (0);

} 

/* ===========================================================================
PROGRAM get_quality_flags
============================================================================*/
int get_quality_flags(int argc, void *argv[])
{

int32 Array_Size;
int32 Record_Size;
int Main_Status = 0;
int32 i, j, k;
uint32 Quality_Word;
uint32 Quality_Value;
int32 first_bit;
int32 Quality_Flag_Var;
int which_qa, max_flag;
uint32 temp_mask;
size_t length;
int32 start[2], end[2], increment[2];
QA_Flag_Record QA_Flag_Inform;
uint32 (*QA_Flag_Array)[MAX_SAMPLE];
uint8 *ptr_int32;
STRING *filename;
STRING *sds_name;
int32 *index;
int32 *num_record;
int32 *rank;
int32 *start_list;
int32 *end_list;
int32 *increment_list;
int32 *the_count;
void *output_data;

    if(argc != 10)
    {
       fprintf(stderr,"get_quality_flags: Incorrect number of arguments\r\n");
       return(-1);  /* Signal an error */
    }

    filename        =(STRING *)argv[0];
    sds_name        =(STRING *)argv[1];
    index      	    =(int32 *)argv[2];
    num_record 	    =(int32 *)argv[3];
    rank	    =(int32 *)argv[4];
    start_list	    =(int32 *)argv[5];
    end_list	    =(int32 *)argv[6];
    increment_list  =(int32 *)argv[7];
    the_count       =(int32 *)argv[8];
    output_data     =(void *) argv[9];


  for(i = 0 ; i < 2 ; i++)
  {
    start[i] = start_list[i];
    end[i] = end_list[i];
    increment[i] = increment_list[i];
  }

  if(! strcmp(sds_name->s, "Ancillary QA Flags Set 1") ) which_qa = 2;
  else if(! strcmp(sds_name->s, "Ancillary QA Flags Set 2") ) which_qa = 3;
  else which_qa = 1;

  switch (which_qa)
  {
	case 2:
		max_flag = MAX_AQA1;
		break;
	case 3:
		max_flag = MAX_AQA2;
		break;
	default:
		max_flag = MAX_QA;
  }

/*  if(*index > MAX_QA) */
  if(*index > max_flag)
  {
    fprintf(stderr, "Index is out of the rane.\n");
    return (-1);
  }

  length = strlen(filename->s);
  BDS_File_Name = malloc(length + 1);
  if(BDS_File_Name == NULL)
  {
    fprintf(stderr, "Unable to allocate memory for BDS_File_Name.\n");
    return (-1);
  }

  strcpy(BDS_File_Name, filename->s);

  if (!Hishdf(BDS_File_Name))
  {
    fprintf(stderr, "ERROR - specified file is not an HDF file.\n");
    return (-1);
  }

    strcpy(QA_Flags.Name, sds_name->s);
/*    printf("sds name = %s\n",sds_name->s); */
/* strcpy(QA_Flags.Name, QA_Flags_SDS_Name); */
    Initialize_SDS(&QA_Flags);
    Open_BDS(BDS_File_Name);

    if (!Open_SDS(&QA_Flags))
    {
/*
      strcpy(QA_Flags.Name, QA_Flags1_SDS_Name);
      Initialize_SDS(&QA_Flags);
      if (!Open_SDS(&QA_Flags))
      {
*/
	 Error_Message("ERROR - Unable to open QA_Flags SDS.");
	 Close_and_Exit();
/*     } */
    }

    BDS_Total_Records = QA_Flags.Rows;
 
    Array_Size = sizeof(uint32) * MAX_SAMPLE;
    QA_Flag_Array = calloc(BDS_Total_Records, Array_Size);
    if (QA_Flag_Array == NULL)
    {
      Error_Message("ERROR - Unable to allocate QA_Flag_Array.");
      Close_and_Exit();
    }

      /* ======================================================================
	 BEGIN MAIN PROCESSING CODE HERE
      =======================================================================*/

      Main_Status = Read_SDS(&QA_Flags, (*QA_Flag_Array));
      if (Main_Status == FAILURE)
      {
	fprintf(stderr, "ERROR - Unable to read QA_Flags SDS.\n");
	free(QA_Flag_Array);
	return(-1);
      }

      switch (which_qa)
      {
	case 2:
		QA_Flag_Inform = Assign_AQA1_Mask_Value(*index);
		break;
	case 3:
		QA_Flag_Inform = Assign_AQA2_Mask_Value(*index);
		break;
	default:
		QA_Flag_Inform = Assign_QA_Mask_Value(*index);
      }

      Record_Size = sizeof(int32);
      ptr_int32 = (uint8 *)output_data;
      first_bit = QA_Flag_Inform.first_bit;
      temp_mask = QA_Flag_Inform.mask;

      for (i = start[0] ; i < end[0] ; i += increment[0])
      {
	for(j = start[1] ; j < end[1] ; j += increment[1])
	{
	   Quality_Word = QA_Flag_Array[i][j];
	   Quality_Value = Quality_Word & temp_mask;
	   Quality_Flag_Var = (Quality_Value >> first_bit);
	   memcpy(ptr_int32, &Quality_Flag_Var, Record_Size);
	  ptr_int32 += Record_Size;
	}
      }

      free(QA_Flag_Array);
      Close_BDS();

     return (0);

} 

/* ============================================================================
PROCEDURE get_note
=============================================================================*/
int32 get_note(int32 note , int32 para1, char ninfo[])
{

  int32 para2;

  para2 = 0;
  switch(note)
  {
     case 20:
     {
        switch(para1)
        {
	  case 0:
	    strcpy(ninfo, "No Command ICP");
	    return para2;
	  case 256: 
	    strcpy(ninfo, "Command Azimuth Goto Position");
            para2 = 302;
	    return para2;
	  case 512:
	    strcpy(ninfo, "Set Azimuth Fixed Crosstrack");
	    return para2;
	  case 513:
	    strcpy(ninfo, "Set Azimuth Fixed Position A");
	    return para2;
	  case 514:
	    strcpy(ninfo, "Set Azimuth Fixed Position B");
	    return para2;
	  case 515:
	    strcpy(ninfo, "Set Azimuth Fixed SolarCal");
	    return para2;
	  case 516:
	    strcpy(ninfo, "Set Azimuth Fixed Caged");
            return para2;
	  case 517:
	    strcpy(ninfo, "Set Azimuth Fixed Spare 1");
	    return para2;
	  case 518:
	    strcpy(ninfo, "Set Azimuth Fixed Contamination Pos");
	    return para2;
	  case 519:
	    strcpy(ninfo, "Set Azimuth Fixed Spare 3");
	    return para2;
	  case 768:
	    strcpy(ninfo, "Set Azimuth Rate Goto Rate");
	    return para2;
	  case 769:
	    strcpy(ninfo, "Set Azimuth Rate Async Rate");
	    return para2;
	  case 770:
	    strcpy(ninfo, "Set Azimuth Rate Sync Rate");
	    return para2;
	  case 1024:
	    strcpy(ninfo, "Command Brake");
	    para2 = 303;
	    return para2;
	  case 1280:
	    strcpy(ninfo, "Step Brake To Caged");
	    return para2;
	  case 1536:
	    strcpy(ninfo, "Step Brake To Applied");
	    return para2;
	  case 4096:
	    strcpy(ninfo, "Set Instrument Mode");
	    para2 = 304;
	    return para2;
	  case 4352:
	    strcpy(ninfo, "Set Safehold Response A");
	    para2 = 305;
	    return para2;
	  case 4353:
	    strcpy(ninfo, "Set Safehold Response B");
	    para2 = 305;
	    return para2;
	  case 4608:
	    strcpy(ninfo, "Set SPS1 Response");
	    para2 = 306;
	    return para2;
	  case 4609:
	    strcpy(ninfo, "Set SPS2 Response");
	    para2 = 306;
	    return para2;
	  case 4864:
	    strcpy(ninfo, "Set SPS1 Threshold Noise");
	    return para2;
	  case 4865:
	    strcpy(ninfo, "Set SPS2 Threshold Noise");
	    return para2;
	  case 5120:
	    strcpy(ninfo, "Set SPS1 Threshold Numerator");
	    return para2;
	  case 5121:
	    strcpy(ninfo, "Set SPS2 Threshold Numerator");
	    return para2;
	  case 5376:
	    strcpy(ninfo, "Set SPS1 Threshold Count");
	    return para2;
	  case 5377:
	    strcpy(ninfo, "Set SPS2 Threshold Count");
	    return para2;
	  case 5632:
	    strcpy(ninfo, "Set Scan Timeout Response");
	    para2 = 307;
	    return para2;
	  case 5888:
	    strcpy(ninfo, "Set Scan Timeout Count");
	    return para2;
	  case 6400:
	    strcpy(ninfo, "Set Quicklook Flag");
	    para2 = 308;
	    return para2;
	  case 6656:
	    strcpy(ninfo, "Select Time Mark Frequency Bus");
	    para2 = 319;
	    return para2;
	  case 6912:
	    strcpy(ninfo, "Set Time Mark Interrup Response");
	    para2 = 320;
	    return para2;
	  case 7168:
	    strcpy(ninfo, "Set IMOK Signal Response");
	    para2 = 320;
	    return para2;
	  case 7680:
	    strcpy(ninfo, "Set Watchdog Timer ICP");
	    para2 = 300;
	    return para2;
	  case 7936:
	    strcpy(ninfo, "Set PROM Power ICP");
	    para2 = 301;
	    return para2;
	  case 8192:
	    strcpy(ninfo, "Set Mem Dump Start Offset ICP");
	    return para2;
	  case 8448:
	    strcpy(ninfo, "Set Mem Dump Start Segment ICP");
	    return para2;
	  case 8704:
	    strcpy(ninfo, "Set Mem Dump End Offset ICP");
	    return para2;
	  case 8960:
	    strcpy(ninfo, "Set Mem Dump End Segment ICP");
	    return para2;
	  case 9728:
	    strcpy(ninfo, "Set Azimuth Encoder LED");
	    para2 = 309;
	    return para2;
	  case 9984:
	    strcpy(ninfo, "Set Azimuth Offset Correction");
	    return para2;
	  case 10240:
	    strcpy(ninfo, "Set Azimuth Stall Error Thres");
	    return para2;
	  case 10496:
	    strcpy(ninfo, "Set Azimuth Stall Count Thres");
	    return para2;
	  case 12288:
	    strcpy(ninfo, "Set Packet Data Type");
	    para2 = 310;
	    return para2;
	  case 12544:
	    strcpy(ninfo, "Low Rate Science Transfer Enable");
	    para2 = 321;
	    return para2;
	  case 16128:
	    strcpy(ninfo, "EOSAM Load Initiate");
	    para2 = 322;
	    return para2;
	  case 16384:
	    strcpy(ninfo, "No Command DAP");
	    return para2;
	  case 16640:
	    strcpy(ninfo, "Set Scan Mode");
	    para2 = 311;
	    return para2;
	  case 16896:
	    strcpy(ninfo, "Command Cover Main");
	    para2 = 318;
	    return para2;
	  case 16897:
	    strcpy(ninfo, "Command Cover MAM");
	    para2 = 318;
	    return para2;
	  case 17152:
	    strcpy(ninfo, "Set SWICS Intensity");
	    para2 = 312;
	    return para2;
	  case 17408:
	    strcpy(ninfo, "Set Blackbody Temp Setpoint");
	    return para2;
	  case 17664:
	    strcpy(ninfo, "Set Blackbody Temp Control");
	    para2 = 313;
	    return para2;
	  case 17920:
	    strcpy(ninfo, "Set Tot Brid Bal Coarse DAC Val");
	    return para2;
	  case 17921:
	    strcpy(ninfo, "Set SW Brid Bal Coarse DAC Val");
	    return para2;
	  case 17922:
	    strcpy(ninfo, "Set LW Brid Bal Coarse DAC Val");
	    return para2;
	  case 18176:
	    strcpy(ninfo, "Set Tot Brid Bal Fine DAC Val");
	    return para2;
	  case 18177:
	    strcpy(ninfo, "Set SW Brid Bal Fine DAC Val");
	    return para2;
	  case 18178:
	    strcpy(ninfo, "Set LW Brid Bal Fine DAC Val");
	    return para2;
	  case 18432:
	    strcpy(ninfo, "Set Tot Brid Bal Control Mode");
	    para2 = 314;
	    return para2;
	  case 18433:
	    strcpy(ninfo, "Set SW Brid Bal Control Mode");
	    para2 = 314;
	    return para2;
	  case 18434:
	    strcpy(ninfo, "Set LW Brid Bal Control Mode");
	    para2 = 314;
	    return para2;
	  case 18688:
	    strcpy(ninfo, "Set Tot Sensor Temp Setpoint");
	    return para2;
	  case 18689:
	    strcpy(ninfo, "Set SW Sensor Temp Setpoint");
	    return para2;
	  case 18690:
	    strcpy(ninfo, "Set LW Sensor Temp Setpoint");
	    return para2;
	  case 18944:
	    strcpy(ninfo, "Set Tot Sensor Temp Control");
	    para2 = 315;
	    return para2;
	  case 18945:
	    strcpy(ninfo, " Set SW Sensor Temp Control");
	    para2 = 315;
	    return para2;
	  case 18946:
	    strcpy(ninfo, "Set LW Sensor Temp Control");
	    para2 = 315;
	    return para2;
	  case 19200:
	    strcpy(ninfo,  "Set Tot Sensor Temp Coef A0");
	    return para2;
	  case 19201:
	    strcpy(ninfo, "Set SW Sensor Temp Coef A0");
	    return para2;
	  case 19202:
	    strcpy(ninfo, "Set LW Sensor Temp Coef A0");
	    return para2;
	  case 19456:
	    strcpy(ninfo, "Set Tot Sensor Temp Coef A1");
	    return para2;
	  case 19457:
	    strcpy(ninfo, "Set SW Sensor Temp Coef A1");
	    return para2;
	  case 19458:
	    strcpy(ninfo, "Set LW Sensor Temp Coef A1");
	    return para2;
	  case 19712:
	    strcpy(ninfo, "Set Tot Sensor Temp Coef B1");
	    return para2;
	  case 19713:
	    strcpy(ninfo, "Set SW Sensor Temp Coef B1");
	    return para2;
	  case 19714:
	    strcpy(ninfo, "Set LW Sensor Temp Coef B1");
	    return para2;
	  case 19968:
	    strcpy(ninfo, "Set Tot Sensor Temp Coef D0");
	    return para2;
	  case 19969:
	    strcpy(ninfo, "Set SW Sensor Temp Coef D0");
	    return para2;
	  case 19970:
	    strcpy(ninfo, "Set LW Sensor Temp Coef D0");
	    return para2;
	  case 20480:
	    strcpy(ninfo, "Set Main Cover Active Pos Sensor");
	    para2 = 316;
	    return para2;
	  case 20736:
	    strcpy(ninfo, "Step Main Cover To Open");
	    return para2;
	  case 20737:
	    strcpy(ninfo,"Step MAM Cover To Open");
	    return para2;
	  case 20992:
	    strcpy(ninfo, "Step Main Cover To Closed");
	    return para2;
	  case 20993:
	    strcpy(ninfo, "Step MAM Cover To Closed");
	    return para2;
	  case 21248:
	    strcpy(ninfo, "Set Main Cover Sensor 1 Lag Error");
	    return para2;
	  case 21249:
	    strcpy(ninfo, "Set Main Cover Sensor 2 Lag Error");
	    return para2;
	  case 23040:
	    strcpy(ninfo, "Set Submux Control");
	    para2 = 317;
	    return para2;
	  case 23296:
	    strcpy(ninfo, "Set Submux Fixed Channel");
	    return para2;
	  case 23552:
	    strcpy(ninfo, "Set Elevation Stow Pos");
	    return para2;
	  case 24064:
	    strcpy(ninfo, "Set Watchdog Timer DAP");
	    para2 = 300;
	    return para2;
	  case 24320:
	    strcpy(ninfo, "Set PROM Power DAP");
	    para2 = 301;
	    return para2;
	  case 24576:
	    strcpy(ninfo, "Set Mem Dump Start Offset DAP");
	    return para2;
	  case 24832:
	    strcpy(ninfo, "Set Mem Dump Start Segment DAP");
	    return para2;
	  case 25088:
	    strcpy(ninfo, "Set Mem Dump End Offset DAP");
	    return para2;
	  case 25344:
	    strcpy(ninfo, "Set Mem Dump End Segment DAP");
	    return para2;
	  case 26112:
	    strcpy(ninfo, "Set Elevation Encoder LED");
	    para2 = 309;
	    return para2;
	  case 26368:
	    strcpy(ninfo, "Set Elevation Offset Correction");
	    return para2;
	  case 26624:
	    strcpy(ninfo, "Set Elevation Stall Error Thres");
	    return para2;
	  case 26880:
	    strcpy(ninfo, "Set Elevation Stall Count Thres");
	    return para2;
	  case 37120:
	    strcpy(ninfo, "ICP Memory Load");
	    return para2;
	  case 41472:
	    strcpy(ninfo, "ICP Sequence Table Load");
	    return para2;
	  case 42240:
	    strcpy(ninfo, "ICP Unique Data Load");
	    return para2;
	  case 53504:
	    strcpy(ninfo, "DAP Memory Load");
	    return para2;
	  case 58624:
	    strcpy(ninfo, "DAP Unique Data Load");
	    return para2;
	  case 62208:
	    strcpy(ninfo, "DAP Scan Table Load");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 100:
     {
        switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Temperature Control Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Temperature Control On");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 101:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Bridge Balance Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Bridge Balance Maintenance");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Bridge Balance Reset");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 102:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "DAC Value Unchanged");
	    return para2;
	  case 1:
	    strcpy(ninfo, "DAC Value Changed");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 103:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "SWICS Lamp Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "SWICS Lamp at Level 1");
	    return para2;
	  case 2:
	    strcpy(ninfo, "SWICS Lamp at Level 2");
	    return para2;
	  case 3:
	    strcpy(ninfo, "SWICS Lamp at Level 3");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 104:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stop");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Open");
	  case 2:
	    strcpy(ninfo, "Close");
	  case 4:
	    strcpy(ninfo, "Fixed Step Towares Open");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Fixed Step Towares Closed");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 105:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Cover Stopped");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cover Opening");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Cover Closing");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Cover Stepping Forwardr");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Cover Stepping Reverse");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Cover Start Moving");
	   return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 106:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Not At Opened Or Closed");
	    return para2;
	  case 1:
	    strcpy(ninfo, "At Open");
	    return para2;
	  case 2:
	    strcpy(ninfo, "At Closed");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Potential Bad Sensor");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 107:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Cover Sensor 1 Active");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cover Sensor 2 Active");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 108:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stow");
	    return para2; 
	  case 1:
	    strcpy(ninfo, "Normal Earth Scan");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Short Earth Scan");
	    return para2; 
	  case 3:
	    strcpy(ninfo, "MAM Scan");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Nadir Scan");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Noise Test 1");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Noise Test 2");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Stow Minus 45 Dwell");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Slam Against Stop");
	    return para2;
	  case 9:
	    strcpy(ninfo, "ICS Scan");
	    return para2;
	  case 10:
	    strcpy(ninfo, "WFBB Scan");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Nadir Dwell Scan");
	    return para2;
	  case 12:
	    strcpy(ninfo, "Nadir Plus 80 Dwell");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Nadir Minus 80 Dwell");
	    return para2;
	  case 14:
	    strcpy(ninfo, "MAM Uniformity Scan");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Step Response Scan");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 109:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Normal Scan Operation");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Initialization In-Progess");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "Elevation At Initialized Position");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Scan Abort In-Progress");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Elevation At Aborted Position");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 110:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Low Encoder LED Intensity");
	    return para2;
	  case 1:
	    strcpy(ninfo, "High Encoder LED Intensity");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 111:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Go to Crosstrack");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Go to Position A");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Go to Position B");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Go to Solar Calibration Angle");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Go to Caged");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Go to Spare Position 1");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Go to Spare Position 2");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Go to Spare Position 3");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Scan A to B Asynchronous");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Scan A to B Synchronous");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Stop Azimuth");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 112:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stopped");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Moving");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 113:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Forward");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Backward");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 114:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "At Go to Position");
	    return para2;
	  case 1:
	    strcpy(ninfo, "At Stopped");
	    return para2;
	  case 2:
	    strcpy(ninfo, "At Initial Position");
	    return para2;
	  case 3:
	    strcpy(ninfo, "At Scan Position");
	    return para2;
	  case 4:
	    strcpy(ninfo, "In Motion");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 115:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Drive Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Drive Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 116:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stop");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cage");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Apply");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Release");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Fixed Step Towards Cage");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Fixed Step Towards Apply");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 117:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stopped");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Caging");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "Applying");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Releasing");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Forward Stepping");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Reverse Stepping");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Start Moving");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 118:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Not At Released, Applied Or Caged");
	    return para2;
	  case 1:
	    strcpy(ninfo, "At Caged");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "At Applied");
	    return para2; 
	  case 3:
	    strcpy(ninfo, "At Released");
	    return para2; 
	  case 4:
	    strcpy(ninfo, "Potential Bad Position Sensor");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 119:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Normal Science Data");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Calibration Data");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Memory Dump Data");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Gimbal Data");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Execution Time Data");
	    return para2;
	  case 5:
	    strcpy(ninfo, "No Archive Data");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Fixed Pattern");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 120:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "FTM");
	    return para2;
	  case 1:
	    strcpy(ninfo, "PFM");
	    return para2;
	  case 2:
	    strcpy(ninfo, "FM1");
	    return para2;
	  case 3:
	    strcpy(ninfo, "FM2");
	    return para2;
	  case 4:
	    strcpy(ninfo, "FM3");
	    return para2;
	  case 5:
	    strcpy(ninfo, "FM4");
	    return para2;
	  case 6:
	    strcpy(ninfo, "FM5");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 121:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Timecode Based On SpaceCraft Timing");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Timecode Based On Instrument Timing");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 122:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Safe Mode");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Standby Mode");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "Crosstrack Mode");
	    return para2; 
	  case 3:
	    strcpy(ninfo, "Biaxial Mode");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Solar Calibration Mode");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Diagnostic Configuration Mode");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Internal Calibration Mode");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Special Short Scan Mode");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Contamination Safe Mode");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Hold Mode");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Abbreviated Internal Calibration");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Internal Sequence 11");
	    return para2;
	  case 12:
	    strcpy(ninfo, "Internal Sequence 12");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Internal Sequence 13");
	    return para2;
	  case 14:
	    strcpy(ninfo, "Internal Sequence 14");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Internal Sequence 15");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 123:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Command");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Safe Hold");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Solar Avoidance");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Scan Timeout");
	    return para2; 
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 124:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Executing Sequence Commands");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Waiting For Next Scan Period");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Waiting For Azimuth");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Sequence Complete");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 125:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Normal Operation");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Spacecraft Safe Hold");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 126:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 127:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Reset Not Caused by Watchdog Timeout");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Reset Caused by Watchdog Timeout");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 128:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Disarm Watchdog Timer");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Arm Watchdog Timer");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 129:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "PROM Power On");
	    return para2;
	  case 1:
	    strcpy(ninfo, "PROM Power Off");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 130:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Sun is Not Present");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Sun is Present");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 131:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Solar Presence Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Solar Presence Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 132:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Sun Not Detected");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Sun Detected");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 133:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Solar Warning Not Issued");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Solar Warning Issued");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 134:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Scan Timeout Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Scan Timeout Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 135:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Scan Timeout Not Actively Counting");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Scan Timeout Actively Counting");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 136:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Gimbal Not Stalled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Gimbal Stalled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 137:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Quick Look Flag Not Set");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Quick Look Flag Set");
		    return para2; 
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 138:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "DMA Communication Ok");
	    return para2;
	  case 1:
	    strcpy(ninfo, "DMA Transmit Timed Out");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "DMA Receive Timed Out");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Sample Numbers Out of Sync");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 139:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Cmd Accepted");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cmd Not Used");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Cmd Index Out Of Range");
	    return para2; 
	  case 3:
	    strcpy(ninfo, "Cmd Parameter Out Of Range");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Cmd Not A Valid Short Command");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Cmd Not A Valid Long Command");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Cmd Contained Incorrect Checksum");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Cmd Exceeded Mode Index");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Cmd Not Accepted In Current Mode");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Cmd Not Accepted During Seq Execution");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Cannot Use Brake While Az Moving");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Cannot Cage Az In Current Position");
	    return para2;
	  case 12:
	    strcpy(ninfo, "Cannot Move Az With Brake Not Released");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Reqd Mode Not Allowed In Current Mode");
	    return para2;
	  case 14:
	    strcpy(ninfo, "Pos A Must Be Less Than Pos B");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 140:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Spacecraft");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Internal Sequence");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 141:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "No Error");
	    return para2; 
	  case 1:
	    strcpy(ninfo, "Unexpected Interrupt");
	    return para2; 
	  case 2:
	    strcpy(ninfo, "Illegal Internal Seq Control Value");
	    return para2; 
	  case 3:
	    strcpy(ninfo, "Process Short Cmd Illegal Cmd");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Process Long Cmd Illegal Cmd");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Check Illegal Cmd");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Received 1553 Message With an Error");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Incorrect Initial DAA Sync");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Pack Data Illegal Data Indicator Value");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Int Seq Index Limit Exceeded");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Failed At Least One DMA Com");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Illegal HsKpg Destination Size");
	    return para2;
	  case 12:
	    strcpy(ninfo,  "Spurious DAP Sample Clk Interrupt");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Spurious ICP Sample Clk Interrupt");
	    return para2;
	  case 20:
	    strcpy(ninfo, "Potential Failed Brake Pos Sensor");
	    return para2;
	  case 21:
	    strcpy(ninfo, "Potential Failed Cover Pos Sensor");
	    return para2;
	  case 22:
	    strcpy(ninfo, "Main Cover Allowed Lag Exceeded");
	    return para2;
	  case 23:
	    strcpy(ninfo, "TRMM Science Pkt xfer Lockup Det");
	    return para2;
	  case 24:
	    strcpy(ninfo, "DAA & ICA Sample # Do not Match");
	    return para2;
	  case 25:
	    strcpy(ninfo, "DAA Reset Due to Cont Com Failure");
	    return para2;
	  case 63:
	    strcpy(ninfo, "Undefined Error");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 142:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "No Scan Timeout");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Scan Timeout Occurred");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 143:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 144:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Signal Not Received");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Signal Received");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 145:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Signal Received");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Signal Not Received");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 146:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Bus A Selected");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Bus B Selected");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 147:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "No Time Mark & Freq Interrupt");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Time Mark & Freq Interrupt Occurred");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument status");
	    return para2;
        }
     }
     case 300:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Disarm Watchdog Timer");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Arm Watchdog Timer");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 301:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "PROM Power On");
	    return para2;
	  case 1:
	    strcpy(ninfo, "PROM Power Off");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 302:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Go to Crosstrack");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Go to Position A");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Go to Position B");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Go to Solar Calibration Angle");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Go to Caged");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Go to Spare Position 1");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Go to Spare Position 2");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Go to Spare Position 3");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Scan A to B Asynchronous");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Scan A to B Synchronous");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Stop Azimuth");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 303:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stop");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cage");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Apply");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Release");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 304:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Safe Mode");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Standby Mode");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Crosstrack Mode");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Biaxial Mode");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Solar Calibration Mode");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Diagnostic Configuration Mode");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Internal Calibration Mode");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Special Short Scan Mode");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Contamination Safe Mode");
	    return para2;
	  case 9:
	    strcpy(ninfo, "Hold Mode");
	    return para2;
	  case 10:
	    strcpy(ninfo, "Abbrev Internal Calibration Mode");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Internal Sequence 11");
	    return para2;
	  case 12:
	    strcpy(ninfo, "Internal Sequence 12");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Internal Sequence 13");
	    return para2;
	  case 14:
	    strcpy(ninfo, "Internal Sequence 14");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Internal Sequence 15");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 305:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 306:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Solar Presence Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Solar Presence Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 307: 
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Scan Timeout Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Scan Timeout Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 308:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Quick Look Flag Not Set");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Quick Look Flag Set");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 309:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Low Encoder LED Intensity");
	    return para2;
	  case 1:
	    strcpy(ninfo, "High Encoder LED Intensity");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 310:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Normal Science Data");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Calibration Data");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Memory Dump Data");
	    return para2;
	  case 3:
	    strcpy(ninfo, "Gimbal Data");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Execution Time Data");
	    return para2;
	  case 5:
	    strcpy(ninfo, "No Archive Data");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Fixed Pattern");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 311:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stow");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Normal Earth Scan");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Short Earth Scan");
	    return para2;
	  case 3:
	    strcpy(ninfo, "MAM Scan");
	    return para2;
	  case 4:
	    strcpy(ninfo, "Nadir Scan");
	    return para2;
	  case 5:
	    strcpy(ninfo, "Noise Test 1");
	    return para2;
	  case 6:
	    strcpy(ninfo, "Noise Test 2");
	    return para2;
	  case 7:
	    strcpy(ninfo, "Stow Minus 45 Dwell");
	    return para2;
	  case 8:
	    strcpy(ninfo, "Slam Against Stop");
	    return para2;
	  case 9:
	    strcpy(ninfo, "ICS Scan");
	    return para2;
	  case 10:
	    strcpy(ninfo, "WFBB Scan");
	    return para2;
	  case 11:
	    strcpy(ninfo, "Nadir Dwell Scan");
	    return para2;
	  case 12:
	    strcpy(ninfo, "Nadir Plus 80 Dwell");
	    return para2;
	  case 13:
	    strcpy(ninfo, "Nadir Minus 80 Dwell");
	    return para2;
	  case 14:
	    strcpy(ninfo, "MAM Uniformity Scan");
	    return para2;
	  case 15:
	    strcpy(ninfo, "Step Response Scan");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 312:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "SWICS Lamp Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "SWICS Lamp @ Level 1");
	    return para2;
	  case 2:
	    strcpy(ninfo, "SWICS Lamp @ Level 2");
	    return para2;
	  case 3:
	    strcpy(ninfo, "SWICS Lamp @ Level 3");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 313:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Blackbody Temp Control Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Blackbody Temp Control On");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 314:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Bridge Balance Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Bridge Balance On");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 315:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Detector Temp Control Off");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Detector Temp Control On");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 316:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Cover Sensor 1 Active");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Cover Sensor 2 Active");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 317:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Submux Table");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Fixed Channel");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 318:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Stop");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Open");
	    return para2;
	  case 2:
	    strcpy(ninfo, "Close");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 319:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Bus A");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Bus B");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 320:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Response Disabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Response Enabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 321:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "Transfer Enabled");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Transfer Disabled");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
     case 322:
     {
	switch(para1)
	{
	  case 0:
	    strcpy(ninfo, "No Action");
	    return para2;
	  case 1:
	    strcpy(ninfo, "Load");
	    return para2;
	  default:
	    strcpy(ninfo, "Unknown Instrument Command");
	    return para2;
        }
     }
  }
}

/* ============================================================================
PROCEDURE Error_Message
=============================================================================*/
void Error_Message(char *Message)
{
  printf("%s\n", Message);
}

/* ============================================================================
PROCEDURE Initialize
=============================================================================*/
void Initialize(void)
{
  strcpy(Conv_Digital.Name, Conv_Digital_Vdata_Name);
  Initialize_Vdata(&Conv_Digital);

  strcpy(Time_Indices.Name, Time_Indices_SDS_Name);
  Initialize_SDS(&Time_Indices);

  strcpy(Raw_Digital.Name, Raw_Digital_SDS_Name);
  Initialize_SDS(&Raw_Digital);
}

/* ============================================================================
PROCEDURE Initialize_Vdata
=============================================================================*/
void Initialize_Vdata(Vdata *Vdata_In)
{
  Vdata_In->ID = UNINITIALIZED;
  Vdata_In->Reference = UNINITIALIZED;
  Vdata_In->Attached = FALSE;
  Vdata_In->Total_Fields = 0;
  Vdata_In->Total_Records = 0;
  Vdata_In->Current_Record = UNINITIALIZED;
  Vdata_In->Record_Size = 0;
  Vdata_In->Vdata_Buffer = NULL;
}

/* ============================================================================
PROCEDURE Initialize_SDS
=============================================================================*/
void Initialize_SDS(SDS *SDS_In)
{
  SDS_In->ID = UNINITIALIZED;
  SDS_In->Index = UNINITIALIZED;
  SDS_In->Selected = FALSE;
  SDS_In->Rows = 0;
  SDS_In->Columns = 0;
  SDS_In->Data_Type = 0;
  SDS_In->Data_Size = 0;
}

/* ============================================================================
PROCEDURE Open_BDS
=============================================================================*/
void Open_BDS(char *File_Name)
{
  strcpy(BDS_HDF.Name, File_Name);
  BDS_HDF.ID = Hopen(BDS_HDF.Name, DFACC_READ, 0);
  if (BDS_HDF.ID == FAIL)
    {
      Error_Message("ERROR - Unable to open BDS file for VSet access.");
      Close_and_Exit();
    }
  else
    {
      BDS_HDF.File_Opened = TRUE;
      Vstart(BDS_HDF.ID);
      BDS_HDF.V_Access_Enabled = TRUE;
    }

  strcpy(BDS_SD.Name, File_Name);
  BDS_SD.ID = SDstart(BDS_SD.Name, DFACC_READ);
  if (BDS_SD.ID == FAIL)
    {
      Error_Message("ERROR - Unable to open BDS file for SD access.");
      Close_and_Exit();
    }
  else
      BDS_SD.Access_Enabled = TRUE;
}

/* ===========================================================================
FUNCTION Open_Vdata
============================================================================*/ 
int Open_Vdata(Vdata *Vdata_In)
{
  int Status;
  int32 Number_of_Records;
  int32 HDF_Status;
  int32 Record_Size;
  char Field_Names[FIELDLISTMAXSIZE];
  int32 Buffer_Size;

  Vdata_In->Reference = VSfind(BDS_HDF.ID, Vdata_In->Name);
  if (Vdata_In->Reference == FAIL)
    {
      fprintf(stderr, "ERROR - Could not find Vdata %s\n.", Vdata_In->Name);
      Status = FAILURE;
    }
  else
    {
      Vdata_In->ID = VSattach(BDS_HDF.ID, Vdata_In->Reference, READ_ACCESS);
      HDF_Status = VSinquire(Vdata_In -> ID, &Number_of_Records, NULL,
			     Field_Names, &Record_Size, NULL);
      if (HDF_Status != FAIL)
	{
	  Vdata_In -> Total_Records = Number_of_Records;
	  Vdata_In -> Record_Size = Record_Size;
	  strcpy(Vdata_In -> Field_Names, Field_Names);

	  /* =================================================================
	     Allocate memory for the Vdata buffer
	     ===============================================================*/

	  Buffer_Size = Vdata_In -> Record_Size * Vdata_In -> Total_Records;
	  /* Buffer_Size = Vdata_In -> Record_Size ; */
	  Vdata_In -> Vdata_Buffer = malloc((size_t)Buffer_Size);

	  if (Vdata_In -> Vdata_Buffer == NULL)
	    {
	      Error_Message("ERROR - Unable to allocate Vdata buffer.");
	      Status = FAILURE;
	    }
	  else
	    Status = SUCCESS;
	}
      else
	{
	  Error_Message("ERROR - Vdata inquiry failed.");
	  Status = FAILURE;
	}

      if (Status == SUCCESS)
	Vdata_In -> Attached = TRUE;

    }
  return Status;
}

/* ===========================================================================
FUNCTION Close_Vdata
============================================================================*/ 
void Close_Vdata(Vdata *Vdata_In)
{
  printf("Closing Vdata %s.\n", Vdata_In -> Name);
  VSdetach(Vdata_In->ID);
  printf("End closing Vdata %s.\n", Vdata_In->Name);
  Vdata_In -> Attached = FALSE;
}

/* ===========================================================================
FUNCTION Open_SDS
============================================================================*/
int Open_SDS(SDS *SDS_In)
{
  int Status;
  char Name[MAX_NC_NAME];
  int32 Dimension_Sizes[2];
  int32 Rank, Number_Type, Attr_No, HDF_Status;

  SDS_In->Index = SDnametoindex(BDS_SD.ID, SDS_In->Name);
  if (SDS_In->Index == FAIL)
    {
      printf("ERROR - Could not find %s SDS.\n", SDS_In->Name);
      Status = FAILURE;
    }
  else
    {
      SDS_In->ID = SDselect(BDS_SD.ID, SDS_In->Index);
      HDF_Status = SDgetinfo(SDS_In -> ID, Name, &Rank, Dimension_Sizes,
			     &Number_Type, &Attr_No);
      if (HDF_Status != FAIL)
	{
	  SDS_In -> Rows = Dimension_Sizes[0];
	  SDS_In -> Columns = Dimension_Sizes[1];
	  SDS_In -> Data_Type = Number_Type;

	  switch (Number_Type)
	    {
	    case DFNT_UINT8 :
	    case DFNT_INT8 :
	      SDS_In -> Data_Size = sizeof(uint8);
	      break;

	    case DFNT_UINT16 :
	    case DFNT_INT16 :
	      SDS_In -> Data_Size = sizeof(uint16);
	      break;

	    case DFNT_UINT32 :
	    case DFNT_INT32 :
	    case DFNT_FLOAT32 :
	      SDS_In -> Data_Size = sizeof(uint32);
	      break;

	    case DFNT_FLOAT64 :
	      SDS_In -> Data_Size = sizeof(float64);
	      break;

	    }
	}
      SDS_In->Selected = TRUE;
      Status = SUCCESS;
    }
  return Status;
}

/* ===========================================================================
FUNCTION Close_SDS
============================================================================*/
void Close_SDS(SDS *SDS_In)
{
  int32 Status;

  printf("Closing SDS data %s.\n", SDS_In->Name);
  Status = SDendaccess(SDS_In->ID);
  if (Status == SUCCEED)
    SDS_In -> Selected = FALSE;
  else
    {
      Error_Message("ERROR - SDS close.");
      printf("%s\n", SDS_In->Name);
    }
  printf("End close SDS data %s.\n", SDS_In->Name);
}

/* ===========================================================================
PROCEDURE Close_BDS
============================================================================*/
int Close_BDS(void)
{
  if (Conv_Digital.Attached)
    Close_Vdata(&Conv_Digital);

  if (Raw_Digital.Selected)
    Close_SDS(&Raw_Digital);

  if (Time_Indices.Selected)
    Close_SDS(&Time_Indices);

  if (QA_Flags.Selected)
    Close_SDS(&QA_Flags);

  if (BDS_SD.Access_Enabled)
    {
      SDend(BDS_SD.ID);
      BDS_SD.Access_Enabled = FALSE;
    }

  if (BDS_HDF.V_Access_Enabled)
    {
      Vend(BDS_HDF.ID);
      BDS_HDF.V_Access_Enabled = FALSE;
    }

  if (BDS_HDF.File_Opened)
    {
      Hclose(BDS_HDF.ID);
      BDS_HDF.File_Opened = FALSE;
    }

}

/* ===========================================================================
PROCEDURE Close_and Exit
============================================================================*/
int Close_and_Exit(void)
{
  Free_Data_Arrays();
  Close_BDS();
  printf("Processing terminated.\n");
  return (-1);
}

/* ===========================================================================
PROCEDURE Structures_Match
============================================================================*/
BOOLEAN Structures_Match(void)
{
  BOOLEAN Status = FALSE;

  if ( Conv_Digital.Total_Records == Raw_Digital.Rows &&
      Raw_Digital.Rows == Time_Indices.Rows)

    Status = TRUE;

  return Status;
}

/* ===========================================================================
PROCEDURE Build_Data_Arrays
============================================================================*/
BOOLEAN Build_Data_Arrays(void)
{
  int Array_Size;
  BOOLEAN Status = FALSE;

  Converted_Digital_Table = calloc(BDS_Total_Records, sizeof(Converted_Digital_Record));
  if(Converted_Digital_Table == NULL)
  {
    Error_Message("ERROR - Unable to allocate Converted_Digital_Table.");
    return Status;
  }

  Array_Size = sizeof(int32) * MAX_FIELD;
  Digital_Data_Variables = calloc(BDS_Total_Records, Array_Size);
  if (Digital_Data_Variables == NULL)
  {
    Error_Message("ERROR - Unable to allocate Digital_Data_Variables.");
    return Status;
  }

  Array_Size = sizeof(float64) * 2;

  Julian_Times_Array = calloc(BDS_Total_Records, Array_Size);
  if(Julian_Times_Array == NULL)
  {
    Error_Message("ERROR - Unable to allocate Julian_Times_Array.");
    return Status;
  }

  Status = TRUE;

  return Status;
}

/* ===========================================================================
PROCEDURE Free_Data_Arrays
============================================================================*/
void Free_Data_Arrays(void)
{
  if (Converted_Digital_Table != NULL)
    free(Converted_Digital_Table);

  if (Digital_Data_Variables != NULL)
    free(Digital_Data_Variables);

  if (Julian_Times_Array != NULL)
    free(Julian_Times_Array);
}

/* ===========================================================================
PROCEDURE Initialize_Read_Vdata
============================================================================*/
int Initialize_Read_Vdata(Vdata *Vdata_In)
{

  int Status;
  int Set_Fields;

  Status = SUCCESS;

  if (!Vdata_In -> Attached)
  {
    printf("ERROR - %s Vdata not attached.\n", Vdata_In->Name);
    Status = FAILURE;
    return Status;
  }

  Set_Fields = VSsetfields(Vdata_In -> ID, Vdata_In -> Field_Names);
  if(Set_Fields == FAIL)
  {
    printf("ERROR - Unable to set %s Vdata record fields.\n", Vdata_In->Name);
    Status = FAILURE;
    return Status;
  }

  return Status;

}

/* ===========================================================================
PROCEDURE Read_CD_Vdata
============================================================================*/
int Read_CD_Vdata(Vdata *Vdata_In)
{

  int Status;
  int32 Records_Read;
  int32 Seek_Record;
  int32 Record;
  uint8 *Buffer_Index;
  Converted_Digital_Record Local_Record;
  size_t Data_Size1, Data_Size2;

  Status = SUCCESS;

  Status = Initialize_Read_Vdata(Vdata_In);

  if(Status == FAILURE)
  {
    Error_Message("ERROR - Unable to initialize Read Vdata for Conv_Digital.");
    return Status;
  }

  Data_Size1 = sizeof(Local_Record.Packet_Counter);
  Data_Size2 = 17 * sizeof(float32);

  Seek_Record = VSseek(Vdata_In->ID, 0);
  if (Seek_Record == FAIL)
  {
    printf("ERROR - Unable to seek %d %s Vdata record.\n", Record, Vdata_In->Name);
    Status = FAILURE;
    return Status;
  }

  Records_Read = VSread(Vdata_In -> ID, Vdata_In -> Vdata_Buffer, BDS_Total_Records, FULL_INTERLACE);
  if (Records_Read == FAIL)
  {
    printf("ERROR - Unable to read %d %s Vdata.\n", Record, Vdata_In->Name);
    Status = FAILURE;
    return Status;
  }

  Buffer_Index = Vdata_In -> Vdata_Buffer;

  for (Record = 0; Record < BDS_Total_Records; Record++)
  {
    Buffer_Index = Buffer_Index +  Data_Size2;

    Buffer_Index = Buffer_Index + 5 * Data_Size1;
    memcpy((char *)&Local_Record.Packet_Counter, (char *)Buffer_Index, Data_Size1);

    Buffer_Index = Buffer_Index + Data_Size1;

    *(Converted_Digital_Table + Record) = Local_Record;

  }

  if (Vdata_In -> Vdata_Buffer != NULL)
    free(Vdata_In -> Vdata_Buffer);

  return Status;

}

/* ===========================================================================
PROCEDURE Read_JT_SDS
============================================================================*/
int Read_JT_SDS(SDS *SDS_In)
{

  int Status;
  int Read_Status;
  int32 Start[2], Edge[2];
  int32 i, j;

  Status = SUCCESS;

  Start[0] = 0;
  Start[1] = 0;
  Edge[0] = BDS_Total_Records;
  Edge[1] = 2;

  Read_Status = SDreaddata(SDS_In->ID, Start, NULL, Edge, (void *)Julian_Times_Array);
  if(Read_Status == FAIL)
  {
    Error_Message("ERROR - Unable to read Time_Indices SDS.");
    Status = FAILURE;
  }
      
  return Status;
 
}

/* ===========================================================================
PROCEDURE Read_SDS
============================================================================*/
int Read_SDS(SDS *SDS_In, void *Data_Array)
{

  int Status;
  int Read_Status;
  int32 Start[2], Edge[2];
  int32 i;
 
  Status = SUCCESS;
 
  Start[0] = 0;
  Start[1] = 0;
  Edge[0] = SDS_In->Rows;
  Edge[1] = SDS_In->Columns;
 
  Read_Status = SDreaddata(SDS_In->ID, Start, NULL, Edge, (void *)Data_Array);
  if(Read_Status == FAIL)
  {
    fprintf(stderr, "ERROR - Unable to read SDS_In->Name SDS.\r\n");
    Status = FAILURE;
  }

  return Status;

}

/* ===========================================================================
PROCEDURE Open_All_BDS_Structures
============================================================================*/
int Open_All_BDS_Structures(void)
{

  int Main_Status;

  Main_Status = SUCCESS;

  if (!Open_Vdata(&Conv_Digital))
  {
    Error_Message("ERROR - Unable to open Conv_Digital Vdata.");
    Main_Status = FAILURE;
    return Main_Status;
  }

  if (!Open_SDS(&Raw_Digital))
  {
    Error_Message("ERROR - Unable to open Raw_Digital SDS.");
    Main_Status = FAILURE;
    return Main_Status;
  }

  if (!Open_SDS(&Time_Indices))
  {
    Error_Message("ERROR - Unable to open Time_Indices SDS.");
    Main_Status = FAILURE;
    return Main_Status;
  }

  return Main_Status;

}

/* ===========================================================================
FUNCTION Read_Digital_Location_File
============================================================================*/
Digital_Data_Record Read_Digital_Location_File(int32 index, int32 instr_id, int32 *number_variables)
{
  int32  num_var, i;
  int32 word_number, first_bit, last_bit, note;
  int32 num_read, num_skip1, num_skip2;
  size_t name_len;
  char buf[120];
  char name[50];
  char *loc;
  char *ptr_str;
  char *Digital_File_Name;
  FILE *digital;
  Digital_Data_Record Digital_Data_Info[MAX_FIELD];

  Digital_File_Name = malloc(strlen(Digital_Location_File) + 1);
  if(Digital_File_Name == NULL)
  {
    fprintf(stderr, "Memory allocation error for Digital_File_Name.\n");
    Digital_Data_Info[index].word_number = -1;
    return Digital_Data_Info[index];
  }
 
  strcpy(Digital_File_Name, Digital_Location_File);

  if((digital = fopen(Digital_File_Name, "r")) == NULL)
  {
    fprintf(stderr, "ERROR - Unable to open Digital_Location.file.\r\n");
    free(Digital_File_Name);
    Digital_Data_Info[index].word_number = -1;
    return Digital_Data_Info[index];
  }

  num_var = 0;
  while( !feof(digital) )
  { 
    fgets(buf, 119, digital);
    if(buf[0] == '\0') continue;

    if(buf[0] == '-') 
    {
	loc = strstr(buf, "WORD 142");
	if (loc == NULL) continue;
	switch (instr_id)
	{
	    case 1:
	    {
		num_read = 4;
		num_skip1 = 0;
		num_skip2 = 10;
		break;
	    }
	    case 2:
	    case 3:
	    case 8:
	    {
		num_read = 7;
		num_skip1 = 6;
		num_skip2 = 0;
		break;
	    }
	    case 4:
	    case 5:
	    {
		num_read = 0;
		num_skip1 = 14;
		num_skip2 = 0;
		break;
	    }
	    default:
	    {
		num_read = 4;
		num_skip1 = 0;
		num_skip2 = 10;
	    }
	}

	for (i = 0; i < num_skip1; i++)
	{
		fgets(buf, 119, digital);
	}

	for (i = 0; i < num_read; i++)
	{
		fgets(buf, 119, digital);
		loc = NULL;
		loc = strchr(buf, ' ');
		if( loc == NULL)
		{
			fprintf(stderr, "ERROR - Unable to separate the variable name.\r\n");
			fprintf(stderr, "%s\n", buf);
			free(Digital_File_Name);
			Digital_Data_Info[index].word_number = -1;
			return Digital_Data_Info[index];
		}

		*loc = '\0';
		strcpy(name, buf);
		ptr_str = loc + 1;
		sscanf(ptr_str, "%d%d%d%d", &word_number, &first_bit, &last_bit, &note);

		strcpy(Digital_Data_Info[num_var].name , name);
		Digital_Data_Info[num_var].word_number = word_number;
		Digital_Data_Info[num_var].first_bit = first_bit;
		Digital_Data_Info[num_var].last_bit = last_bit;
		Digital_Data_Info[num_var].note = note;
		Digital_Data_Info[num_var].position = num_var;

		num_var++;
	}
		
	for (i = 0; i < num_skip2; i++)
	{
		fgets(buf, 119, digital);
	}

	continue;

    }
    loc = NULL;
    loc = strchr(buf, ' ');
    if( loc == NULL)
    {
      fprintf(stderr, "ERROR - Unable to separate the variable name.\r\n");
      fprintf(stderr, "%s\n", buf);
      free(Digital_File_Name);
      Digital_Data_Info[index].word_number = -1;
      return Digital_Data_Info[index];
    }

    *loc = '\0';
    strcpy(name, buf);
    ptr_str = loc + 1;
    sscanf(ptr_str, "%d%d%d%d", &word_number, &first_bit, &last_bit, &note);

    strcpy(Digital_Data_Info[num_var].name , name);
    Digital_Data_Info[num_var].word_number = word_number;
    Digital_Data_Info[num_var].first_bit = first_bit;
    Digital_Data_Info[num_var].last_bit = last_bit;
    Digital_Data_Info[num_var].note = note;
    Digital_Data_Info[num_var].position = num_var;

    num_var++;
  }
  
  *number_variables = num_var;
  free(Digital_File_Name);
  fclose(digital);
  return Digital_Data_Info[index];
}

/* ===========================================================================
FUNCTION Assign_Digital_Mask_Value
============================================================================*/
uint16 Assign_Digital_Mask_Value(Digital_Data_Record Digital_Data_Inform)
{

  int i, j;
  int32 first_bit, last_bit;
  uint16 temp_mask;

  temp_mask = 0;
  first_bit = Digital_Data_Inform.first_bit;
  last_bit = Digital_Data_Inform.last_bit;
  for(j = first_bit; j <= last_bit ; j++)
  {
    temp_mask = temp_mask | ( 1 << j);
  }
  return temp_mask;
}

/* ===========================================================================
FUNCTION Get_Digital_NameList
============================================================================*/
char *get_digital_namelist(int argc, void *argv[])
{
  int32 i;
  int32 *instr_id;
  int32 num_read, num_skip1, num_skip2;
  size_t name_len;
  char variable_names[32678];
  char buf[120];
  char name[50];
  char *loc;
  char *Digital_File_Name;
  FILE *digital;

    if(argc != 1)
    {
       fprintf(stderr,"get_digital_namelist: Incorrect number of arguments\r\n");
       strcpy(variable_names, "BAD");
       return variable_names;  /* Signal an error */
    }

    instr_id 	    =(int32 *)argv[0];

  Digital_File_Name = malloc(strlen(Digital_Location_File) + 1);
  if(Digital_File_Name == NULL)
  {
    fprintf(stderr, "Memory allocation error for Digital_File_Name.\n");
    strcpy(variable_names, "BAD");
    return variable_names;
  }
 
  strcpy(Digital_File_Name, Digital_Location_File);

  if((digital = fopen(Digital_File_Name, "r")) == NULL)
  {
    fprintf(stderr, "ERROR - Unable to open Digital_Location.file.\r\n");
    free(Digital_File_Name);
    strcpy(variable_names, "BAD");
    return variable_names;
  }

  variable_names[0] = '\0';
  while( !feof(digital) )
  { 
      
    fgets(buf, 119, digital);
    if(buf[0] == '\0') continue;

    if(buf[0] == '-') 
    {
	loc = strstr(buf, "WORD 142");
	if (loc == NULL) continue;
	switch (*instr_id)
	{
	    case 1:
	    {
		num_read = 4;
		num_skip1 = 0;
		num_skip2 = 10;
		break;
	    }
	    case 2:
	    case 3:
            case 8:
	    {
		num_read = 7;
		num_skip1 = 6;
		num_skip2 = 0;
		break;
	    }
	    case 4:
	    case 5:
	    {
		num_read = 0;
		num_skip1 = 14;
		num_skip2 = 0;
		break;
	    }
	    default:
	    {
		num_read = 4;
		num_skip1 = 0;
		num_skip2 = 10;
	    }
	}

	for (i = 0; i < num_skip1; i++)
	{
		fgets(buf, 119, digital);
	}

	for (i = 0; i < num_read; i++)
	{
		fgets(buf, 119, digital);
		loc = NULL;
		loc = strchr(buf, ' ');
		if( loc == NULL)
		{
			fprintf(stderr, "ERROR - Unable to separate the variable name.\r\n");
			fprintf(stderr, "%s", buf);
			free(Digital_File_Name);
			strcpy(variable_names, "BAD");
			return variable_names;
		}

		*loc = '\0';
		strcpy(name, buf);

		strcat(variable_names, name);
		strcat(variable_names, ",");
	}
		
	for (i = 0; i < num_skip2; i++)
	{
		fgets(buf, 119, digital);
	}

	continue;

    }
    loc = NULL;
    loc = strchr(buf, ' ');
    if( loc == NULL)
    {
      fprintf(stderr, "ERROR - Unable to separate the variable name.\r\n");
      fprintf(stderr, "%s", buf);
      free(Digital_File_Name);
      strcpy(variable_names, "BAD");
      return variable_names;
    }

    *loc = '\0';
    strcpy(name, buf);

    strcat(variable_names, name);
    strcat(variable_names, ",");
  }
  
  name_len = strlen(variable_names);
  if(name_len) variable_names[name_len-1] = '\0';

  free(Digital_File_Name);
  fclose(digital);
  return variable_names;
}


/* ===========================================================================
FUNCTION Assign_QA_Mask_Value
============================================================================*/
QA_Flag_Record Assign_QA_Mask_Value(int32 index)
{

  QA_Flag_Record QA_Flag_Inform[MAX_QA];

  strcpy(QA_Flag_Inform[0].name , "CERES FOV Flag");
  QA_Flag_Inform[0].first_bit = 0;
  QA_Flag_Inform[0].mask = 0x00000003;

  strcpy(QA_Flag_Inform[1].name , "SW Filtered Radiance Flag");
  QA_Flag_Inform[1].first_bit = 2;
  QA_Flag_Inform[1].mask = 0x0000000c;

  strcpy(QA_Flag_Inform[2].name , "WN Filtered Radiance Flag");
  QA_Flag_Inform[2].first_bit = 4;
  QA_Flag_Inform[2].mask = 0x00000030;

  strcpy(QA_Flag_Inform[3].name , "Total Filtered Radiance Flag");
  QA_Flag_Inform[3].first_bit = 6;
  QA_Flag_Inform[3].mask = 0x000000c0;

  strcpy(QA_Flag_Inform[4].name , "Azimuth Scan Plane");
  QA_Flag_Inform[4].first_bit = 8;
  QA_Flag_Inform[4].mask = 0x00000300;

  strcpy(QA_Flag_Inform[5].name , "Elevation Scan Profile");
  QA_Flag_Inform[5].first_bit = 10;
  QA_Flag_Inform[5].mask = 0x00003c00;

  strcpy(QA_Flag_Inform[6].name , "Azimuth Motion Status");
  QA_Flag_Inform[6].first_bit = 14;
  QA_Flag_Inform[6].mask = 0x00004000;

  strcpy(QA_Flag_Inform[7].name , "Elevation Scan Rate");
  QA_Flag_Inform[7].first_bit = 15;
  QA_Flag_Inform[7].mask = 0x00018000;

  strcpy(QA_Flag_Inform[8].name , "Clock Angle Rate");
  QA_Flag_Inform[8].first_bit = 17;
  QA_Flag_Inform[8].mask = 0x00020000;

  strcpy(QA_Flag_Inform[9].name , "Cone Angle Rate");
  QA_Flag_Inform[9].first_bit = 18;
  QA_Flag_Inform[9].mask = 0x00040000;

  return QA_Flag_Inform[index];

}

/* ===========================================================================
FUNCTION Assign_AQA1_Mask_Value
============================================================================*/
QA_Flag_Record Assign_AQA1_Mask_Value(int32 index)
{

  QA_Flag_Record QA_Flag_Inform[MAX_AQA1];

  strcpy(QA_Flag_Inform[0].name , "Elevation Profile ID");
  QA_Flag_Inform[0].first_bit = 1;
  QA_Flag_Inform[0].mask = 0x0000003e;

  strcpy(QA_Flag_Inform[1].name , "MAM Cover Status");
  QA_Flag_Inform[1].first_bit = 6;
  QA_Flag_Inform[1].mask = 0x00000040;

  strcpy(QA_Flag_Inform[2].name , "Main Cover Status");
  QA_Flag_Inform[2].first_bit = 7;
  QA_Flag_Inform[2].mask = 0x00000080;

  strcpy(QA_Flag_Inform[3].name , "Bias Voltage Edit Check");
  QA_Flag_Inform[3].first_bit = 8;
  QA_Flag_Inform[3].mask = 0x00000300;

  strcpy(QA_Flag_Inform[4].name , "TOT DAC Voltage Edit Check");
  QA_Flag_Inform[4].first_bit = 10;
  QA_Flag_Inform[4].mask = 0x00000c00;

  strcpy(QA_Flag_Inform[5].name , "SW DAC Voltage Edit Check");
  QA_Flag_Inform[5].first_bit = 12;
  QA_Flag_Inform[5].mask = 0x00003000;

  strcpy(QA_Flag_Inform[6].name , "WN DAC Voltage Edit Check");
  QA_Flag_Inform[6].first_bit = 14;
  QA_Flag_Inform[6].mask = 0x0000c000;

  strcpy(QA_Flag_Inform[7].name , "TOT Heatsink Temperature Edit Check");
  QA_Flag_Inform[7].first_bit = 16;
  QA_Flag_Inform[7].mask = 0x00030000;

  strcpy(QA_Flag_Inform[8].name , "SW Heatsink Temperature Edit Check");
  QA_Flag_Inform[8].first_bit = 18;
  QA_Flag_Inform[8].mask = 0x000c0000;

  strcpy(QA_Flag_Inform[9].name , "WN Heatsink Temperature Edit Check");
  QA_Flag_Inform[9].first_bit = 20;
  QA_Flag_Inform[9].mask = 0x00300000;

  strcpy(QA_Flag_Inform[10].name , "TOT Radiance Edit Check");
  QA_Flag_Inform[10].first_bit = 22;
  QA_Flag_Inform[10].mask = 0x01c00000;

  strcpy(QA_Flag_Inform[11].name , "SW Radiance Edit Check");
  QA_Flag_Inform[11].first_bit = 25;
  QA_Flag_Inform[11].mask = 0x0e000000;

  strcpy(QA_Flag_Inform[12].name , "WN Radiance Edit Check");
  QA_Flag_Inform[12].first_bit = 28;
  QA_Flag_Inform[12].mask = 0x70000000;

  return QA_Flag_Inform[index];

}

/* ===========================================================================
FUNCTION Assign_AQA2_Mask_Value
============================================================================*/
QA_Flag_Record Assign_AQA2_Mask_Value(int32 index)
{

  QA_Flag_Record QA_Flag_Inform[MAX_AQA2];

  strcpy(QA_Flag_Inform[0].name , "TOT 2nd Time Constant Vk Status");
  QA_Flag_Inform[0].first_bit = 3;
  QA_Flag_Inform[0].mask = 0x00000038;

  strcpy(QA_Flag_Inform[1].name , "SW 2nd Time Constant Vk Status");
  QA_Flag_Inform[1].first_bit = 6;
  QA_Flag_Inform[1].mask = 0x000001c0;

  strcpy(QA_Flag_Inform[2].name , "WN 2nd Time Constant Vk Status");
  QA_Flag_Inform[2].first_bit = 9;
  QA_Flag_Inform[2].mask = 0x00000e00;

  strcpy(QA_Flag_Inform[3].name , "Measurement Used in Spaceclamp");
  QA_Flag_Inform[3].first_bit = 12;
  QA_Flag_Inform[3].mask = 0x00001000;

  strcpy(QA_Flag_Inform[4].name , "TOT SpaceClamp Status");
  QA_Flag_Inform[4].first_bit = 13;
  QA_Flag_Inform[4].mask = 0x0001e000;

  strcpy(QA_Flag_Inform[5].name , "SW SpaceClamp Status");
  QA_Flag_Inform[5].first_bit = 17;
  QA_Flag_Inform[5].mask = 0x001e0000;

  strcpy(QA_Flag_Inform[6].name , "WN SpaceClamp Status");
  QA_Flag_Inform[6].first_bit = 21;
  QA_Flag_Inform[6].mask = 0x01e00000;

  strcpy(QA_Flag_Inform[7].name , "TOT DAC Status");
  QA_Flag_Inform[7].first_bit = 25;
  QA_Flag_Inform[7].mask = 0x06000000;

  strcpy(QA_Flag_Inform[8].name , "SW DAC Status");
  QA_Flag_Inform[8].first_bit = 27;
  QA_Flag_Inform[8].mask = 0x18000000;

  strcpy(QA_Flag_Inform[9].name , "WN DAC Status");
  QA_Flag_Inform[9].first_bit = 29;
  QA_Flag_Inform[9].mask = 0x60000000;

  return QA_Flag_Inform[index];

}


/* ===========================================================================
FUNCTION get_analog_location
============================================================================*/
int get_analog_location(int argc, void *argv[])
{

  FILE *input_file;
  char buf[150];
  char *input_filename = {"Analog_Location.file"};
  char *loc;
  int32 interval;
  int i;
  int32 *location;
  STRING *field_name;
  int32 *true_order;
  void *output_data;

  if(argc != 3)
  {
/*     fprintf(stderr,"get_analog_location: Incorrect number of arguments\r\n"); */
     exit(1);
  }

  field_name   = (STRING *)argv[0];
  true_order   = (int32 *)argv[1];
  output_data  = (void *) argv[2];

  if((input_file = fopen(input_filename, "r")) == NULL)
  {
    /* fprintf(stderr, "\nERROR: Unable to open input file %s.\n", input_filename); */
    return(-1);
  }

  while( !feof(input_file))
  {
     buf[0] = '\0';
     if(fgets(buf, 149, input_file) == NULL)
     {
	/* fprintf(stderr, "\nERROR: End of input file or Reading Error encounted.\n"); */
	fclose(input_file);
	return(-1);
     }
     if(buf[0] == '\n' || buf[0] == '-') continue;

     loc = strstr(buf, field_name->s);
     if(loc == NULL) continue;

     location = (int32 *)output_data;
     switch(*true_order)
     {
	case 3:
	{
		buf[0] = '\0';
		if(fgets(buf, 149, input_file) == NULL)
		{
			/* fprintf(stderr, "\nERROR: End of input file or Reading Error encounted.\n"); */
			fclose(input_file);
			return(-1);
		}
		sscanf(buf, "%d%d%d", location, location+1, location+2);
		fclose(input_file);
		return(0);
	}
	case 12:
	{
		buf[0] = '\0';
		if(fgets(buf, 149, input_file) == NULL)
		{
			/* fprintf(stderr, "\nERROR: End of input file or Reading Error encounted.\n"); */
			fclose(input_file);
			return(-1);
		}
		sscanf(buf, "%d%d%d%d%d%d%d%d%d%d%d%d", location, location+1, location+2, location+3, \
			location+4, location+5, location+6, location+7, location+8, location+9, \
			location+10, location+11);
		fclose(input_file);
		return(0);
	}
	case 60:
        {
	   for(i=0;i<6;i++)
	   {
                buf[0] = '\0';
                if(fgets(buf, 149, input_file) == NULL)
                {
                        /* fprintf(stderr, "\nERROR: End of input file or Reading Error encounted.\n"); */
                        fclose(input_file);
                        return(-1);
                }
                sscanf(buf, "%d%d%d%d%d%d%d%d%d%d", location+(i*10), location+(i*10+1), location+(i*10+2), \
			location+(i*10+3), location+(i*10+4), location+(i*10+5), location+(i*10+6), \
			location+(i*10+7), location+(i*10+8), location+(i*10+9) );
	   }
                fclose(input_file);
                return(0);
        }
	default:
	{
		break;
	}
     }
    break;
  }
  fclose(input_file);
  return(-1);

}

