pro write_win,file,wid=wid,fgc=fgc,bgc=bgc,tiff=tiff,cmap=cmap
;+
; ROUTINE:      write_win
;
; PURPOSE:      copy image on current window to a gif image file
;
; USEAGE:       write_win,file
;
; INPUT:
;   file        output file name, image will be written in gif or tiff
;               image format
;
; KEYWORD INPUT:
;
;   tiff        if set, output is in tiff format instead of gif
;
;   cmap        if set, color table is expanded to 256 values.
;               don't use this option when discrete color values have
;               been set with dcolors or tvlct
;
;   wid         index of the idl window from which to copy the image,
;               if not set write_win copies from current default window
;
;   bgc         background color.  sets color index 0 of gif image to 
;               specified RGB value.  Does not affect current color table.
;               A scalor value of BGC is automatically turned into a color
;               triplet, i.e., bgc=255   =>  RGB=[255,255,255]
;
;   fgc         foreground color.  sets color index 255 of gif image to 
;               specified RGB value.  Does not affect current color table.
;               A scalor value of FGC is automatically turned into a color
;               triplet, i.e., fgc=0   =>  RGB=[0,0,0]
;
; OUTPUT:       none
;
; EXAMPLE:
;           loadct,5
;           window,0
;           tvim,sin(20*hanning(200,200)*dist(200)),title='GIF test image',/sc
;           write_win,'test_image.gif',fgc=0,bgc=[210,255,210]
;           write_win,'test_image.tiff',fgc=0,bgc=[210,255,210],/tiff
;           exit
;
;           xv test_image.gif
;
;  author:  Paul Ricchiazzi                            feb94
;           Institute for Computational Earth System Science
;           University of California, Santa Barbara
;
; REVISIONS:
;-
;
if n_elements(wid) ne 0 then begin
  oldwin=!d.window
  wset,wid
endif

tvlct,r,g,b,/get
im=bytscl(tvrd())

if keyword_set(cmap) then begin
  r=congrid(r,256,/minus_one)
  g=congrid(g,256,/minus_one)
  b=congrid(b,256,/minus_one)
endif 


nc=n_elements(r)-1
case n_elements(fgc) of
1:begin
  r(nc)=fgc
  g(nc)=fgc
  b(nc)=fgc
end
3:begin
  r(nc)=fgc(0)
  g(nc)=fgc(1)
  b(nc)=fgc(2)
end
else:
endcase

case n_elements(bgc) of
1:begin
  r(0)=bgc
  g(0)=bgc
  b(0)=bgc
end
3:begin
  r(0)=bgc(0)
  g(0)=bgc(1)
  b(0)=bgc(2)
end
else:
endcase

xresol=2.54*!d.x_px_cm
yresol=2.54*!d.y_px_cm

if keyword_set(tiff) then begin
  tiff_write,file,im,red=r,green=g,blue=b,xresol=xresol,yresol=yresol
endif else begin
  write_gif,file,im,r,g,b
endelse

if n_elements(wid) ne 0 then wset,oldwin
end
